import { ErrorEvent, CloseEvent } from 'reconnecting-websocket';
import { Doc } from 'sharedb/lib/client';
import { DocBlock, DocBlockDelta, DocObject, RemoteUsers } from '@nexteditorjs/nexteditor-core';
import { ClientError, ErrorType, ShareDBDocOptions, ShareDBError } from './options';
import { NextEditorCustomMessage, NextEditorInitMessage, NextEditorPresenceMessage, NextEditorUser, NextEditorWelcomeMessage } from '../messages';
export interface ShareDBDocClientEvent {
    onSubscribe: () => void;
    onOp: (ops: any[], source: any, clientId: string) => void;
    onError: (errorType: ErrorType, error: ClientError) => void;
    onClose: (event: CloseEvent) => void;
}
export default class ShareDBDocClient {
    private options;
    private events;
    private socket;
    private connection;
    private presence;
    private localPresence;
    private orgMessageHandler;
    private docUser;
    remoteUsers: RemoteUsers;
    clientId: string;
    doc: Doc;
    constructor(options: ShareDBDocOptions, events: ShareDBDocClientEvent);
    get data(): any;
    get user(): NextEditorUser;
    destroy(): void;
    handleSubscribe: (error: ShareDBError | undefined) => void;
    handleSubscribePresence: (error: unknown) => void;
    handleSocketError: (error: ErrorEvent) => void;
    handleSocketClose: (event: CloseEvent) => void;
    handleWebsocketMessage: (event: MessageEvent<unknown>) => void;
    handleCustomMessage: (event: MessageEvent<unknown>) => boolean;
    handleKnownCustomMessage: (message: NextEditorCustomMessage) => void;
    handleInitMessage: (message: NextEditorInitMessage) => void;
    handleWelcomeMessage: (message: NextEditorWelcomeMessage) => void;
    handlePresenceMessage: (id: string, value: unknown) => void;
    sendJoinMessage: () => void;
    submitOp: (ops: any) => Promise<void>;
    createDoc: (data: DocObject) => Promise<void>;
    insertChildContainer: (containerId: string, blocks: DocBlock[]) => Promise<void>;
    deleteChildContainer: (containerId: string) => Promise<void>;
    insertBlock: (containerId: string, index: number, obj: unknown) => Promise<void>;
    deleteBlock: (containerId: string, index: number) => Promise<void>;
    updateBlockData: (containerId: string, index: number, delta: DocBlockDelta) => Promise<void>;
    updateRichText: (containerId: string, index: number, ops: any[]) => Promise<void>;
    broadcastClientMessages: (data: NextEditorPresenceMessage) => Promise<void>;
}
