var __defProp = Object.defineProperty;
var __defNormalProp = (obj, key, value) => key in obj ? __defProp(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __publicField = (obj, key, value) => {
  __defNormalProp(obj, typeof key !== "symbol" ? key + "" : key, value);
  return value;
};
import { assert, genId, getLogger, toBase64URL, RemoteUsers, EventCallbacks, createEmptyDoc, getTextLength } from "@nexteditorjs/nexteditor-core";
import cloneDeep$1 from "lodash.clonedeep";
import ReconnectingWebSocket from "reconnecting-websocket";
import * as json1 from "ot-json1";
class BlockIds {
  constructor() {
    __publicField(this, "ids", /* @__PURE__ */ new Map());
  }
  onInsertBlock(blockIndex) {
    const indexes = Array.from(this.ids.keys()).sort((n1, n2) => n2 - n1);
    for (let i = 0; i < indexes.length; i++) {
      const index = indexes[i];
      if (index >= blockIndex) {
        const oldId = this.ids.get(index);
        assert(oldId !== void 0);
        this.ids.delete(index);
        this.ids.set(index + 1, oldId);
      }
    }
    const newId = genId();
    this.ids.set(blockIndex, newId);
  }
  onDeleteBlock(blockIndex) {
    this.ids.delete(blockIndex);
    const indexes = Array.from(this.ids.keys()).sort((n1, n2) => n1 - n2);
    for (let i = 0; i < indexes.length; i++) {
      const index = indexes[i];
      if (index > blockIndex) {
        const oldId = this.ids.get(index);
        assert(oldId !== void 0);
        this.ids.delete(index);
        this.ids.set(index - 1, oldId);
      }
    }
  }
  getId(blockIndex) {
    let id = this.ids.get(blockIndex);
    if (!id) {
      id = genId();
      this.ids.set(blockIndex, id);
    }
    return id;
  }
  getById(id) {
    return Array.from(this.ids.entries()).find(([, value]) => value === id);
  }
}
class ContainerBlockIds {
  constructor() {
    __publicField(this, "ids", /* @__PURE__ */ new Map());
  }
  getContainerIds(containerId) {
    let ret = this.ids.get(containerId);
    if (!ret) {
      ret = new BlockIds();
      this.ids.set(containerId, ret);
    }
    return ret;
  }
  onInsertBlock(containerId, blockIndex) {
    this.getContainerIds(containerId).onInsertBlock(blockIndex);
  }
  onDeleteBlock(containerId, blockIndex) {
    this.getContainerIds(containerId).onDeleteBlock(blockIndex);
  }
  getBlockId(containerId, blockIndex) {
    return this.getContainerIds(containerId).getId(blockIndex);
  }
  getBlockIndexById(id) {
    const entries = Array.from(this.ids.entries());
    for (let i = 0; i < entries.length; i++) {
      const entry = entries[i];
      const ret = entry[1].getById(id);
      if (ret) {
        return {
          containerId: entry[0],
          blockIndex: ret[0]
        };
      }
    }
    assert(false, "fault error: failed to get block index");
    return { containerId: "error", blockIndex: -1 };
  }
}
class OpBlockDataDelta {
  constructor(deletedKeys = /* @__PURE__ */ new Set(), insertedValues = /* @__PURE__ */ new Map()) {
    this.deletedKeys = deletedKeys;
    this.insertedValues = insertedValues;
  }
  insert(key, value) {
    this.insertedValues.set(key, value);
  }
  delete(key) {
    this.deletedKeys.add(key);
  }
  toDocBlockDelta() {
    const insert = {};
    this.insertedValues.forEach((value, key) => {
      insert[key] = value;
    });
    return {
      insert,
      delete: Array.from(this.deletedKeys)
    };
  }
}
const console$2 = getLogger("op-parser");
class InternalParser {
  constructor(handler, local) {
    __publicField(this, "updatingBlockDataDeltaMap", /* @__PURE__ */ new Map());
    __publicField(this, "blockIds", new ContainerBlockIds());
    this.handler = handler;
    this.local = local;
  }
  onDeleteBlock(containerId, blockIndex) {
    const blockId = this.blockIds.getBlockId(containerId, blockIndex);
    this.blockIds.onDeleteBlock(containerId, blockIndex);
    const ignoreObjectData = this.updatingBlockDataDeltaMap.get(blockId);
    if (ignoreObjectData) {
      console$2.debug(`ignore update object data before delete block: ${JSON.stringify(ignoreObjectData)}`);
      this.updatingBlockDataDeltaMap.delete(blockId);
    }
    this.handler.onDeleteBlock(containerId, blockIndex, this.local);
  }
  onInsertBlock(containerId, blockIndex, data) {
    this.blockIds.onInsertBlock(containerId, blockIndex);
    this.handler.onInsertBlock(containerId, blockIndex, data, this.local);
  }
  onUpdateBlockText(containerId, blockIndex, actions) {
    this.handler.onUpdateBlockText(containerId, blockIndex, actions, this.local);
  }
  onDeleteBlockData(containerId, blockIndex, key) {
    const blockId = this.blockIds.getBlockId(containerId, blockIndex);
    let delta = this.updatingBlockDataDeltaMap.get(blockId);
    if (!delta) {
      delta = new OpBlockDataDelta();
      this.updatingBlockDataDeltaMap.set(blockId, delta);
    }
    delta.delete(key);
  }
  onInsertBlockData(containerId, blockIndex, key, value) {
    const blockId = this.blockIds.getBlockId(containerId, blockIndex);
    let delta = this.updatingBlockDataDeltaMap.get(blockId);
    if (!delta) {
      delta = new OpBlockDataDelta();
      this.updatingBlockDataDeltaMap.set(blockId, delta);
    }
    delta.insert(key, value);
  }
  executeUpdateBlockDataActions() {
    Array.from(this.updatingBlockDataDeltaMap.entries()).forEach(([blockId, objectData]) => {
      const { containerId, blockIndex } = this.blockIds.getBlockIndexById(blockId);
      this.handler.onUpdateBlockData(containerId, blockIndex, objectData, this.local);
    });
  }
}
class DeleteBlockAction {
}
class DeleteBlockDataAction {
  constructor(key) {
    __publicField(this, "key");
    this.key = key;
  }
}
function parseInsertBlockOnlyOp(containerId, orgOps, parser) {
  const ops = orgOps.concat();
  const blockIndex = ops[0];
  if (typeof blockIndex !== "number") {
    return false;
  }
  ops.shift();
  if (ops.length === 1) {
    return false;
  }
  const firstOp = ops[0];
  if (typeof firstOp !== "object") {
    return false;
  }
  if (!firstOp.i || Object.keys(firstOp).length !== 1) {
    return false;
  }
  for (let i = 1; i < ops.length; i++) {
    const nextOp = ops[i];
    if (!Array.isArray(nextOp)) {
      return false;
    }
    if (nextOp.length !== 2) {
      return false;
    }
    const key = nextOp[0];
    if (typeof key !== "string") {
      return false;
    }
    const op = nextOp[1];
    if (typeof op !== "object") {
      return false;
    }
    if (op.i === void 0 || Object.keys(op).length !== 1) {
      return false;
    }
  }
  const blockData = firstOp.i;
  assert(blockData.id);
  assert(blockData.type);
  for (let i = 1; i < ops.length; i++) {
    const nextOp = ops[i];
    const key = nextOp[0];
    const op = nextOp[1];
    blockData[key] = op.i;
  }
  parser.onInsertBlock(containerId, blockIndex, blockData);
  return true;
}
function parseBlockOp(containerId, orgOps, processType, processor) {
  if (processType === "upsert" && parseInsertBlockOnlyOp(containerId, orgOps, processor)) {
    return;
  }
  assert(Array.isArray(orgOps), `invalid block op: ${containerId}, ${JSON.stringify(orgOps)}`);
  const ops = orgOps.concat();
  const blockIndex = ops[0];
  ops.shift();
  const removeActions = [];
  while (ops.length > 0) {
    const data = ops[0];
    if (data === "text") {
      const opData = ops[1];
      assert(typeof opData === "object");
      assert(opData.et === "rich-text");
      ops.splice(0, 2);
      if (processType === "upsert") {
        const deltaOps = opData.e;
        const richTextData = deltaOps;
        processor.onUpdateBlockText(containerId, blockIndex, richTextData);
      }
      assert(ops.length === 0);
    } else if (Array.isArray(data)) {
      assert(data.length === 2);
      const key = data[0];
      assert(typeof key === "string");
      const opData = data[1];
      if (key === "text") {
        assert(typeof opData === "object");
        if (opData.i) {
          if (processType === "upsert") {
            processor.onInsertBlockData(containerId, blockIndex, key, opData.i);
          }
        }
        if (opData.r) {
          if (processType === "remove") {
            processor.onDeleteBlockData(containerId, blockIndex, key);
          }
        }
        if (opData.et === "rich-text") {
          if (processType === "upsert") {
            const deltaOps = opData.e;
            const richTextData = deltaOps;
            processor.onUpdateBlockText(containerId, blockIndex, richTextData);
          }
        }
      } else {
        if (processType === "remove") {
          if (opData.r) {
            removeActions.push(new DeleteBlockDataAction(key));
          }
        }
        if (processType === "upsert") {
          if (opData.i) {
            processor.onInsertBlockData(containerId, blockIndex, key, opData.i);
          }
        }
      }
      ops.shift();
    } else if (typeof data === "object") {
      const opData = data;
      if (processType === "remove") {
        if (opData.r) {
          removeActions.push(new DeleteBlockAction());
        }
      }
      if (processType === "upsert") {
        if (opData.i) {
          processor.onInsertBlock(containerId, blockIndex, opData.i);
        }
      }
      ops.shift();
    } else {
      assert(typeof data === "string");
      assert(data !== "text");
      assert(ops.length === 2);
      const key = data;
      const opData = ops[1];
      if (processType === "remove") {
        if (opData.r) {
          removeActions.push(new DeleteBlockDataAction(key));
        }
      }
      if (processType === "upsert") {
        if (opData.i) {
          processor.onInsertBlockData(containerId, blockIndex, key, opData.i);
        }
      }
      ops.splice(0, 2);
    }
  }
  removeActions.reverse();
  removeActions.forEach((a) => {
    if (a instanceof DeleteBlockAction) {
      processor.onDeleteBlock(containerId, blockIndex);
    } else if (a instanceof DeleteBlockDataAction) {
      processor.onDeleteBlockData(containerId, blockIndex, a.key);
    } else {
      assert(false, `invalid action type: ${typeof a}, ${JSON.stringify(a)}`);
    }
  });
}
function parseMetaOp(ops, parseType, parser, handler) {
  console$2.warn(`unsupported meta op, ${JSON.stringify(ops)}`);
}
function parseOp(ops, parseType, parser, handler) {
  const rootKey = ops[0];
  if (rootKey === "meta") {
    parseMetaOp(ops);
    return;
  }
  assert(rootKey === "blocks", `invalid op path: ${JSON.stringify(ops)}`);
  const containerId = ops[1];
  if (Array.isArray(containerId)) {
    const subOps = ops.slice(1);
    subOps.forEach((subOp) => {
      const newOp = [rootKey, ...subOp];
      parseOp(newOp, parseType, parser, handler);
    });
    return;
  }
  assert(typeof containerId === "string", `invalid container id: ${JSON.stringify(ops)}`);
  if (Array.isArray(ops[2])) {
    if (parseType === "remove") {
      ops.slice(2).reverse().forEach((op) => {
        parseBlockOp(containerId, op, parseType, parser);
      });
    } else {
      ops.slice(2).forEach((op) => {
        parseBlockOp(containerId, op, parseType, parser);
      });
    }
  } else {
    if (typeof ops[2] === "object") {
      const action = ops[2];
      if (action.r) {
        if (parseType === "remove") {
          handler.onDeleteContainer(containerId, parser.local);
        }
      }
      if (action.i) {
        if (parseType === "upsert") {
          handler.onCreateContainer(containerId, action.i, parser.local);
        }
      }
    } else {
      assert(typeof ops[2] === "number");
      parseBlockOp(containerId, ops.slice(2), parseType, parser);
    }
  }
}
function parseOps(orgOps, handler, local) {
  const parser = new InternalParser(handler, local);
  for (let i = 0; i < 2; i++) {
    const parseType = i === 0 ? "remove" : "upsert";
    const ops = cloneDeep$1(orgOps);
    const first = ops[0];
    if (Array.isArray(first)) {
      ops.forEach((op) => {
        parseOp(op, parseType, parser, handler);
      });
    } else {
      parseOp(ops, parseType, parser, handler);
    }
  }
  parser.executeUpdateBlockDataActions();
}
var commonjsGlobal$1 = typeof globalThis !== "undefined" ? globalThis : typeof window !== "undefined" ? window : typeof global !== "undefined" ? global : typeof self !== "undefined" ? self : {};
function getAugmentedNamespace(n) {
  if (n.__esModule)
    return n;
  var a = Object.defineProperty({}, "__esModule", { value: true });
  Object.keys(n).forEach(function(k) {
    var d = Object.getOwnPropertyDescriptor(n, k);
    Object.defineProperty(a, k, d.get ? d : {
      enumerable: true,
      get: function() {
        return n[k];
      }
    });
  });
  return a;
}
var emitter$6 = {};
var events = { exports: {} };
var R = typeof Reflect === "object" ? Reflect : null;
var ReflectApply = R && typeof R.apply === "function" ? R.apply : function ReflectApply2(target, receiver, args) {
  return Function.prototype.apply.call(target, receiver, args);
};
var ReflectOwnKeys;
if (R && typeof R.ownKeys === "function") {
  ReflectOwnKeys = R.ownKeys;
} else if (Object.getOwnPropertySymbols) {
  ReflectOwnKeys = function ReflectOwnKeys2(target) {
    return Object.getOwnPropertyNames(target).concat(Object.getOwnPropertySymbols(target));
  };
} else {
  ReflectOwnKeys = function ReflectOwnKeys2(target) {
    return Object.getOwnPropertyNames(target);
  };
}
function ProcessEmitWarning(warning) {
  if (console && console.warn)
    console.warn(warning);
}
var NumberIsNaN = Number.isNaN || function NumberIsNaN2(value) {
  return value !== value;
};
function EventEmitter$1() {
  EventEmitter$1.init.call(this);
}
events.exports = EventEmitter$1;
events.exports.once = once2;
EventEmitter$1.EventEmitter = EventEmitter$1;
EventEmitter$1.prototype._events = void 0;
EventEmitter$1.prototype._eventsCount = 0;
EventEmitter$1.prototype._maxListeners = void 0;
var defaultMaxListeners = 10;
function checkListener(listener) {
  if (typeof listener !== "function") {
    throw new TypeError('The "listener" argument must be of type Function. Received type ' + typeof listener);
  }
}
Object.defineProperty(EventEmitter$1, "defaultMaxListeners", {
  enumerable: true,
  get: function() {
    return defaultMaxListeners;
  },
  set: function(arg) {
    if (typeof arg !== "number" || arg < 0 || NumberIsNaN(arg)) {
      throw new RangeError('The value of "defaultMaxListeners" is out of range. It must be a non-negative number. Received ' + arg + ".");
    }
    defaultMaxListeners = arg;
  }
});
EventEmitter$1.init = function() {
  if (this._events === void 0 || this._events === Object.getPrototypeOf(this)._events) {
    this._events = /* @__PURE__ */ Object.create(null);
    this._eventsCount = 0;
  }
  this._maxListeners = this._maxListeners || void 0;
};
EventEmitter$1.prototype.setMaxListeners = function setMaxListeners(n) {
  if (typeof n !== "number" || n < 0 || NumberIsNaN(n)) {
    throw new RangeError('The value of "n" is out of range. It must be a non-negative number. Received ' + n + ".");
  }
  this._maxListeners = n;
  return this;
};
function _getMaxListeners(that) {
  if (that._maxListeners === void 0)
    return EventEmitter$1.defaultMaxListeners;
  return that._maxListeners;
}
EventEmitter$1.prototype.getMaxListeners = function getMaxListeners() {
  return _getMaxListeners(this);
};
EventEmitter$1.prototype.emit = function emit(type) {
  var args = [];
  for (var i = 1; i < arguments.length; i++)
    args.push(arguments[i]);
  var doError = type === "error";
  var events2 = this._events;
  if (events2 !== void 0)
    doError = doError && events2.error === void 0;
  else if (!doError)
    return false;
  if (doError) {
    var er;
    if (args.length > 0)
      er = args[0];
    if (er instanceof Error) {
      throw er;
    }
    var err = new Error("Unhandled error." + (er ? " (" + er.message + ")" : ""));
    err.context = er;
    throw err;
  }
  var handler = events2[type];
  if (handler === void 0)
    return false;
  if (typeof handler === "function") {
    ReflectApply(handler, this, args);
  } else {
    var len = handler.length;
    var listeners2 = arrayClone(handler, len);
    for (var i = 0; i < len; ++i)
      ReflectApply(listeners2[i], this, args);
  }
  return true;
};
function _addListener(target, type, listener, prepend) {
  var m;
  var events2;
  var existing;
  checkListener(listener);
  events2 = target._events;
  if (events2 === void 0) {
    events2 = target._events = /* @__PURE__ */ Object.create(null);
    target._eventsCount = 0;
  } else {
    if (events2.newListener !== void 0) {
      target.emit("newListener", type, listener.listener ? listener.listener : listener);
      events2 = target._events;
    }
    existing = events2[type];
  }
  if (existing === void 0) {
    existing = events2[type] = listener;
    ++target._eventsCount;
  } else {
    if (typeof existing === "function") {
      existing = events2[type] = prepend ? [listener, existing] : [existing, listener];
    } else if (prepend) {
      existing.unshift(listener);
    } else {
      existing.push(listener);
    }
    m = _getMaxListeners(target);
    if (m > 0 && existing.length > m && !existing.warned) {
      existing.warned = true;
      var w = new Error("Possible EventEmitter memory leak detected. " + existing.length + " " + String(type) + " listeners added. Use emitter.setMaxListeners() to increase limit");
      w.name = "MaxListenersExceededWarning";
      w.emitter = target;
      w.type = type;
      w.count = existing.length;
      ProcessEmitWarning(w);
    }
  }
  return target;
}
EventEmitter$1.prototype.addListener = function addListener(type, listener) {
  return _addListener(this, type, listener, false);
};
EventEmitter$1.prototype.on = EventEmitter$1.prototype.addListener;
EventEmitter$1.prototype.prependListener = function prependListener(type, listener) {
  return _addListener(this, type, listener, true);
};
function onceWrapper() {
  if (!this.fired) {
    this.target.removeListener(this.type, this.wrapFn);
    this.fired = true;
    if (arguments.length === 0)
      return this.listener.call(this.target);
    return this.listener.apply(this.target, arguments);
  }
}
function _onceWrap(target, type, listener) {
  var state = { fired: false, wrapFn: void 0, target, type, listener };
  var wrapped = onceWrapper.bind(state);
  wrapped.listener = listener;
  state.wrapFn = wrapped;
  return wrapped;
}
EventEmitter$1.prototype.once = function once(type, listener) {
  checkListener(listener);
  this.on(type, _onceWrap(this, type, listener));
  return this;
};
EventEmitter$1.prototype.prependOnceListener = function prependOnceListener(type, listener) {
  checkListener(listener);
  this.prependListener(type, _onceWrap(this, type, listener));
  return this;
};
EventEmitter$1.prototype.removeListener = function removeListener(type, listener) {
  var list, events2, position, i, originalListener;
  checkListener(listener);
  events2 = this._events;
  if (events2 === void 0)
    return this;
  list = events2[type];
  if (list === void 0)
    return this;
  if (list === listener || list.listener === listener) {
    if (--this._eventsCount === 0)
      this._events = /* @__PURE__ */ Object.create(null);
    else {
      delete events2[type];
      if (events2.removeListener)
        this.emit("removeListener", type, list.listener || listener);
    }
  } else if (typeof list !== "function") {
    position = -1;
    for (i = list.length - 1; i >= 0; i--) {
      if (list[i] === listener || list[i].listener === listener) {
        originalListener = list[i].listener;
        position = i;
        break;
      }
    }
    if (position < 0)
      return this;
    if (position === 0)
      list.shift();
    else {
      spliceOne(list, position);
    }
    if (list.length === 1)
      events2[type] = list[0];
    if (events2.removeListener !== void 0)
      this.emit("removeListener", type, originalListener || listener);
  }
  return this;
};
EventEmitter$1.prototype.off = EventEmitter$1.prototype.removeListener;
EventEmitter$1.prototype.removeAllListeners = function removeAllListeners(type) {
  var listeners2, events2, i;
  events2 = this._events;
  if (events2 === void 0)
    return this;
  if (events2.removeListener === void 0) {
    if (arguments.length === 0) {
      this._events = /* @__PURE__ */ Object.create(null);
      this._eventsCount = 0;
    } else if (events2[type] !== void 0) {
      if (--this._eventsCount === 0)
        this._events = /* @__PURE__ */ Object.create(null);
      else
        delete events2[type];
    }
    return this;
  }
  if (arguments.length === 0) {
    var keys = Object.keys(events2);
    var key;
    for (i = 0; i < keys.length; ++i) {
      key = keys[i];
      if (key === "removeListener")
        continue;
      this.removeAllListeners(key);
    }
    this.removeAllListeners("removeListener");
    this._events = /* @__PURE__ */ Object.create(null);
    this._eventsCount = 0;
    return this;
  }
  listeners2 = events2[type];
  if (typeof listeners2 === "function") {
    this.removeListener(type, listeners2);
  } else if (listeners2 !== void 0) {
    for (i = listeners2.length - 1; i >= 0; i--) {
      this.removeListener(type, listeners2[i]);
    }
  }
  return this;
};
function _listeners(target, type, unwrap) {
  var events2 = target._events;
  if (events2 === void 0)
    return [];
  var evlistener = events2[type];
  if (evlistener === void 0)
    return [];
  if (typeof evlistener === "function")
    return unwrap ? [evlistener.listener || evlistener] : [evlistener];
  return unwrap ? unwrapListeners(evlistener) : arrayClone(evlistener, evlistener.length);
}
EventEmitter$1.prototype.listeners = function listeners(type) {
  return _listeners(this, type, true);
};
EventEmitter$1.prototype.rawListeners = function rawListeners(type) {
  return _listeners(this, type, false);
};
EventEmitter$1.listenerCount = function(emitter2, type) {
  if (typeof emitter2.listenerCount === "function") {
    return emitter2.listenerCount(type);
  } else {
    return listenerCount.call(emitter2, type);
  }
};
EventEmitter$1.prototype.listenerCount = listenerCount;
function listenerCount(type) {
  var events2 = this._events;
  if (events2 !== void 0) {
    var evlistener = events2[type];
    if (typeof evlistener === "function") {
      return 1;
    } else if (evlistener !== void 0) {
      return evlistener.length;
    }
  }
  return 0;
}
EventEmitter$1.prototype.eventNames = function eventNames() {
  return this._eventsCount > 0 ? ReflectOwnKeys(this._events) : [];
};
function arrayClone(arr, n) {
  var copy = new Array(n);
  for (var i = 0; i < n; ++i)
    copy[i] = arr[i];
  return copy;
}
function spliceOne(list, index) {
  for (; index + 1 < list.length; index++)
    list[index] = list[index + 1];
  list.pop();
}
function unwrapListeners(arr) {
  var ret = new Array(arr.length);
  for (var i = 0; i < ret.length; ++i) {
    ret[i] = arr[i].listener || arr[i];
  }
  return ret;
}
function once2(emitter2, name) {
  return new Promise(function(resolve, reject) {
    function errorListener(err) {
      emitter2.removeListener(name, resolver);
      reject(err);
    }
    function resolver() {
      if (typeof emitter2.removeListener === "function") {
        emitter2.removeListener("error", errorListener);
      }
      resolve([].slice.call(arguments));
    }
    eventTargetAgnosticAddListener(emitter2, name, resolver, { once: true });
    if (name !== "error") {
      addErrorHandlerIfEventEmitter(emitter2, errorListener, { once: true });
    }
  });
}
function addErrorHandlerIfEventEmitter(emitter2, handler, flags) {
  if (typeof emitter2.on === "function") {
    eventTargetAgnosticAddListener(emitter2, "error", handler, flags);
  }
}
function eventTargetAgnosticAddListener(emitter2, name, listener, flags) {
  if (typeof emitter2.on === "function") {
    if (flags.once) {
      emitter2.once(name, listener);
    } else {
      emitter2.on(name, listener);
    }
  } else if (typeof emitter2.addEventListener === "function") {
    emitter2.addEventListener(name, function wrapListener(arg) {
      if (flags.once) {
        emitter2.removeEventListener(name, wrapListener);
      }
      listener(arg);
    });
  } else {
    throw new TypeError('The "emitter" argument must be of type EventEmitter. Received type ' + typeof emitter2);
  }
}
var EventEmitter = events.exports.EventEmitter;
emitter$6.EventEmitter = EventEmitter;
emitter$6.mixin = mixin;
function mixin(Constructor) {
  for (var key in EventEmitter.prototype) {
    Constructor.prototype[key] = EventEmitter.prototype[key];
  }
}
var SUPPORTED_METHODS = [
  "info",
  "warn",
  "error"
];
function Logger$1() {
  var defaultMethods = {};
  SUPPORTED_METHODS.forEach(function(method) {
    defaultMethods[method] = console[method].bind(console);
  });
  this.setMethods(defaultMethods);
}
var logger$3 = Logger$1;
Logger$1.prototype.setMethods = function(overrides) {
  overrides = overrides || {};
  var logger2 = this;
  SUPPORTED_METHODS.forEach(function(method) {
    if (typeof overrides[method] === "function") {
      logger2[method] = overrides[method];
    }
  });
};
var Logger = logger$3;
var logger$2 = new Logger();
var logger_1 = logger$2;
function ShareDBError$3(code, message) {
  this.code = code;
  this.message = message || "";
  if (Error.captureStackTrace) {
    Error.captureStackTrace(this, ShareDBError$3);
  } else {
    this.stack = new Error().stack;
  }
}
ShareDBError$3.prototype = Object.create(Error.prototype);
ShareDBError$3.prototype.constructor = ShareDBError$3;
ShareDBError$3.prototype.name = "ShareDBError";
ShareDBError$3.CODES = {
  ERR_APPLY_OP_VERSION_DOES_NOT_MATCH_SNAPSHOT: "ERR_APPLY_OP_VERSION_DOES_NOT_MATCH_SNAPSHOT",
  ERR_APPLY_SNAPSHOT_NOT_PROVIDED: "ERR_APPLY_SNAPSHOT_NOT_PROVIDED",
  ERR_CLIENT_ID_BADLY_FORMED: "ERR_CLIENT_ID_BADLY_FORMED",
  ERR_CONNECTION_SEQ_INTEGER_OVERFLOW: "ERR_CONNECTION_SEQ_INTEGER_OVERFLOW",
  ERR_CONNECTION_STATE_TRANSITION_INVALID: "ERR_CONNECTION_STATE_TRANSITION_INVALID",
  ERR_DATABASE_ADAPTER_NOT_FOUND: "ERR_DATABASE_ADAPTER_NOT_FOUND",
  ERR_DATABASE_DOES_NOT_SUPPORT_SUBSCRIBE: "ERR_DATABASE_DOES_NOT_SUPPORT_SUBSCRIBE",
  ERR_DATABASE_METHOD_NOT_IMPLEMENTED: "ERR_DATABASE_METHOD_NOT_IMPLEMENTED",
  ERR_DEFAULT_TYPE_MISMATCH: "ERR_DEFAULT_TYPE_MISMATCH",
  ERR_DOC_MISSING_VERSION: "ERR_DOC_MISSING_VERSION",
  ERR_DOC_ALREADY_CREATED: "ERR_DOC_ALREADY_CREATED",
  ERR_DOC_DOES_NOT_EXIST: "ERR_DOC_DOES_NOT_EXIST",
  ERR_DOC_TYPE_NOT_RECOGNIZED: "ERR_DOC_TYPE_NOT_RECOGNIZED",
  ERR_DOC_WAS_DELETED: "ERR_DOC_WAS_DELETED",
  ERR_INFLIGHT_OP_MISSING: "ERR_INFLIGHT_OP_MISSING",
  ERR_INGESTED_SNAPSHOT_HAS_NO_VERSION: "ERR_INGESTED_SNAPSHOT_HAS_NO_VERSION",
  ERR_MAX_SUBMIT_RETRIES_EXCEEDED: "ERR_MAX_SUBMIT_RETRIES_EXCEEDED",
  ERR_MESSAGE_BADLY_FORMED: "ERR_MESSAGE_BADLY_FORMED",
  ERR_MILESTONE_ARGUMENT_INVALID: "ERR_MILESTONE_ARGUMENT_INVALID",
  ERR_OP_ALREADY_SUBMITTED: "ERR_OP_ALREADY_SUBMITTED",
  ERR_OP_NOT_ALLOWED_IN_PROJECTION: "ERR_OP_NOT_ALLOWED_IN_PROJECTION",
  ERR_OP_SUBMIT_REJECTED: "ERR_OP_SUBMIT_REJECTED",
  ERR_OP_VERSION_MISMATCH_AFTER_TRANSFORM: "ERR_OP_VERSION_MISMATCH_AFTER_TRANSFORM",
  ERR_OP_VERSION_MISMATCH_DURING_TRANSFORM: "ERR_OP_VERSION_MISMATCH_DURING_TRANSFORM",
  ERR_OP_VERSION_NEWER_THAN_CURRENT_SNAPSHOT: "ERR_OP_VERSION_NEWER_THAN_CURRENT_SNAPSHOT",
  ERR_OT_LEGACY_JSON0_OP_CANNOT_BE_NORMALIZED: "ERR_OT_LEGACY_JSON0_OP_CANNOT_BE_NORMALIZED",
  ERR_OT_OP_BADLY_FORMED: "ERR_OT_OP_BADLY_FORMED",
  ERR_OT_OP_NOT_APPLIED: "ERR_OT_OP_NOT_APPLIED",
  ERR_OT_OP_NOT_PROVIDED: "ERR_OT_OP_NOT_PROVIDED",
  ERR_PRESENCE_TRANSFORM_FAILED: "ERR_PRESENCE_TRANSFORM_FAILED",
  ERR_PROTOCOL_VERSION_NOT_SUPPORTED: "ERR_PROTOCOL_VERSION_NOT_SUPPORTED",
  ERR_QUERY_EMITTER_LISTENER_NOT_ASSIGNED: "ERR_QUERY_EMITTER_LISTENER_NOT_ASSIGNED",
  ERR_SNAPSHOT_READ_SILENT_REJECTION: "ERR_SNAPSHOT_READ_SILENT_REJECTION",
  ERR_SNAPSHOT_READS_REJECTED: "ERR_SNAPSHOT_READS_REJECTED",
  ERR_SUBMIT_TRANSFORM_OPS_NOT_FOUND: "ERR_SUBMIT_TRANSFORM_OPS_NOT_FOUND",
  ERR_TYPE_CANNOT_BE_PROJECTED: "ERR_TYPE_CANNOT_BE_PROJECTED",
  ERR_TYPE_DOES_NOT_SUPPORT_PRESENCE: "ERR_TYPE_DOES_NOT_SUPPORT_PRESENCE",
  ERR_UNKNOWN_ERROR: "ERR_UNKNOWN_ERROR"
};
var error = ShareDBError$3;
var types$3 = {};
var bootstrapTransform_1 = bootstrapTransform;
function bootstrapTransform(type, transformComponent2, checkValidOp2, append2) {
  var transformComponentX = function(left, right, destLeft, destRight) {
    transformComponent2(destLeft, left, right, "left");
    transformComponent2(destRight, right, left, "right");
  };
  var transformX2 = type.transformX = function(leftOp, rightOp) {
    checkValidOp2(leftOp);
    checkValidOp2(rightOp);
    var newRightOp = [];
    for (var i = 0; i < rightOp.length; i++) {
      var rightComponent = rightOp[i];
      var newLeftOp = [];
      var k = 0;
      while (k < leftOp.length) {
        var nextC = [];
        transformComponentX(leftOp[k], rightComponent, newLeftOp, nextC);
        k++;
        if (nextC.length === 1) {
          rightComponent = nextC[0];
        } else if (nextC.length === 0) {
          for (var j = k; j < leftOp.length; j++) {
            append2(newLeftOp, leftOp[j]);
          }
          rightComponent = null;
          break;
        } else {
          var pair = transformX2(leftOp.slice(k), nextC);
          for (var l = 0; l < pair[0].length; l++) {
            append2(newLeftOp, pair[0][l]);
          }
          for (var r = 0; r < pair[1].length; r++) {
            append2(newRightOp, pair[1][r]);
          }
          rightComponent = null;
          break;
        }
      }
      if (rightComponent != null) {
        append2(newRightOp, rightComponent);
      }
      leftOp = newLeftOp;
    }
    return [leftOp, newRightOp];
  };
  type.transform = function(op, otherOp, type2) {
    if (!(type2 === "left" || type2 === "right"))
      throw new Error("type must be 'left' or 'right'");
    if (otherOp.length === 0)
      return op;
    if (op.length === 1 && otherOp.length === 1)
      return transformComponent2([], op[0], otherOp[0], type2);
    if (type2 === "left")
      return transformX2(op, otherOp)[0];
    else
      return transformX2(otherOp, op)[1];
  };
}
var text0 = { exports: {} };
var text$1 = text0.exports = {
  name: "text0",
  uri: "http://sharejs.org/types/textv0",
  create: function(initial) {
    if (initial != null && typeof initial !== "string") {
      throw new Error("Initial data must be a string");
    }
    return initial || "";
  }
};
var strInject = function(s1, pos, s2) {
  return s1.slice(0, pos) + s2 + s1.slice(pos);
};
var checkValidComponent = function(c) {
  if (typeof c.p !== "number")
    throw new Error("component missing position field");
  if (typeof c.i === "string" === (typeof c.d === "string"))
    throw new Error("component needs an i or d field");
  if (c.p < 0)
    throw new Error("position cannot be negative");
};
var checkValidOp = function(op) {
  for (var i = 0; i < op.length; i++) {
    checkValidComponent(op[i]);
  }
};
text$1.apply = function(snapshot2, op) {
  var deleted;
  checkValidOp(op);
  for (var i = 0; i < op.length; i++) {
    var component = op[i];
    if (component.i != null) {
      snapshot2 = strInject(snapshot2, component.p, component.i);
    } else {
      deleted = snapshot2.slice(component.p, component.p + component.d.length);
      if (component.d !== deleted)
        throw new Error("Delete component '" + component.d + "' does not match deleted text '" + deleted + "'");
      snapshot2 = snapshot2.slice(0, component.p) + snapshot2.slice(component.p + component.d.length);
    }
  }
  return snapshot2;
};
var append = text$1._append = function(newOp, c) {
  if (c.i === "" || c.d === "")
    return;
  if (newOp.length === 0) {
    newOp.push(c);
  } else {
    var last = newOp[newOp.length - 1];
    if (last.i != null && c.i != null && last.p <= c.p && c.p <= last.p + last.i.length) {
      newOp[newOp.length - 1] = { i: strInject(last.i, c.p - last.p, c.i), p: last.p };
    } else if (last.d != null && c.d != null && c.p <= last.p && last.p <= c.p + c.d.length) {
      newOp[newOp.length - 1] = { d: strInject(c.d, last.p - c.p, last.d), p: c.p };
    } else {
      newOp.push(c);
    }
  }
};
text$1.compose = function(op1, op2) {
  checkValidOp(op1);
  checkValidOp(op2);
  var newOp = op1.slice();
  for (var i = 0; i < op2.length; i++) {
    append(newOp, op2[i]);
  }
  return newOp;
};
text$1.normalize = function(op) {
  var newOp = [];
  if (op.i != null || op.p != null)
    op = [op];
  for (var i = 0; i < op.length; i++) {
    var c = op[i];
    if (c.p == null)
      c.p = 0;
    append(newOp, c);
  }
  return newOp;
};
var transformPosition = function(pos, c, insertAfter) {
  if (c.i != null) {
    if (c.p < pos || c.p === pos && insertAfter) {
      return pos + c.i.length;
    } else {
      return pos;
    }
  } else {
    if (pos <= c.p) {
      return pos;
    } else if (pos <= c.p + c.d.length) {
      return c.p;
    } else {
      return pos - c.d.length;
    }
  }
};
text$1.transformCursor = function(position, op, side) {
  var insertAfter = side === "right";
  for (var i = 0; i < op.length; i++) {
    position = transformPosition(position, op[i], insertAfter);
  }
  return position;
};
var transformComponent = text$1._tc = function(dest, c, otherC, side) {
  checkValidComponent(c);
  checkValidComponent(otherC);
  if (c.i != null) {
    append(dest, { i: c.i, p: transformPosition(c.p, otherC, side === "right") });
  } else {
    if (otherC.i != null) {
      var s = c.d;
      if (c.p < otherC.p) {
        append(dest, { d: s.slice(0, otherC.p - c.p), p: c.p });
        s = s.slice(otherC.p - c.p);
      }
      if (s !== "")
        append(dest, { d: s, p: c.p + otherC.i.length });
    } else {
      if (c.p >= otherC.p + otherC.d.length)
        append(dest, { d: c.d, p: c.p - otherC.d.length });
      else if (c.p + c.d.length <= otherC.p)
        append(dest, c);
      else {
        var newC = { d: "", p: c.p };
        if (c.p < otherC.p)
          newC.d = c.d.slice(0, otherC.p - c.p);
        if (c.p + c.d.length > otherC.p + otherC.d.length)
          newC.d += c.d.slice(otherC.p + otherC.d.length - c.p);
        var intersectStart = Math.max(c.p, otherC.p);
        var intersectEnd = Math.min(c.p + c.d.length, otherC.p + otherC.d.length);
        var cIntersect = c.d.slice(intersectStart - c.p, intersectEnd - c.p);
        var otherIntersect = otherC.d.slice(intersectStart - otherC.p, intersectEnd - otherC.p);
        if (cIntersect !== otherIntersect)
          throw new Error("Delete ops delete different text in the same region of the document");
        if (newC.d !== "") {
          newC.p = transformPosition(newC.p, otherC);
          append(dest, newC);
        }
      }
    }
  }
  return dest;
};
var invertComponent = function(c) {
  return c.i != null ? { d: c.i, p: c.p } : { i: c.d, p: c.p };
};
text$1.invert = function(op) {
  op = op.slice().reverse();
  for (var i = 0; i < op.length; i++) {
    op[i] = invertComponent(op[i]);
  }
  return op;
};
bootstrapTransform_1(text$1, transformComponent, checkValidOp, append);
var isArray$1 = function(obj) {
  return Object.prototype.toString.call(obj) == "[object Array]";
};
var isObject$1 = function(obj) {
  return !!obj && obj.constructor === Object;
};
var clone$1 = function(o) {
  return JSON.parse(JSON.stringify(o));
};
var json = {
  name: "json0",
  uri: "http://sharejs.org/types/JSONv0"
};
var subtypes = {};
json.registerSubtype = function(subtype) {
  subtypes[subtype.name] = subtype;
};
json.create = function(data) {
  return data === void 0 ? null : clone$1(data);
};
json.invertComponent = function(c) {
  var c_ = { p: c.p };
  if (c.t && subtypes[c.t]) {
    c_.t = c.t;
    c_.o = subtypes[c.t].invert(c.o);
  }
  if (c.si !== void 0)
    c_.sd = c.si;
  if (c.sd !== void 0)
    c_.si = c.sd;
  if (c.oi !== void 0)
    c_.od = c.oi;
  if (c.od !== void 0)
    c_.oi = c.od;
  if (c.li !== void 0)
    c_.ld = c.li;
  if (c.ld !== void 0)
    c_.li = c.ld;
  if (c.na !== void 0)
    c_.na = -c.na;
  if (c.lm !== void 0) {
    c_.lm = c.p[c.p.length - 1];
    c_.p = c.p.slice(0, c.p.length - 1).concat([c.lm]);
  }
  return c_;
};
json.invert = function(op) {
  var op_ = op.slice().reverse();
  var iop = [];
  for (var i = 0; i < op_.length; i++) {
    iop.push(json.invertComponent(op_[i]));
  }
  return iop;
};
json.checkValidOp = function(op) {
  for (var i = 0; i < op.length; i++) {
    if (!isArray$1(op[i].p))
      throw new Error("Missing path");
  }
};
json.checkList = function(elem) {
  if (!isArray$1(elem))
    throw new Error("Referenced element not a list");
};
json.checkObj = function(elem) {
  if (!isObject$1(elem)) {
    throw new Error("Referenced element not an object (it was " + JSON.stringify(elem) + ")");
  }
};
function convertFromText(c) {
  c.t = "text0";
  var o = { p: c.p.pop() };
  if (c.si != null)
    o.i = c.si;
  if (c.sd != null)
    o.d = c.sd;
  c.o = [o];
}
function convertToText(c) {
  c.p.push(c.o[0].p);
  if (c.o[0].i != null)
    c.si = c.o[0].i;
  if (c.o[0].d != null)
    c.sd = c.o[0].d;
  delete c.t;
  delete c.o;
}
json.apply = function(snapshot2, op) {
  json.checkValidOp(op);
  op = clone$1(op);
  var container = {
    data: snapshot2
  };
  for (var i = 0; i < op.length; i++) {
    var c = op[i];
    if (c.si != null || c.sd != null)
      convertFromText(c);
    var parent = null;
    var elem = container;
    var key = "data";
    for (var j = 0; j < c.p.length; j++) {
      var p = c.p[j];
      parent = elem;
      elem = elem[key];
      key = p;
      if (parent == null)
        throw new Error("Path invalid");
    }
    if (c.t && c.o !== void 0 && subtypes[c.t]) {
      elem[key] = subtypes[c.t].apply(elem[key], c.o);
    } else if (c.na !== void 0) {
      if (typeof elem[key] != "number")
        throw new Error("Referenced element not a number");
      elem[key] += c.na;
    } else if (c.li !== void 0 && c.ld !== void 0) {
      json.checkList(elem);
      elem[key] = c.li;
    } else if (c.li !== void 0) {
      json.checkList(elem);
      elem.splice(key, 0, c.li);
    } else if (c.ld !== void 0) {
      json.checkList(elem);
      elem.splice(key, 1);
    } else if (c.lm !== void 0) {
      json.checkList(elem);
      if (c.lm != key) {
        var e = elem[key];
        elem.splice(key, 1);
        elem.splice(c.lm, 0, e);
      }
    } else if (c.oi !== void 0) {
      json.checkObj(elem);
      elem[key] = c.oi;
    } else if (c.od !== void 0) {
      json.checkObj(elem);
      delete elem[key];
    } else {
      throw new Error("invalid / missing instruction in op");
    }
  }
  return container.data;
};
json.shatter = function(op) {
  var results = [];
  for (var i = 0; i < op.length; i++) {
    results.push([op[i]]);
  }
  return results;
};
json.incrementalApply = function(snapshot2, op, _yield) {
  for (var i = 0; i < op.length; i++) {
    var smallOp = [op[i]];
    snapshot2 = json.apply(snapshot2, smallOp);
    _yield(smallOp, snapshot2);
  }
  return snapshot2;
};
var pathMatches = json.pathMatches = function(p1, p2, ignoreLast) {
  if (p1.length != p2.length)
    return false;
  for (var i = 0; i < p1.length; i++) {
    if (p1[i] !== p2[i] && (!ignoreLast || i !== p1.length - 1))
      return false;
  }
  return true;
};
json.append = function(dest, c) {
  c = clone$1(c);
  if (dest.length === 0) {
    dest.push(c);
    return;
  }
  var last = dest[dest.length - 1];
  if ((c.si != null || c.sd != null) && (last.si != null || last.sd != null)) {
    convertFromText(c);
    convertFromText(last);
  }
  if (pathMatches(c.p, last.p)) {
    if (c.t && last.t && c.t === last.t && subtypes[c.t]) {
      last.o = subtypes[c.t].compose(last.o, c.o);
      if (c.si != null || c.sd != null) {
        var p = c.p;
        for (var i = 0; i < last.o.length - 1; i++) {
          c.o = [last.o.pop()];
          c.p = p.slice();
          convertToText(c);
          dest.push(c);
        }
        convertToText(last);
      }
    } else if (last.na != null && c.na != null) {
      dest[dest.length - 1] = { p: last.p, na: last.na + c.na };
    } else if (last.li !== void 0 && c.li === void 0 && c.ld === last.li) {
      if (last.ld !== void 0) {
        delete last.li;
      } else {
        dest.pop();
      }
    } else if (last.od !== void 0 && last.oi === void 0 && c.oi !== void 0 && c.od === void 0) {
      last.oi = c.oi;
    } else if (last.oi !== void 0 && c.od !== void 0) {
      if (c.oi !== void 0) {
        last.oi = c.oi;
      } else if (last.od !== void 0) {
        delete last.oi;
      } else {
        dest.pop();
      }
    } else if (c.lm !== void 0 && c.p[c.p.length - 1] === c.lm)
      ;
    else {
      dest.push(c);
    }
  } else {
    if ((c.si != null || c.sd != null) && (last.si != null || last.sd != null)) {
      convertToText(c);
      convertToText(last);
    }
    dest.push(c);
  }
};
json.compose = function(op1, op2) {
  json.checkValidOp(op1);
  json.checkValidOp(op2);
  var newOp = clone$1(op1);
  for (var i = 0; i < op2.length; i++) {
    json.append(newOp, op2[i]);
  }
  return newOp;
};
json.normalize = function(op) {
  var newOp = [];
  op = isArray$1(op) ? op : [op];
  for (var i = 0; i < op.length; i++) {
    var c = op[i];
    if (c.p == null)
      c.p = [];
    json.append(newOp, c);
  }
  return newOp;
};
json.commonLengthForOps = function(a, b) {
  var alen = a.p.length;
  var blen = b.p.length;
  if (a.na != null || a.t)
    alen++;
  if (b.na != null || b.t)
    blen++;
  if (alen === 0)
    return -1;
  if (blen === 0)
    return null;
  alen--;
  blen--;
  for (var i = 0; i < alen; i++) {
    var p = a.p[i];
    if (i >= blen || p !== b.p[i])
      return null;
  }
  return alen;
};
json.canOpAffectPath = function(op, path) {
  return json.commonLengthForOps({ p: path }, op) != null;
};
json.transformComponent = function(dest, c, otherC, type) {
  c = clone$1(c);
  var common = json.commonLengthForOps(otherC, c);
  var common2 = json.commonLengthForOps(c, otherC);
  var cplength = c.p.length;
  var otherCplength = otherC.p.length;
  if (c.na != null || c.t)
    cplength++;
  if (otherC.na != null || otherC.t)
    otherCplength++;
  if (common2 != null && otherCplength > cplength && c.p[common2] == otherC.p[common2]) {
    if (c.ld !== void 0) {
      var oc = clone$1(otherC);
      oc.p = oc.p.slice(cplength);
      c.ld = json.apply(clone$1(c.ld), [oc]);
    } else if (c.od !== void 0) {
      var oc = clone$1(otherC);
      oc.p = oc.p.slice(cplength);
      c.od = json.apply(clone$1(c.od), [oc]);
    }
  }
  if (common != null) {
    var commonOperand = cplength == otherCplength;
    var oc = otherC;
    if ((c.si != null || c.sd != null) && (otherC.si != null || otherC.sd != null)) {
      convertFromText(c);
      oc = clone$1(otherC);
      convertFromText(oc);
    }
    if (oc.t && subtypes[oc.t]) {
      if (c.t && c.t === oc.t) {
        var res = subtypes[c.t].transform(c.o, oc.o, type);
        if (c.si != null || c.sd != null) {
          var p = c.p;
          for (var i = 0; i < res.length; i++) {
            c.o = [res[i]];
            c.p = p.slice();
            convertToText(c);
            json.append(dest, c);
          }
        } else if (!isArray$1(res) || res.length > 0) {
          c.o = res;
          json.append(dest, c);
        }
        return dest;
      }
    } else if (otherC.na !== void 0)
      ;
    else if (otherC.li !== void 0 && otherC.ld !== void 0) {
      if (otherC.p[common] === c.p[common]) {
        if (!commonOperand) {
          return dest;
        } else if (c.ld !== void 0) {
          if (c.li !== void 0 && type === "left") {
            c.ld = clone$1(otherC.li);
          } else {
            return dest;
          }
        }
      }
    } else if (otherC.li !== void 0) {
      if (c.li !== void 0 && c.ld === void 0 && commonOperand && c.p[common] === otherC.p[common]) {
        if (type === "right")
          c.p[common]++;
      } else if (otherC.p[common] <= c.p[common]) {
        c.p[common]++;
      }
      if (c.lm !== void 0) {
        if (commonOperand) {
          if (otherC.p[common] <= c.lm)
            c.lm++;
        }
      }
    } else if (otherC.ld !== void 0) {
      if (c.lm !== void 0) {
        if (commonOperand) {
          if (otherC.p[common] === c.p[common]) {
            return dest;
          }
          var p = otherC.p[common];
          var from = c.p[common];
          var to = c.lm;
          if (p < to || p === to && from < to)
            c.lm--;
        }
      }
      if (otherC.p[common] < c.p[common]) {
        c.p[common]--;
      } else if (otherC.p[common] === c.p[common]) {
        if (otherCplength < cplength) {
          return dest;
        } else if (c.ld !== void 0) {
          if (c.li !== void 0) {
            delete c.ld;
          } else {
            return dest;
          }
        }
      }
    } else if (otherC.lm !== void 0) {
      if (c.lm !== void 0 && cplength === otherCplength) {
        var from = c.p[common];
        var to = c.lm;
        var otherFrom = otherC.p[common];
        var otherTo = otherC.lm;
        if (otherFrom !== otherTo) {
          if (from === otherFrom) {
            if (type === "left") {
              c.p[common] = otherTo;
              if (from === to)
                c.lm = otherTo;
            } else {
              return dest;
            }
          } else {
            if (from > otherFrom)
              c.p[common]--;
            if (from > otherTo)
              c.p[common]++;
            else if (from === otherTo) {
              if (otherFrom > otherTo) {
                c.p[common]++;
                if (from === to)
                  c.lm++;
              }
            }
            if (to > otherFrom) {
              c.lm--;
            } else if (to === otherFrom) {
              if (to > from)
                c.lm--;
            }
            if (to > otherTo) {
              c.lm++;
            } else if (to === otherTo) {
              if (otherTo > otherFrom && to > from || otherTo < otherFrom && to < from) {
                if (type === "right")
                  c.lm++;
              } else {
                if (to > from)
                  c.lm++;
                else if (to === otherFrom)
                  c.lm--;
              }
            }
          }
        }
      } else if (c.li !== void 0 && c.ld === void 0 && commonOperand) {
        var from = otherC.p[common];
        var to = otherC.lm;
        p = c.p[common];
        if (p > from)
          c.p[common]--;
        if (p > to)
          c.p[common]++;
      } else {
        var from = otherC.p[common];
        var to = otherC.lm;
        p = c.p[common];
        if (p === from) {
          c.p[common] = to;
        } else {
          if (p > from)
            c.p[common]--;
          if (p > to)
            c.p[common]++;
          else if (p === to && from > to)
            c.p[common]++;
        }
      }
    } else if (otherC.oi !== void 0 && otherC.od !== void 0) {
      if (c.p[common] === otherC.p[common]) {
        if (c.oi !== void 0 && commonOperand) {
          if (type === "right") {
            return dest;
          } else {
            c.od = otherC.oi;
          }
        } else {
          return dest;
        }
      }
    } else if (otherC.oi !== void 0) {
      if (c.oi !== void 0 && c.p[common] === otherC.p[common]) {
        if (type === "left") {
          json.append(dest, { p: c.p, od: otherC.oi });
        } else {
          return dest;
        }
      }
    } else if (otherC.od !== void 0) {
      if (c.p[common] == otherC.p[common]) {
        if (!commonOperand)
          return dest;
        if (c.oi !== void 0) {
          delete c.od;
        } else {
          return dest;
        }
      }
    }
  }
  json.append(dest, c);
  return dest;
};
bootstrapTransform_1(json, json.transformComponent, json.checkValidOp, json.append);
var text = text0.exports;
json.registerSubtype(text);
var json0 = json;
var lib = {
  type: json0
};
(function(exports) {
  exports.defaultType = lib.type;
  exports.map = {};
  exports.register = function(type) {
    if (type.name)
      exports.map[type.name] = type;
    if (type.uri)
      exports.map[type.uri] = type;
  };
  exports.register(exports.defaultType);
})(types$3);
var util$9 = {};
(function(exports) {
  exports.doNothing = doNothing;
  function doNothing() {
  }
  exports.hasKeys = function(object) {
    for (var key in object)
      return true;
    return false;
  };
  exports.isInteger = Number.isInteger || function(value) {
    return typeof value === "number" && isFinite(value) && Math.floor(value) === value;
  };
  exports.isValidVersion = function(version) {
    if (version === null)
      return true;
    return exports.isInteger(version) && version >= 0;
  };
  exports.isValidTimestamp = function(timestamp) {
    return exports.isValidVersion(timestamp);
  };
  exports.MAX_SAFE_INTEGER = 9007199254740991;
  exports.dig = function() {
    var obj = arguments[0];
    for (var i = 1; i < arguments.length; i++) {
      var key = arguments[i];
      obj = obj[key] || (i === arguments.length - 1 ? void 0 : {});
    }
    return obj;
  };
  exports.digOrCreate = function() {
    var obj = arguments[0];
    var createCallback = arguments[arguments.length - 1];
    for (var i = 1; i < arguments.length - 1; i++) {
      var key = arguments[i];
      obj = obj[key] || (obj[key] = i === arguments.length - 2 ? createCallback() : {});
    }
    return obj;
  };
  exports.digAndRemove = function() {
    var obj = arguments[0];
    var objects = [obj];
    for (var i = 1; i < arguments.length - 1; i++) {
      var key = arguments[i];
      if (!obj.hasOwnProperty(key))
        break;
      obj = obj[key];
      objects.push(obj);
    }
    for (var i = objects.length - 1; i >= 0; i--) {
      var parent = objects[i];
      var key = arguments[i + 1];
      var child = parent[key];
      if (i === objects.length - 1 || !exports.hasKeys(child))
        delete parent[key];
    }
  };
  exports.supportsPresence = function(type) {
    return type && typeof type.transformPresence === "function";
  };
  exports.callEach = function(callbacks, error2) {
    var called = false;
    callbacks.forEach(function(callback) {
      if (callback) {
        callback(error2);
        called = true;
      }
    });
    return called;
  };
  exports.truthy = function(arg) {
    return !!arg;
  };
  exports.nextTick = function(callback) {
    if (typeof process !== "undefined" && process.nextTick) {
      return process.nextTick.apply(null, arguments);
    }
    var args = [];
    for (var i = 1; i < arguments.length; i++) {
      args[i - 1] = arguments[i];
    }
    setTimeout(function() {
      callback.apply(null, args);
    });
  };
  exports.clone = function(obj) {
    return obj === void 0 ? void 0 : JSON.parse(JSON.stringify(obj));
  };
})(util$9);
var isArray = Array.isArray;
var keyList = Object.keys;
var hasProp = Object.prototype.hasOwnProperty;
var fastDeepEqual = function equal(a, b) {
  if (a === b)
    return true;
  if (a && b && typeof a == "object" && typeof b == "object") {
    var arrA = isArray(a), arrB = isArray(b), i, length, key;
    if (arrA && arrB) {
      length = a.length;
      if (length != b.length)
        return false;
      for (i = length; i-- !== 0; )
        if (!equal(a[i], b[i]))
          return false;
      return true;
    }
    if (arrA != arrB)
      return false;
    var dateA = a instanceof Date, dateB = b instanceof Date;
    if (dateA != dateB)
      return false;
    if (dateA && dateB)
      return a.getTime() == b.getTime();
    var regexpA = a instanceof RegExp, regexpB = b instanceof RegExp;
    if (regexpA != regexpB)
      return false;
    if (regexpA && regexpB)
      return a.toString() == b.toString();
    var keys = keyList(a);
    length = keys.length;
    if (length !== keyList(b).length)
      return false;
    for (i = length; i-- !== 0; )
      if (!hasProp.call(b, keys[i]))
        return false;
    for (i = length; i-- !== 0; ) {
      key = keys[i];
      if (!equal(a[key], b[key]))
        return false;
    }
    return true;
  }
  return a !== a && b !== b;
};
var emitter$5 = emitter$6;
var logger$1 = logger_1;
var ShareDBError$2 = error;
var types$2 = types$3;
var util$8 = util$9;
var clone = util$8.clone;
var deepEqual = fastDeepEqual;
var ERROR_CODE$2 = ShareDBError$2.CODES;
var doc = Doc$1;
function Doc$1(connection2, collection, id) {
  emitter$5.EventEmitter.call(this);
  this.connection = connection2;
  this.collection = collection;
  this.id = id;
  this.version = null;
  this.type = null;
  this.data = void 0;
  this.inflightFetch = [];
  this.inflightSubscribe = null;
  this.pendingFetch = [];
  this.pendingSubscribe = [];
  this.subscribed = false;
  this.wantSubscribe = false;
  this.inflightOp = null;
  this.pendingOps = [];
  this.type = null;
  this.applyStack = null;
  this.preventCompose = false;
  this.submitSource = false;
  this.paused = false;
  this._dataStateVersion = 0;
}
emitter$5.mixin(Doc$1);
Doc$1.prototype.destroy = function(callback) {
  var doc2 = this;
  doc2.whenNothingPending(function() {
    if (doc2.wantSubscribe) {
      doc2.unsubscribe(function(err) {
        if (err) {
          if (callback)
            return callback(err);
          return doc2.emit("error", err);
        }
        doc2.connection._destroyDoc(doc2);
        doc2.emit("destroy");
        if (callback)
          callback();
      });
    } else {
      doc2.connection._destroyDoc(doc2);
      doc2.emit("destroy");
      if (callback)
        callback();
    }
  });
};
Doc$1.prototype._setType = function(newType) {
  if (typeof newType === "string") {
    newType = types$2.map[newType];
  }
  if (newType) {
    this.type = newType;
  } else if (newType === null) {
    this.type = newType;
    this._setData(void 0);
  } else {
    var err = new ShareDBError$2(ERROR_CODE$2.ERR_DOC_TYPE_NOT_RECOGNIZED, "Missing type " + newType);
    return this.emit("error", err);
  }
};
Doc$1.prototype._setData = function(data) {
  this.data = data;
  this._dataStateVersion++;
};
Doc$1.prototype.ingestSnapshot = function(snapshot2, callback) {
  if (!snapshot2)
    return callback && callback();
  if (typeof snapshot2.v !== "number") {
    var err = new ShareDBError$2(ERROR_CODE$2.ERR_INGESTED_SNAPSHOT_HAS_NO_VERSION, "Missing version in ingested snapshot. " + this.collection + "." + this.id);
    if (callback)
      return callback(err);
    return this.emit("error", err);
  }
  if (this.type || this.hasWritePending()) {
    if (this.version == null) {
      if (this.hasWritePending()) {
        return callback && this.once("no write pending", callback);
      }
      var err = new ShareDBError$2(ERROR_CODE$2.ERR_DOC_MISSING_VERSION, "Cannot ingest snapshot in doc with null version. " + this.collection + "." + this.id);
      if (callback)
        return callback(err);
      return this.emit("error", err);
    }
    if (snapshot2.v > this.version)
      return this.fetch(callback);
    return callback && callback();
  }
  if (this.version > snapshot2.v)
    return callback && callback();
  this.version = snapshot2.v;
  var type = snapshot2.type === void 0 ? types$2.defaultType : snapshot2.type;
  this._setType(type);
  this._setData(this.type && this.type.deserialize ? this.type.deserialize(snapshot2.data) : snapshot2.data);
  this.emit("load");
  callback && callback();
};
Doc$1.prototype.whenNothingPending = function(callback) {
  var doc2 = this;
  util$8.nextTick(function() {
    if (doc2.hasPending()) {
      doc2.once("nothing pending", callback);
      return;
    }
    callback();
  });
};
Doc$1.prototype.hasPending = function() {
  return !!(this.inflightOp || this.pendingOps.length || this.inflightFetch.length || this.inflightSubscribe || this.pendingFetch.length || this.pendingSubscribe.length);
};
Doc$1.prototype.hasWritePending = function() {
  return !!(this.inflightOp || this.pendingOps.length);
};
Doc$1.prototype._emitNothingPending = function() {
  if (this.hasWritePending())
    return;
  this.emit("no write pending");
  if (this.hasPending())
    return;
  this.emit("nothing pending");
};
Doc$1.prototype._emitResponseError = function(err, callback) {
  if (err && err.code === ERROR_CODE$2.ERR_SNAPSHOT_READ_SILENT_REJECTION) {
    this.wantSubscribe = false;
    if (callback) {
      callback();
    }
    this._emitNothingPending();
    return;
  }
  if (callback) {
    callback(err);
    this._emitNothingPending();
    return;
  }
  this._emitNothingPending();
  this.emit("error", err);
};
Doc$1.prototype._handleFetch = function(error2, snapshot2) {
  var callbacks = this.pendingFetch;
  this.pendingFetch = [];
  var callback = this.inflightFetch.shift();
  if (callback)
    callbacks.push(callback);
  if (callbacks.length) {
    callback = function(error3) {
      util$8.callEach(callbacks, error3);
    };
  }
  if (error2)
    return this._emitResponseError(error2, callback);
  this.ingestSnapshot(snapshot2, callback);
  this._emitNothingPending();
};
Doc$1.prototype._handleSubscribe = function(error2, snapshot2) {
  var request = this.inflightSubscribe;
  this.inflightSubscribe = null;
  var callbacks = this.pendingFetch;
  this.pendingFetch = [];
  if (request.callback)
    callbacks.push(request.callback);
  var callback;
  if (callbacks.length) {
    callback = function(error3) {
      util$8.callEach(callbacks, error3);
    };
  }
  if (error2)
    return this._emitResponseError(error2, callback);
  this.subscribed = request.wantSubscribe;
  if (this.subscribed)
    this.ingestSnapshot(snapshot2, callback);
  else if (callback)
    callback();
  this._emitNothingPending();
  this._flushSubscribe();
};
Doc$1.prototype._handleOp = function(err, message) {
  if (err) {
    if (this.inflightOp) {
      if (err.code === ERROR_CODE$2.ERR_OP_SUBMIT_REJECTED)
        err = null;
      return this._rollback(err);
    }
    return this.emit("error", err);
  }
  if (this.inflightOp && message.src === this.inflightOp.src && message.seq === this.inflightOp.seq) {
    this._opAcknowledged(message);
    return;
  }
  if (this.version == null || message.v > this.version) {
    this.fetch();
    return;
  }
  if (message.v < this.version) {
    return;
  }
  if (this.inflightOp) {
    var transformErr = transformX(this.inflightOp, message);
    if (transformErr)
      return this._hardRollback(transformErr);
  }
  for (var i = 0; i < this.pendingOps.length; i++) {
    var transformErr = transformX(this.pendingOps[i], message);
    if (transformErr)
      return this._hardRollback(transformErr);
  }
  this.version++;
  try {
    this._otApply(message, false);
  } catch (error2) {
    return this._hardRollback(error2);
  }
};
Doc$1.prototype._onConnectionStateChanged = function() {
  if (this.connection.canSend) {
    this.flush();
    this._resubscribe();
  } else {
    if (this.inflightOp) {
      this.pendingOps.unshift(this.inflightOp);
      this.inflightOp = null;
    }
    this.subscribed = false;
    if (this.inflightSubscribe) {
      if (this.inflightSubscribe.wantSubscribe) {
        this.pendingSubscribe.unshift(this.inflightSubscribe);
        this.inflightSubscribe = null;
      } else {
        this._handleSubscribe();
      }
    }
    if (this.inflightFetch.length) {
      this.pendingFetch = this.pendingFetch.concat(this.inflightFetch);
      this.inflightFetch.length = 0;
    }
  }
};
Doc$1.prototype._resubscribe = function() {
  if (!this.pendingSubscribe.length && this.wantSubscribe) {
    return this.subscribe();
  }
  var willFetch = this.pendingSubscribe.some(function(request) {
    return request.wantSubscribe;
  });
  if (!willFetch && this.pendingFetch.length)
    this.fetch();
  this._flushSubscribe();
};
Doc$1.prototype.fetch = function(callback) {
  if (this.connection.canSend) {
    var isDuplicate = this.connection.sendFetch(this);
    pushActionCallback(this.inflightFetch, isDuplicate, callback);
    return;
  }
  this.pendingFetch.push(callback);
};
Doc$1.prototype.subscribe = function(callback) {
  var wantSubscribe = true;
  this._queueSubscribe(wantSubscribe, callback);
};
Doc$1.prototype.unsubscribe = function(callback) {
  var wantSubscribe = false;
  this._queueSubscribe(wantSubscribe, callback);
};
Doc$1.prototype._queueSubscribe = function(wantSubscribe, callback) {
  var lastRequest = this.pendingSubscribe[this.pendingSubscribe.length - 1] || this.inflightSubscribe;
  var isDuplicateRequest = lastRequest && lastRequest.wantSubscribe === wantSubscribe;
  if (isDuplicateRequest) {
    lastRequest.callback = combineCallbacks([lastRequest.callback, callback]);
    return;
  }
  this.pendingSubscribe.push({
    wantSubscribe: !!wantSubscribe,
    callback
  });
  this._flushSubscribe();
};
Doc$1.prototype._flushSubscribe = function() {
  if (this.inflightSubscribe || !this.pendingSubscribe.length)
    return;
  if (this.connection.canSend) {
    this.inflightSubscribe = this.pendingSubscribe.shift();
    this.wantSubscribe = this.inflightSubscribe.wantSubscribe;
    if (this.wantSubscribe) {
      this.connection.sendSubscribe(this);
    } else {
      this.subscribed = false;
      this.connection.sendUnsubscribe(this);
    }
    return;
  }
  if (!this.pendingSubscribe[0].wantSubscribe) {
    this.inflightSubscribe = this.pendingSubscribe.shift();
    var doc2 = this;
    util$8.nextTick(function() {
      doc2._handleSubscribe();
    });
  }
};
function pushActionCallback(inflight, isDuplicate, callback) {
  if (isDuplicate) {
    var lastCallback = inflight.pop();
    inflight.push(function(err) {
      lastCallback && lastCallback(err);
      callback && callback(err);
    });
  } else {
    inflight.push(callback);
  }
}
function combineCallbacks(callbacks) {
  callbacks = callbacks.filter(util$8.truthy);
  if (!callbacks.length)
    return null;
  return function(error2) {
    util$8.callEach(callbacks, error2);
  };
}
Doc$1.prototype.flush = function() {
  if (!this.connection.canSend || this.inflightOp)
    return;
  if (!this.paused && this.pendingOps.length) {
    this._sendOp();
  }
};
function setNoOp(op) {
  delete op.op;
  delete op.create;
  delete op.del;
}
function transformX(client, server) {
  if (client.del)
    return setNoOp(server);
  if (server.del) {
    return new ShareDBError$2(ERROR_CODE$2.ERR_DOC_WAS_DELETED, "Document was deleted");
  }
  if (server.create) {
    return new ShareDBError$2(ERROR_CODE$2.ERR_DOC_ALREADY_CREATED, "Document already created");
  }
  if (!("op" in server))
    return;
  if (client.create) {
    return new ShareDBError$2(ERROR_CODE$2.ERR_DOC_ALREADY_CREATED, "Document already created");
  }
  if (client.type.transformX) {
    var result = client.type.transformX(client.op, server.op);
    client.op = result[0];
    server.op = result[1];
  } else {
    var clientOp = client.type.transform(client.op, server.op, "left");
    var serverOp = client.type.transform(server.op, client.op, "right");
    client.op = clientOp;
    server.op = serverOp;
  }
}
Doc$1.prototype._otApply = function(op, source) {
  if ("op" in op) {
    if (!this.type) {
      throw new ShareDBError$2(ERROR_CODE$2.ERR_DOC_DOES_NOT_EXIST, "Cannot apply op to uncreated document. " + this.collection + "." + this.id);
    }
    this.emit("before op batch", op.op, source);
    if (!source && this.type === types$2.defaultType && op.op.length > 1) {
      if (!this.applyStack)
        this.applyStack = [];
      var stackLength = this.applyStack.length;
      for (var i = 0; i < op.op.length; i++) {
        var component = op.op[i];
        var componentOp = { op: [component] };
        this.emit("before op", componentOp.op, source, op.src);
        for (var j = stackLength; j < this.applyStack.length; j++) {
          var transformErr = transformX(this.applyStack[j], componentOp);
          if (transformErr)
            return this._hardRollback(transformErr);
        }
        this._setData(this.type.apply(this.data, componentOp.op));
        this.emit("op", componentOp.op, source, op.src);
      }
      this.emit("op batch", op.op, source);
      this._popApplyStack(stackLength);
      return;
    }
    this.emit("before op", op.op, source, op.src);
    this._setData(this.type.apply(this.data, op.op));
    this.emit("op", op.op, source, op.src);
    this.emit("op batch", op.op, source);
    return;
  }
  if (op.create) {
    this._setType(op.create.type);
    if (this.type.deserialize) {
      if (this.type.createDeserialized) {
        this._setData(this.type.createDeserialized(op.create.data));
      } else {
        this._setData(this.type.deserialize(this.type.create(op.create.data)));
      }
    } else {
      this._setData(this.type.create(op.create.data));
    }
    this.emit("create", source);
    return;
  }
  if (op.del) {
    var oldData = this.data;
    this._setType(null);
    this.emit("del", oldData, source);
    return;
  }
};
Doc$1.prototype._sendOp = function() {
  if (!this.connection.canSend)
    return;
  var src = this.connection.id;
  if (!this.inflightOp) {
    this.inflightOp = this.pendingOps.shift();
  }
  var op = this.inflightOp;
  if (!op) {
    var err = new ShareDBError$2(ERROR_CODE$2.ERR_INFLIGHT_OP_MISSING, "No op to send on call to _sendOp");
    return this.emit("error", err);
  }
  op.sentAt = Date.now();
  op.retries = op.retries == null ? 0 : op.retries + 1;
  if (op.seq == null) {
    if (this.connection.seq >= util$8.MAX_SAFE_INTEGER) {
      return this.emit("error", new ShareDBError$2(ERROR_CODE$2.ERR_CONNECTION_SEQ_INTEGER_OVERFLOW, "Connection seq has exceeded the max safe integer, maybe from being open for too long"));
    }
    op.seq = this.connection.seq++;
  }
  this.connection.sendOp(this, op);
  if (op.src == null)
    op.src = src;
};
Doc$1.prototype._submit = function(op, source, callback) {
  if (!source)
    source = true;
  if ("op" in op) {
    if (!this.type) {
      var err = new ShareDBError$2(ERROR_CODE$2.ERR_DOC_DOES_NOT_EXIST, "Cannot submit op. Document has not been created. " + this.collection + "." + this.id);
      if (callback)
        return callback(err);
      return this.emit("error", err);
    }
    if (this.type.normalize)
      op.op = this.type.normalize(op.op);
  }
  try {
    this._pushOp(op, source, callback);
    this._otApply(op, source);
  } catch (error2) {
    return this._hardRollback(error2);
  }
  var doc2 = this;
  util$8.nextTick(function() {
    doc2.flush();
  });
};
Doc$1.prototype._pushOp = function(op, source, callback) {
  op.source = source;
  if (this.applyStack) {
    this.applyStack.push(op);
  } else {
    var composed = this._tryCompose(op);
    if (composed) {
      composed.callbacks.push(callback);
      return;
    }
  }
  op.type = this.type;
  op.callbacks = [callback];
  this.pendingOps.push(op);
};
Doc$1.prototype._popApplyStack = function(to) {
  if (to > 0) {
    this.applyStack.length = to;
    return;
  }
  var op = this.applyStack[0];
  this.applyStack = null;
  if (!op)
    return;
  var i = this.pendingOps.indexOf(op);
  if (i === -1)
    return;
  var ops = this.pendingOps.splice(i);
  for (var i = 0; i < ops.length; i++) {
    var op = ops[i];
    var composed = this._tryCompose(op);
    if (composed) {
      composed.callbacks = composed.callbacks.concat(op.callbacks);
    } else {
      this.pendingOps.push(op);
    }
  }
};
Doc$1.prototype._tryCompose = function(op) {
  if (this.preventCompose)
    return;
  var last = this.pendingOps[this.pendingOps.length - 1];
  if (!last || last.sentAt)
    return;
  if (this.submitSource && !deepEqual(op.source, last.source))
    return;
  if (last.create && "op" in op) {
    last.create.data = this.type.apply(last.create.data, op.op);
    return last;
  }
  if ("op" in last && "op" in op && this.type.compose) {
    last.op = this.type.compose(last.op, op.op);
    return last;
  }
};
Doc$1.prototype.submitOp = function(component, options, callback) {
  if (typeof options === "function") {
    callback = options;
    options = null;
  }
  var op = { op: component };
  var source = options && options.source;
  this._submit(op, source, callback);
};
Doc$1.prototype.create = function(data, type, options, callback) {
  if (typeof type === "function") {
    callback = type;
    options = null;
    type = null;
  } else if (typeof options === "function") {
    callback = options;
    options = null;
  }
  if (!type) {
    type = types$2.defaultType.uri;
  }
  if (this.type) {
    var err = new ShareDBError$2(ERROR_CODE$2.ERR_DOC_ALREADY_CREATED, "Document already exists");
    if (callback)
      return callback(err);
    return this.emit("error", err);
  }
  var op = { create: { type, data } };
  var source = options && options.source;
  this._submit(op, source, callback);
};
Doc$1.prototype.del = function(options, callback) {
  if (typeof options === "function") {
    callback = options;
    options = null;
  }
  if (!this.type) {
    var err = new ShareDBError$2(ERROR_CODE$2.ERR_DOC_DOES_NOT_EXIST, "Document does not exist");
    if (callback)
      return callback(err);
    return this.emit("error", err);
  }
  var op = { del: true };
  var source = options && options.source;
  this._submit(op, source, callback);
};
Doc$1.prototype.pause = function() {
  this.paused = true;
};
Doc$1.prototype.resume = function() {
  this.paused = false;
  this.flush();
};
Doc$1.prototype.toSnapshot = function() {
  return {
    v: this.version,
    data: clone(this.data),
    type: this.type.uri
  };
};
Doc$1.prototype._opAcknowledged = function(message) {
  if (this.inflightOp.create) {
    this.version = message.v;
  } else if (message.v !== this.version) {
    logger$1.warn("Invalid version from server. Expected: " + this.version + " Received: " + message.v, message);
    return this.fetch();
  }
  this.version++;
  this._clearInflightOp();
};
Doc$1.prototype._rollback = function(err) {
  var op = this.inflightOp;
  if ("op" in op && op.type.invert) {
    try {
      op.op = op.type.invert(op.op);
    } catch (error2) {
      return this._hardRollback(err);
    }
    for (var i = 0; i < this.pendingOps.length; i++) {
      var transformErr = transformX(this.pendingOps[i], op);
      if (transformErr)
        return this._hardRollback(transformErr);
    }
    try {
      this._otApply(op, false);
    } catch (error2) {
      return this._hardRollback(error2);
    }
    this._clearInflightOp(err);
    return;
  }
  this._hardRollback(err);
};
Doc$1.prototype._hardRollback = function(err) {
  var pendingOps = [];
  if (this.inflightOp)
    pendingOps.push(this.inflightOp);
  pendingOps = pendingOps.concat(this.pendingOps);
  this._setType(null);
  this.version = null;
  this.inflightOp = null;
  this.pendingOps = [];
  var doc2 = this;
  this.fetch(function() {
    var allOpsHadCallbacks = !!pendingOps.length;
    for (var i = 0; i < pendingOps.length; i++) {
      allOpsHadCallbacks = util$8.callEach(pendingOps[i].callbacks, err) && allOpsHadCallbacks;
    }
    if (err && !allOpsHadCallbacks)
      return doc2.emit("error", err);
  });
};
Doc$1.prototype._clearInflightOp = function(err) {
  var inflightOp = this.inflightOp;
  this.inflightOp = null;
  var called = util$8.callEach(inflightOp.callbacks, err);
  this.flush();
  this._emitNothingPending();
  if (err && !called)
    return this.emit("error", err);
};
var emitter$4 = emitter$6;
var util$7 = util$9;
var query = Query$1;
function Query$1(action, connection2, id, collection, query2, options, callback) {
  emitter$4.EventEmitter.call(this);
  this.action = action;
  this.connection = connection2;
  this.id = id;
  this.collection = collection;
  this.query = query2;
  this.results = null;
  if (options && options.results) {
    this.results = options.results;
    delete options.results;
  }
  this.extra = void 0;
  this.options = options;
  this.callback = callback;
  this.ready = false;
  this.sent = false;
}
emitter$4.mixin(Query$1);
Query$1.prototype.hasPending = function() {
  return !this.ready;
};
Query$1.prototype.send = function() {
  if (!this.connection.canSend)
    return;
  var message = {
    a: this.action,
    id: this.id,
    c: this.collection,
    q: this.query
  };
  if (this.options) {
    message.o = this.options;
  }
  if (this.results) {
    var results = [];
    for (var i = 0; i < this.results.length; i++) {
      var doc2 = this.results[i];
      results.push([doc2.id, doc2.version]);
    }
    message.r = results;
  }
  this.connection.send(message);
  this.sent = true;
};
Query$1.prototype.destroy = function(callback) {
  if (this.connection.canSend && this.action === "qs") {
    this.connection.send({ a: "qu", id: this.id });
  }
  this.connection._destroyQuery(this);
  if (callback)
    util$7.nextTick(callback);
};
Query$1.prototype._onConnectionStateChanged = function() {
  if (this.connection.canSend && !this.sent) {
    this.send();
  } else {
    this.sent = false;
  }
};
Query$1.prototype._handleFetch = function(err, data, extra) {
  this.connection._destroyQuery(this);
  this._handleResponse(err, data, extra);
};
Query$1.prototype._handleSubscribe = function(err, data, extra) {
  this._handleResponse(err, data, extra);
};
Query$1.prototype._handleResponse = function(err, data, extra) {
  var callback = this.callback;
  this.callback = null;
  if (err)
    return this._finishResponse(err, callback);
  if (!data)
    return this._finishResponse(null, callback);
  var query2 = this;
  var wait = 1;
  var finish = function(err2) {
    if (err2)
      return query2._finishResponse(err2, callback);
    if (--wait)
      return;
    query2._finishResponse(null, callback);
  };
  if (Array.isArray(data)) {
    wait += data.length;
    this.results = this._ingestSnapshots(data, finish);
    this.extra = extra;
  } else {
    for (var id in data) {
      wait++;
      var snapshot2 = data[id];
      var doc2 = this.connection.get(snapshot2.c || this.collection, id);
      doc2.ingestSnapshot(snapshot2, finish);
    }
  }
  finish();
};
Query$1.prototype._ingestSnapshots = function(snapshots, finish) {
  var results = [];
  for (var i = 0; i < snapshots.length; i++) {
    var snapshot2 = snapshots[i];
    var doc2 = this.connection.get(snapshot2.c || this.collection, snapshot2.d);
    doc2.ingestSnapshot(snapshot2, finish);
    results.push(doc2);
  }
  return results;
};
Query$1.prototype._finishResponse = function(err, callback) {
  this.emit("ready");
  this.ready = true;
  if (err) {
    this.connection._destroyQuery(this);
    if (callback)
      return callback(err);
    return this.emit("error", err);
  }
  if (callback)
    callback(null, this.results, this.extra);
};
Query$1.prototype._handleError = function(err) {
  this.emit("error", err);
};
Query$1.prototype._handleDiff = function(diff2) {
  for (var i = 0; i < diff2.length; i++) {
    var d = diff2[i];
    if (d.type === "insert")
      d.values = this._ingestSnapshots(d.values);
  }
  for (var i = 0; i < diff2.length; i++) {
    var d = diff2[i];
    switch (d.type) {
      case "insert":
        var newDocs = d.values;
        Array.prototype.splice.apply(this.results, [d.index, 0].concat(newDocs));
        this.emit("insert", newDocs, d.index);
        break;
      case "remove":
        var howMany = d.howMany || 1;
        var removed = this.results.splice(d.index, howMany);
        this.emit("remove", removed, d.index);
        break;
      case "move":
        var howMany = d.howMany || 1;
        var docs = this.results.splice(d.from, howMany);
        Array.prototype.splice.apply(this.results, [d.to, 0].concat(docs));
        this.emit("move", docs, d.from, d.to);
        break;
    }
  }
  this.emit("changed", this.results);
};
Query$1.prototype._handleExtra = function(extra) {
  this.extra = extra;
  this.emit("extra", extra);
};
var emitter$3 = emitter$6;
var util$6 = util$9;
var localPresence = LocalPresence$2;
function LocalPresence$2(presence2, presenceId) {
  emitter$3.EventEmitter.call(this);
  if (!presenceId || typeof presenceId !== "string") {
    throw new Error("LocalPresence presenceId must be a string");
  }
  this.presence = presence2;
  this.presenceId = presenceId;
  this.connection = presence2.connection;
  this.presenceVersion = 0;
  this.value = null;
  this._pendingMessages = [];
  this._callbacksByPresenceVersion = {};
}
emitter$3.mixin(LocalPresence$2);
LocalPresence$2.prototype.submit = function(value, callback) {
  this.value = value;
  this.send(callback);
};
LocalPresence$2.prototype.send = function(callback) {
  var message = this._message();
  this._pendingMessages.push(message);
  this._callbacksByPresenceVersion[message.pv] = callback;
  this._sendPending();
};
LocalPresence$2.prototype.destroy = function(callback) {
  var presence2 = this;
  this.submit(null, function(error2) {
    if (error2)
      return presence2._callbackOrEmit(error2, callback);
    delete presence2.presence.localPresences[presence2.presenceId];
    if (callback)
      callback();
  });
};
LocalPresence$2.prototype._sendPending = function() {
  if (!this.connection.canSend)
    return;
  var presence2 = this;
  this._pendingMessages.forEach(function(message) {
    presence2.connection.send(message);
  });
  this._pendingMessages = [];
};
LocalPresence$2.prototype._ack = function(error2, presenceVersion) {
  var callback = this._getCallback(presenceVersion);
  this._callbackOrEmit(error2, callback);
};
LocalPresence$2.prototype._message = function() {
  return {
    a: "p",
    ch: this.presence.channel,
    id: this.presenceId,
    p: this.value,
    pv: this.presenceVersion++
  };
};
LocalPresence$2.prototype._getCallback = function(presenceVersion) {
  var callback = this._callbacksByPresenceVersion[presenceVersion];
  delete this._callbacksByPresenceVersion[presenceVersion];
  return callback;
};
LocalPresence$2.prototype._callbackOrEmit = function(error2, callback) {
  if (callback)
    return util$6.nextTick(callback, error2);
  if (error2)
    this.emit("error", error2);
};
var util$5 = util$9;
var remotePresence = RemotePresence$2;
function RemotePresence$2(presence2, presenceId) {
  this.presence = presence2;
  this.presenceId = presenceId;
  this.connection = this.presence.connection;
  this.value = null;
  this.presenceVersion = 0;
}
RemotePresence$2.prototype.receiveUpdate = function(message) {
  if (message.pv < this.presenceVersion)
    return;
  this.value = message.p;
  this.presenceVersion = message.pv;
  this.presence._updateRemotePresence(this);
};
RemotePresence$2.prototype.destroy = function(callback) {
  delete this.presence._remotePresenceInstances[this.presenceId];
  delete this.presence.remotePresences[this.presenceId];
  if (callback)
    util$5.nextTick(callback);
};
var async$1 = { exports: {} };
(function(module, exports) {
  (function(global2, factory) {
    factory(exports);
  })(commonjsGlobal$1, function(exports2) {
    function slice(arrayLike, start) {
      start = start | 0;
      var newLen = Math.max(arrayLike.length - start, 0);
      var newArr = Array(newLen);
      for (var idx = 0; idx < newLen; idx++) {
        newArr[idx] = arrayLike[start + idx];
      }
      return newArr;
    }
    var apply = function(fn) {
      var args = slice(arguments, 1);
      return function() {
        var callArgs = slice(arguments);
        return fn.apply(null, args.concat(callArgs));
      };
    };
    var initialParams = function(fn) {
      return function() {
        var args = slice(arguments);
        var callback = args.pop();
        fn.call(this, args, callback);
      };
    };
    function isObject2(value) {
      var type = typeof value;
      return value != null && (type == "object" || type == "function");
    }
    var hasSetImmediate = typeof setImmediate === "function" && setImmediate;
    var hasNextTick = typeof process === "object" && typeof process.nextTick === "function";
    function fallback(fn) {
      setTimeout(fn, 0);
    }
    function wrap(defer) {
      return function(fn) {
        var args = slice(arguments, 1);
        defer(function() {
          fn.apply(null, args);
        });
      };
    }
    var _defer;
    if (hasSetImmediate) {
      _defer = setImmediate;
    } else if (hasNextTick) {
      _defer = process.nextTick;
    } else {
      _defer = fallback;
    }
    var setImmediate$1 = wrap(_defer);
    function asyncify(func) {
      return initialParams(function(args, callback) {
        var result;
        try {
          result = func.apply(this, args);
        } catch (e) {
          return callback(e);
        }
        if (isObject2(result) && typeof result.then === "function") {
          result.then(function(value) {
            invokeCallback(callback, null, value);
          }, function(err) {
            invokeCallback(callback, err.message ? err : new Error(err));
          });
        } else {
          callback(null, result);
        }
      });
    }
    function invokeCallback(callback, error2, value) {
      try {
        callback(error2, value);
      } catch (e) {
        setImmediate$1(rethrow, e);
      }
    }
    function rethrow(error2) {
      throw error2;
    }
    var supportsSymbol = typeof Symbol === "function";
    function isAsync(fn) {
      return supportsSymbol && fn[Symbol.toStringTag] === "AsyncFunction";
    }
    function wrapAsync(asyncFn) {
      return isAsync(asyncFn) ? asyncify(asyncFn) : asyncFn;
    }
    function applyEach$1(eachfn) {
      return function(fns) {
        var args = slice(arguments, 1);
        var go = initialParams(function(args2, callback) {
          var that = this;
          return eachfn(fns, function(fn, cb) {
            wrapAsync(fn).apply(that, args2.concat(cb));
          }, callback);
        });
        if (args.length) {
          return go.apply(this, args);
        } else {
          return go;
        }
      };
    }
    var freeGlobal2 = typeof commonjsGlobal$1 == "object" && commonjsGlobal$1 && commonjsGlobal$1.Object === Object && commonjsGlobal$1;
    var freeSelf2 = typeof self == "object" && self && self.Object === Object && self;
    var root2 = freeGlobal2 || freeSelf2 || Function("return this")();
    var Symbol$1 = root2.Symbol;
    var objectProto2 = Object.prototype;
    var hasOwnProperty = objectProto2.hasOwnProperty;
    var nativeObjectToString = objectProto2.toString;
    var symToStringTag$1 = Symbol$1 ? Symbol$1.toStringTag : void 0;
    function getRawTag(value) {
      var isOwn = hasOwnProperty.call(value, symToStringTag$1), tag = value[symToStringTag$1];
      try {
        value[symToStringTag$1] = void 0;
        var unmasked = true;
      } catch (e) {
      }
      var result = nativeObjectToString.call(value);
      if (unmasked) {
        if (isOwn) {
          value[symToStringTag$1] = tag;
        } else {
          delete value[symToStringTag$1];
        }
      }
      return result;
    }
    var objectProto$1 = Object.prototype;
    var nativeObjectToString$1 = objectProto$1.toString;
    function objectToString2(value) {
      return nativeObjectToString$1.call(value);
    }
    var nullTag = "[object Null]";
    var undefinedTag = "[object Undefined]";
    var symToStringTag = Symbol$1 ? Symbol$1.toStringTag : void 0;
    function baseGetTag(value) {
      if (value == null) {
        return value === void 0 ? undefinedTag : nullTag;
      }
      return symToStringTag && symToStringTag in Object(value) ? getRawTag(value) : objectToString2(value);
    }
    var asyncTag = "[object AsyncFunction]";
    var funcTag = "[object Function]";
    var genTag = "[object GeneratorFunction]";
    var proxyTag = "[object Proxy]";
    function isFunction(value) {
      if (!isObject2(value)) {
        return false;
      }
      var tag = baseGetTag(value);
      return tag == funcTag || tag == genTag || tag == asyncTag || tag == proxyTag;
    }
    var MAX_SAFE_INTEGER = 9007199254740991;
    function isLength(value) {
      return typeof value == "number" && value > -1 && value % 1 == 0 && value <= MAX_SAFE_INTEGER;
    }
    function isArrayLike(value) {
      return value != null && isLength(value.length) && !isFunction(value);
    }
    var breakLoop = {};
    function noop() {
    }
    function once3(fn) {
      return function() {
        if (fn === null)
          return;
        var callFn = fn;
        fn = null;
        callFn.apply(this, arguments);
      };
    }
    var iteratorSymbol = typeof Symbol === "function" && Symbol.iterator;
    var getIterator = function(coll) {
      return iteratorSymbol && coll[iteratorSymbol] && coll[iteratorSymbol]();
    };
    function baseTimes(n, iteratee) {
      var index2 = -1, result = Array(n);
      while (++index2 < n) {
        result[index2] = iteratee(index2);
      }
      return result;
    }
    function isObjectLike2(value) {
      return value != null && typeof value == "object";
    }
    var argsTag = "[object Arguments]";
    function baseIsArguments(value) {
      return isObjectLike2(value) && baseGetTag(value) == argsTag;
    }
    var objectProto$3 = Object.prototype;
    var hasOwnProperty$2 = objectProto$3.hasOwnProperty;
    var propertyIsEnumerable = objectProto$3.propertyIsEnumerable;
    var isArguments = baseIsArguments(function() {
      return arguments;
    }()) ? baseIsArguments : function(value) {
      return isObjectLike2(value) && hasOwnProperty$2.call(value, "callee") && !propertyIsEnumerable.call(value, "callee");
    };
    var isArray2 = Array.isArray;
    function stubFalse() {
      return false;
    }
    var freeExports = typeof exports2 == "object" && exports2 && !exports2.nodeType && exports2;
    var freeModule = freeExports && true && module && !module.nodeType && module;
    var moduleExports = freeModule && freeModule.exports === freeExports;
    var Buffer2 = moduleExports ? root2.Buffer : void 0;
    var nativeIsBuffer = Buffer2 ? Buffer2.isBuffer : void 0;
    var isBuffer = nativeIsBuffer || stubFalse;
    var MAX_SAFE_INTEGER$1 = 9007199254740991;
    var reIsUint = /^(?:0|[1-9]\d*)$/;
    function isIndex(value, length) {
      var type = typeof value;
      length = length == null ? MAX_SAFE_INTEGER$1 : length;
      return !!length && (type == "number" || type != "symbol" && reIsUint.test(value)) && (value > -1 && value % 1 == 0 && value < length);
    }
    var argsTag$1 = "[object Arguments]";
    var arrayTag = "[object Array]";
    var boolTag = "[object Boolean]";
    var dateTag = "[object Date]";
    var errorTag = "[object Error]";
    var funcTag$1 = "[object Function]";
    var mapTag = "[object Map]";
    var numberTag = "[object Number]";
    var objectTag = "[object Object]";
    var regexpTag = "[object RegExp]";
    var setTag = "[object Set]";
    var stringTag = "[object String]";
    var weakMapTag = "[object WeakMap]";
    var arrayBufferTag = "[object ArrayBuffer]";
    var dataViewTag = "[object DataView]";
    var float32Tag = "[object Float32Array]";
    var float64Tag = "[object Float64Array]";
    var int8Tag = "[object Int8Array]";
    var int16Tag = "[object Int16Array]";
    var int32Tag = "[object Int32Array]";
    var uint8Tag = "[object Uint8Array]";
    var uint8ClampedTag = "[object Uint8ClampedArray]";
    var uint16Tag = "[object Uint16Array]";
    var uint32Tag = "[object Uint32Array]";
    var typedArrayTags = {};
    typedArrayTags[float32Tag] = typedArrayTags[float64Tag] = typedArrayTags[int8Tag] = typedArrayTags[int16Tag] = typedArrayTags[int32Tag] = typedArrayTags[uint8Tag] = typedArrayTags[uint8ClampedTag] = typedArrayTags[uint16Tag] = typedArrayTags[uint32Tag] = true;
    typedArrayTags[argsTag$1] = typedArrayTags[arrayTag] = typedArrayTags[arrayBufferTag] = typedArrayTags[boolTag] = typedArrayTags[dataViewTag] = typedArrayTags[dateTag] = typedArrayTags[errorTag] = typedArrayTags[funcTag$1] = typedArrayTags[mapTag] = typedArrayTags[numberTag] = typedArrayTags[objectTag] = typedArrayTags[regexpTag] = typedArrayTags[setTag] = typedArrayTags[stringTag] = typedArrayTags[weakMapTag] = false;
    function baseIsTypedArray(value) {
      return isObjectLike2(value) && isLength(value.length) && !!typedArrayTags[baseGetTag(value)];
    }
    function baseUnary(func) {
      return function(value) {
        return func(value);
      };
    }
    var freeExports$1 = typeof exports2 == "object" && exports2 && !exports2.nodeType && exports2;
    var freeModule$1 = freeExports$1 && true && module && !module.nodeType && module;
    var moduleExports$1 = freeModule$1 && freeModule$1.exports === freeExports$1;
    var freeProcess = moduleExports$1 && freeGlobal2.process;
    var nodeUtil = function() {
      try {
        var types2 = freeModule$1 && freeModule$1.require && freeModule$1.require("util").types;
        if (types2) {
          return types2;
        }
        return freeProcess && freeProcess.binding && freeProcess.binding("util");
      } catch (e) {
      }
    }();
    var nodeIsTypedArray = nodeUtil && nodeUtil.isTypedArray;
    var isTypedArray = nodeIsTypedArray ? baseUnary(nodeIsTypedArray) : baseIsTypedArray;
    var objectProto$2 = Object.prototype;
    var hasOwnProperty$1 = objectProto$2.hasOwnProperty;
    function arrayLikeKeys(value, inherited) {
      var isArr = isArray2(value), isArg = !isArr && isArguments(value), isBuff = !isArr && !isArg && isBuffer(value), isType = !isArr && !isArg && !isBuff && isTypedArray(value), skipIndexes = isArr || isArg || isBuff || isType, result = skipIndexes ? baseTimes(value.length, String) : [], length = result.length;
      for (var key in value) {
        if ((inherited || hasOwnProperty$1.call(value, key)) && !(skipIndexes && (key == "length" || isBuff && (key == "offset" || key == "parent") || isType && (key == "buffer" || key == "byteLength" || key == "byteOffset") || isIndex(key, length)))) {
          result.push(key);
        }
      }
      return result;
    }
    var objectProto$5 = Object.prototype;
    function isPrototype(value) {
      var Ctor = value && value.constructor, proto = typeof Ctor == "function" && Ctor.prototype || objectProto$5;
      return value === proto;
    }
    function overArg(func, transform2) {
      return function(arg) {
        return func(transform2(arg));
      };
    }
    var nativeKeys = overArg(Object.keys, Object);
    var objectProto$4 = Object.prototype;
    var hasOwnProperty$3 = objectProto$4.hasOwnProperty;
    function baseKeys(object) {
      if (!isPrototype(object)) {
        return nativeKeys(object);
      }
      var result = [];
      for (var key in Object(object)) {
        if (hasOwnProperty$3.call(object, key) && key != "constructor") {
          result.push(key);
        }
      }
      return result;
    }
    function keys(object) {
      return isArrayLike(object) ? arrayLikeKeys(object) : baseKeys(object);
    }
    function createArrayIterator(coll) {
      var i = -1;
      var len = coll.length;
      return function next() {
        return ++i < len ? { value: coll[i], key: i } : null;
      };
    }
    function createES2015Iterator(iterator2) {
      var i = -1;
      return function next() {
        var item = iterator2.next();
        if (item.done)
          return null;
        i++;
        return { value: item.value, key: i };
      };
    }
    function createObjectIterator(obj) {
      var okeys = keys(obj);
      var i = -1;
      var len = okeys.length;
      return function next() {
        var key = okeys[++i];
        return i < len ? { value: obj[key], key } : null;
      };
    }
    function iterator(coll) {
      if (isArrayLike(coll)) {
        return createArrayIterator(coll);
      }
      var iterator2 = getIterator(coll);
      return iterator2 ? createES2015Iterator(iterator2) : createObjectIterator(coll);
    }
    function onlyOnce(fn) {
      return function() {
        if (fn === null)
          throw new Error("Callback was already called.");
        var callFn = fn;
        fn = null;
        callFn.apply(this, arguments);
      };
    }
    function _eachOfLimit(limit) {
      return function(obj, iteratee, callback) {
        callback = once3(callback || noop);
        if (limit <= 0 || !obj) {
          return callback(null);
        }
        var nextElem = iterator(obj);
        var done = false;
        var running = 0;
        var looping = false;
        function iterateeCallback(err, value) {
          running -= 1;
          if (err) {
            done = true;
            callback(err);
          } else if (value === breakLoop || done && running <= 0) {
            done = true;
            return callback(null);
          } else if (!looping) {
            replenish();
          }
        }
        function replenish() {
          looping = true;
          while (running < limit && !done) {
            var elem = nextElem();
            if (elem === null) {
              done = true;
              if (running <= 0) {
                callback(null);
              }
              return;
            }
            running += 1;
            iteratee(elem.value, elem.key, onlyOnce(iterateeCallback));
          }
          looping = false;
        }
        replenish();
      };
    }
    function eachOfLimit(coll, limit, iteratee, callback) {
      _eachOfLimit(limit)(coll, wrapAsync(iteratee), callback);
    }
    function doLimit(fn, limit) {
      return function(iterable, iteratee, callback) {
        return fn(iterable, limit, iteratee, callback);
      };
    }
    function eachOfArrayLike(coll, iteratee, callback) {
      callback = once3(callback || noop);
      var index2 = 0, completed = 0, length = coll.length;
      if (length === 0) {
        callback(null);
      }
      function iteratorCallback(err, value) {
        if (err) {
          callback(err);
        } else if (++completed === length || value === breakLoop) {
          callback(null);
        }
      }
      for (; index2 < length; index2++) {
        iteratee(coll[index2], index2, onlyOnce(iteratorCallback));
      }
    }
    var eachOfGeneric = doLimit(eachOfLimit, Infinity);
    var eachOf = function(coll, iteratee, callback) {
      var eachOfImplementation = isArrayLike(coll) ? eachOfArrayLike : eachOfGeneric;
      eachOfImplementation(coll, wrapAsync(iteratee), callback);
    };
    function doParallel(fn) {
      return function(obj, iteratee, callback) {
        return fn(eachOf, obj, wrapAsync(iteratee), callback);
      };
    }
    function _asyncMap(eachfn, arr, iteratee, callback) {
      callback = callback || noop;
      arr = arr || [];
      var results = [];
      var counter = 0;
      var _iteratee = wrapAsync(iteratee);
      eachfn(arr, function(value, _, callback2) {
        var index2 = counter++;
        _iteratee(value, function(err, v) {
          results[index2] = v;
          callback2(err);
        });
      }, function(err) {
        callback(err, results);
      });
    }
    var map = doParallel(_asyncMap);
    var applyEach = applyEach$1(map);
    function doParallelLimit(fn) {
      return function(obj, limit, iteratee, callback) {
        return fn(_eachOfLimit(limit), obj, wrapAsync(iteratee), callback);
      };
    }
    var mapLimit = doParallelLimit(_asyncMap);
    var mapSeries = doLimit(mapLimit, 1);
    var applyEachSeries = applyEach$1(mapSeries);
    function arrayEach(array, iteratee) {
      var index2 = -1, length = array == null ? 0 : array.length;
      while (++index2 < length) {
        if (iteratee(array[index2], index2, array) === false) {
          break;
        }
      }
      return array;
    }
    function createBaseFor(fromRight) {
      return function(object, iteratee, keysFunc) {
        var index2 = -1, iterable = Object(object), props = keysFunc(object), length = props.length;
        while (length--) {
          var key = props[fromRight ? length : ++index2];
          if (iteratee(iterable[key], key, iterable) === false) {
            break;
          }
        }
        return object;
      };
    }
    var baseFor = createBaseFor();
    function baseForOwn(object, iteratee) {
      return object && baseFor(object, iteratee, keys);
    }
    function baseFindIndex(array, predicate, fromIndex, fromRight) {
      var length = array.length, index2 = fromIndex + (fromRight ? 1 : -1);
      while (fromRight ? index2-- : ++index2 < length) {
        if (predicate(array[index2], index2, array)) {
          return index2;
        }
      }
      return -1;
    }
    function baseIsNaN(value) {
      return value !== value;
    }
    function strictIndexOf(array, value, fromIndex) {
      var index2 = fromIndex - 1, length = array.length;
      while (++index2 < length) {
        if (array[index2] === value) {
          return index2;
        }
      }
      return -1;
    }
    function baseIndexOf(array, value, fromIndex) {
      return value === value ? strictIndexOf(array, value, fromIndex) : baseFindIndex(array, baseIsNaN, fromIndex);
    }
    var auto = function(tasks, concurrency, callback) {
      if (typeof concurrency === "function") {
        callback = concurrency;
        concurrency = null;
      }
      callback = once3(callback || noop);
      var keys$$1 = keys(tasks);
      var numTasks = keys$$1.length;
      if (!numTasks) {
        return callback(null);
      }
      if (!concurrency) {
        concurrency = numTasks;
      }
      var results = {};
      var runningTasks = 0;
      var hasError = false;
      var listeners2 = /* @__PURE__ */ Object.create(null);
      var readyTasks = [];
      var readyToCheck = [];
      var uncheckedDependencies = {};
      baseForOwn(tasks, function(task, key) {
        if (!isArray2(task)) {
          enqueueTask(key, [task]);
          readyToCheck.push(key);
          return;
        }
        var dependencies = task.slice(0, task.length - 1);
        var remainingDependencies = dependencies.length;
        if (remainingDependencies === 0) {
          enqueueTask(key, task);
          readyToCheck.push(key);
          return;
        }
        uncheckedDependencies[key] = remainingDependencies;
        arrayEach(dependencies, function(dependencyName) {
          if (!tasks[dependencyName]) {
            throw new Error("async.auto task `" + key + "` has a non-existent dependency `" + dependencyName + "` in " + dependencies.join(", "));
          }
          addListener2(dependencyName, function() {
            remainingDependencies--;
            if (remainingDependencies === 0) {
              enqueueTask(key, task);
            }
          });
        });
      });
      checkForDeadlocks();
      processQueue();
      function enqueueTask(key, task) {
        readyTasks.push(function() {
          runTask(key, task);
        });
      }
      function processQueue() {
        if (readyTasks.length === 0 && runningTasks === 0) {
          return callback(null, results);
        }
        while (readyTasks.length && runningTasks < concurrency) {
          var run = readyTasks.shift();
          run();
        }
      }
      function addListener2(taskName, fn) {
        var taskListeners = listeners2[taskName];
        if (!taskListeners) {
          taskListeners = listeners2[taskName] = [];
        }
        taskListeners.push(fn);
      }
      function taskComplete(taskName) {
        var taskListeners = listeners2[taskName] || [];
        arrayEach(taskListeners, function(fn) {
          fn();
        });
        processQueue();
      }
      function runTask(key, task) {
        if (hasError)
          return;
        var taskCallback = onlyOnce(function(err, result) {
          runningTasks--;
          if (arguments.length > 2) {
            result = slice(arguments, 1);
          }
          if (err) {
            var safeResults = {};
            baseForOwn(results, function(val, rkey) {
              safeResults[rkey] = val;
            });
            safeResults[key] = result;
            hasError = true;
            listeners2 = /* @__PURE__ */ Object.create(null);
            callback(err, safeResults);
          } else {
            results[key] = result;
            taskComplete(key);
          }
        });
        runningTasks++;
        var taskFn = wrapAsync(task[task.length - 1]);
        if (task.length > 1) {
          taskFn(results, taskCallback);
        } else {
          taskFn(taskCallback);
        }
      }
      function checkForDeadlocks() {
        var currentTask;
        var counter = 0;
        while (readyToCheck.length) {
          currentTask = readyToCheck.pop();
          counter++;
          arrayEach(getDependents(currentTask), function(dependent) {
            if (--uncheckedDependencies[dependent] === 0) {
              readyToCheck.push(dependent);
            }
          });
        }
        if (counter !== numTasks) {
          throw new Error("async.auto cannot execute tasks due to a recursive dependency");
        }
      }
      function getDependents(taskName) {
        var result = [];
        baseForOwn(tasks, function(task, key) {
          if (isArray2(task) && baseIndexOf(task, taskName, 0) >= 0) {
            result.push(key);
          }
        });
        return result;
      }
    };
    function arrayMap(array, iteratee) {
      var index2 = -1, length = array == null ? 0 : array.length, result = Array(length);
      while (++index2 < length) {
        result[index2] = iteratee(array[index2], index2, array);
      }
      return result;
    }
    var symbolTag2 = "[object Symbol]";
    function isSymbol2(value) {
      return typeof value == "symbol" || isObjectLike2(value) && baseGetTag(value) == symbolTag2;
    }
    var INFINITY = 1 / 0;
    var symbolProto = Symbol$1 ? Symbol$1.prototype : void 0;
    var symbolToString = symbolProto ? symbolProto.toString : void 0;
    function baseToString(value) {
      if (typeof value == "string") {
        return value;
      }
      if (isArray2(value)) {
        return arrayMap(value, baseToString) + "";
      }
      if (isSymbol2(value)) {
        return symbolToString ? symbolToString.call(value) : "";
      }
      var result = value + "";
      return result == "0" && 1 / value == -INFINITY ? "-0" : result;
    }
    function baseSlice(array, start, end) {
      var index2 = -1, length = array.length;
      if (start < 0) {
        start = -start > length ? 0 : length + start;
      }
      end = end > length ? length : end;
      if (end < 0) {
        end += length;
      }
      length = start > end ? 0 : end - start >>> 0;
      start >>>= 0;
      var result = Array(length);
      while (++index2 < length) {
        result[index2] = array[index2 + start];
      }
      return result;
    }
    function castSlice(array, start, end) {
      var length = array.length;
      end = end === void 0 ? length : end;
      return !start && end >= length ? array : baseSlice(array, start, end);
    }
    function charsEndIndex(strSymbols, chrSymbols) {
      var index2 = strSymbols.length;
      while (index2-- && baseIndexOf(chrSymbols, strSymbols[index2], 0) > -1) {
      }
      return index2;
    }
    function charsStartIndex(strSymbols, chrSymbols) {
      var index2 = -1, length = strSymbols.length;
      while (++index2 < length && baseIndexOf(chrSymbols, strSymbols[index2], 0) > -1) {
      }
      return index2;
    }
    function asciiToArray(string) {
      return string.split("");
    }
    var rsAstralRange = "\\ud800-\\udfff";
    var rsComboMarksRange = "\\u0300-\\u036f";
    var reComboHalfMarksRange = "\\ufe20-\\ufe2f";
    var rsComboSymbolsRange = "\\u20d0-\\u20ff";
    var rsComboRange = rsComboMarksRange + reComboHalfMarksRange + rsComboSymbolsRange;
    var rsVarRange = "\\ufe0e\\ufe0f";
    var rsZWJ = "\\u200d";
    var reHasUnicode = RegExp("[" + rsZWJ + rsAstralRange + rsComboRange + rsVarRange + "]");
    function hasUnicode(string) {
      return reHasUnicode.test(string);
    }
    var rsAstralRange$1 = "\\ud800-\\udfff";
    var rsComboMarksRange$1 = "\\u0300-\\u036f";
    var reComboHalfMarksRange$1 = "\\ufe20-\\ufe2f";
    var rsComboSymbolsRange$1 = "\\u20d0-\\u20ff";
    var rsComboRange$1 = rsComboMarksRange$1 + reComboHalfMarksRange$1 + rsComboSymbolsRange$1;
    var rsVarRange$1 = "\\ufe0e\\ufe0f";
    var rsAstral = "[" + rsAstralRange$1 + "]";
    var rsCombo = "[" + rsComboRange$1 + "]";
    var rsFitz = "\\ud83c[\\udffb-\\udfff]";
    var rsModifier = "(?:" + rsCombo + "|" + rsFitz + ")";
    var rsNonAstral = "[^" + rsAstralRange$1 + "]";
    var rsRegional = "(?:\\ud83c[\\udde6-\\uddff]){2}";
    var rsSurrPair = "[\\ud800-\\udbff][\\udc00-\\udfff]";
    var rsZWJ$1 = "\\u200d";
    var reOptMod = rsModifier + "?";
    var rsOptVar = "[" + rsVarRange$1 + "]?";
    var rsOptJoin = "(?:" + rsZWJ$1 + "(?:" + [rsNonAstral, rsRegional, rsSurrPair].join("|") + ")" + rsOptVar + reOptMod + ")*";
    var rsSeq = rsOptVar + reOptMod + rsOptJoin;
    var rsSymbol = "(?:" + [rsNonAstral + rsCombo + "?", rsCombo, rsRegional, rsSurrPair, rsAstral].join("|") + ")";
    var reUnicode = RegExp(rsFitz + "(?=" + rsFitz + ")|" + rsSymbol + rsSeq, "g");
    function unicodeToArray(string) {
      return string.match(reUnicode) || [];
    }
    function stringToArray(string) {
      return hasUnicode(string) ? unicodeToArray(string) : asciiToArray(string);
    }
    function toString(value) {
      return value == null ? "" : baseToString(value);
    }
    var reTrim2 = /^\s+|\s+$/g;
    function trim(string, chars, guard) {
      string = toString(string);
      if (string && (guard || chars === void 0)) {
        return string.replace(reTrim2, "");
      }
      if (!string || !(chars = baseToString(chars))) {
        return string;
      }
      var strSymbols = stringToArray(string), chrSymbols = stringToArray(chars), start = charsStartIndex(strSymbols, chrSymbols), end = charsEndIndex(strSymbols, chrSymbols) + 1;
      return castSlice(strSymbols, start, end).join("");
    }
    var FN_ARGS = /^(?:async\s+)?(function)?\s*[^\(]*\(\s*([^\)]*)\)/m;
    var FN_ARG_SPLIT = /,/;
    var FN_ARG = /(=.+)?(\s*)$/;
    var STRIP_COMMENTS = /((\/\/.*$)|(\/\*[\s\S]*?\*\/))/mg;
    function parseParams(func) {
      func = func.toString().replace(STRIP_COMMENTS, "");
      func = func.match(FN_ARGS)[2].replace(" ", "");
      func = func ? func.split(FN_ARG_SPLIT) : [];
      func = func.map(function(arg) {
        return trim(arg.replace(FN_ARG, ""));
      });
      return func;
    }
    function autoInject(tasks, callback) {
      var newTasks = {};
      baseForOwn(tasks, function(taskFn, key) {
        var params;
        var fnIsAsync = isAsync(taskFn);
        var hasNoDeps = !fnIsAsync && taskFn.length === 1 || fnIsAsync && taskFn.length === 0;
        if (isArray2(taskFn)) {
          params = taskFn.slice(0, -1);
          taskFn = taskFn[taskFn.length - 1];
          newTasks[key] = params.concat(params.length > 0 ? newTask : taskFn);
        } else if (hasNoDeps) {
          newTasks[key] = taskFn;
        } else {
          params = parseParams(taskFn);
          if (taskFn.length === 0 && !fnIsAsync && params.length === 0) {
            throw new Error("autoInject task functions require explicit parameters.");
          }
          if (!fnIsAsync)
            params.pop();
          newTasks[key] = params.concat(newTask);
        }
        function newTask(results, taskCb) {
          var newArgs = arrayMap(params, function(name) {
            return results[name];
          });
          newArgs.push(taskCb);
          wrapAsync(taskFn).apply(null, newArgs);
        }
      });
      auto(newTasks, callback);
    }
    function DLL() {
      this.head = this.tail = null;
      this.length = 0;
    }
    function setInitial(dll, node) {
      dll.length = 1;
      dll.head = dll.tail = node;
    }
    DLL.prototype.removeLink = function(node) {
      if (node.prev)
        node.prev.next = node.next;
      else
        this.head = node.next;
      if (node.next)
        node.next.prev = node.prev;
      else
        this.tail = node.prev;
      node.prev = node.next = null;
      this.length -= 1;
      return node;
    };
    DLL.prototype.empty = function() {
      while (this.head)
        this.shift();
      return this;
    };
    DLL.prototype.insertAfter = function(node, newNode) {
      newNode.prev = node;
      newNode.next = node.next;
      if (node.next)
        node.next.prev = newNode;
      else
        this.tail = newNode;
      node.next = newNode;
      this.length += 1;
    };
    DLL.prototype.insertBefore = function(node, newNode) {
      newNode.prev = node.prev;
      newNode.next = node;
      if (node.prev)
        node.prev.next = newNode;
      else
        this.head = newNode;
      node.prev = newNode;
      this.length += 1;
    };
    DLL.prototype.unshift = function(node) {
      if (this.head)
        this.insertBefore(this.head, node);
      else
        setInitial(this, node);
    };
    DLL.prototype.push = function(node) {
      if (this.tail)
        this.insertAfter(this.tail, node);
      else
        setInitial(this, node);
    };
    DLL.prototype.shift = function() {
      return this.head && this.removeLink(this.head);
    };
    DLL.prototype.pop = function() {
      return this.tail && this.removeLink(this.tail);
    };
    DLL.prototype.toArray = function() {
      var arr = Array(this.length);
      var curr = this.head;
      for (var idx = 0; idx < this.length; idx++) {
        arr[idx] = curr.data;
        curr = curr.next;
      }
      return arr;
    };
    DLL.prototype.remove = function(testFn) {
      var curr = this.head;
      while (!!curr) {
        var next = curr.next;
        if (testFn(curr)) {
          this.removeLink(curr);
        }
        curr = next;
      }
      return this;
    };
    function queue(worker, concurrency, payload) {
      if (concurrency == null) {
        concurrency = 1;
      } else if (concurrency === 0) {
        throw new Error("Concurrency must not be zero");
      }
      var _worker = wrapAsync(worker);
      var numRunning = 0;
      var workersList = [];
      var processingScheduled = false;
      function _insert(data, insertAtFront, callback) {
        if (callback != null && typeof callback !== "function") {
          throw new Error("task callback must be a function");
        }
        q.started = true;
        if (!isArray2(data)) {
          data = [data];
        }
        if (data.length === 0 && q.idle()) {
          return setImmediate$1(function() {
            q.drain();
          });
        }
        for (var i = 0, l = data.length; i < l; i++) {
          var item = {
            data: data[i],
            callback: callback || noop
          };
          if (insertAtFront) {
            q._tasks.unshift(item);
          } else {
            q._tasks.push(item);
          }
        }
        if (!processingScheduled) {
          processingScheduled = true;
          setImmediate$1(function() {
            processingScheduled = false;
            q.process();
          });
        }
      }
      function _next(tasks) {
        return function(err) {
          numRunning -= 1;
          for (var i = 0, l = tasks.length; i < l; i++) {
            var task = tasks[i];
            var index2 = baseIndexOf(workersList, task, 0);
            if (index2 === 0) {
              workersList.shift();
            } else if (index2 > 0) {
              workersList.splice(index2, 1);
            }
            task.callback.apply(task, arguments);
            if (err != null) {
              q.error(err, task.data);
            }
          }
          if (numRunning <= q.concurrency - q.buffer) {
            q.unsaturated();
          }
          if (q.idle()) {
            q.drain();
          }
          q.process();
        };
      }
      var isProcessing = false;
      var q = {
        _tasks: new DLL(),
        concurrency,
        payload,
        saturated: noop,
        unsaturated: noop,
        buffer: concurrency / 4,
        empty: noop,
        drain: noop,
        error: noop,
        started: false,
        paused: false,
        push: function(data, callback) {
          _insert(data, false, callback);
        },
        kill: function() {
          q.drain = noop;
          q._tasks.empty();
        },
        unshift: function(data, callback) {
          _insert(data, true, callback);
        },
        remove: function(testFn) {
          q._tasks.remove(testFn);
        },
        process: function() {
          if (isProcessing) {
            return;
          }
          isProcessing = true;
          while (!q.paused && numRunning < q.concurrency && q._tasks.length) {
            var tasks = [], data = [];
            var l = q._tasks.length;
            if (q.payload)
              l = Math.min(l, q.payload);
            for (var i = 0; i < l; i++) {
              var node = q._tasks.shift();
              tasks.push(node);
              workersList.push(node);
              data.push(node.data);
            }
            numRunning += 1;
            if (q._tasks.length === 0) {
              q.empty();
            }
            if (numRunning === q.concurrency) {
              q.saturated();
            }
            var cb = onlyOnce(_next(tasks));
            _worker(data, cb);
          }
          isProcessing = false;
        },
        length: function() {
          return q._tasks.length;
        },
        running: function() {
          return numRunning;
        },
        workersList: function() {
          return workersList;
        },
        idle: function() {
          return q._tasks.length + numRunning === 0;
        },
        pause: function() {
          q.paused = true;
        },
        resume: function() {
          if (q.paused === false) {
            return;
          }
          q.paused = false;
          setImmediate$1(q.process);
        }
      };
      return q;
    }
    function cargo(worker, payload) {
      return queue(worker, 1, payload);
    }
    var eachOfSeries = doLimit(eachOfLimit, 1);
    function reduce(coll, memo, iteratee, callback) {
      callback = once3(callback || noop);
      var _iteratee = wrapAsync(iteratee);
      eachOfSeries(coll, function(x, i, callback2) {
        _iteratee(memo, x, function(err, v) {
          memo = v;
          callback2(err);
        });
      }, function(err) {
        callback(err, memo);
      });
    }
    function seq() {
      var _functions = arrayMap(arguments, wrapAsync);
      return function() {
        var args = slice(arguments);
        var that = this;
        var cb = args[args.length - 1];
        if (typeof cb == "function") {
          args.pop();
        } else {
          cb = noop;
        }
        reduce(_functions, args, function(newargs, fn, cb2) {
          fn.apply(that, newargs.concat(function(err) {
            var nextargs = slice(arguments, 1);
            cb2(err, nextargs);
          }));
        }, function(err, results) {
          cb.apply(that, [err].concat(results));
        });
      };
    }
    var compose = function() {
      return seq.apply(null, slice(arguments).reverse());
    };
    var _concat = Array.prototype.concat;
    var concatLimit = function(coll, limit, iteratee, callback) {
      callback = callback || noop;
      var _iteratee = wrapAsync(iteratee);
      mapLimit(coll, limit, function(val, callback2) {
        _iteratee(val, function(err) {
          if (err)
            return callback2(err);
          return callback2(null, slice(arguments, 1));
        });
      }, function(err, mapResults) {
        var result = [];
        for (var i = 0; i < mapResults.length; i++) {
          if (mapResults[i]) {
            result = _concat.apply(result, mapResults[i]);
          }
        }
        return callback(err, result);
      });
    };
    var concat = doLimit(concatLimit, Infinity);
    var concatSeries = doLimit(concatLimit, 1);
    var constant = function() {
      var values = slice(arguments);
      var args = [null].concat(values);
      return function() {
        var callback = arguments[arguments.length - 1];
        return callback.apply(this, args);
      };
    };
    function identity(value) {
      return value;
    }
    function _createTester(check, getResult) {
      return function(eachfn, arr, iteratee, cb) {
        cb = cb || noop;
        var testPassed = false;
        var testResult;
        eachfn(arr, function(value, _, callback) {
          iteratee(value, function(err, result) {
            if (err) {
              callback(err);
            } else if (check(result) && !testResult) {
              testPassed = true;
              testResult = getResult(true, value);
              callback(null, breakLoop);
            } else {
              callback();
            }
          });
        }, function(err) {
          if (err) {
            cb(err);
          } else {
            cb(null, testPassed ? testResult : getResult(false));
          }
        });
      };
    }
    function _findGetResult(v, x) {
      return x;
    }
    var detect = doParallel(_createTester(identity, _findGetResult));
    var detectLimit = doParallelLimit(_createTester(identity, _findGetResult));
    var detectSeries = doLimit(detectLimit, 1);
    function consoleFunc(name) {
      return function(fn) {
        var args = slice(arguments, 1);
        args.push(function(err) {
          var args2 = slice(arguments, 1);
          if (typeof console === "object") {
            if (err) {
              if (console.error) {
                console.error(err);
              }
            } else if (console[name]) {
              arrayEach(args2, function(x) {
                console[name](x);
              });
            }
          }
        });
        wrapAsync(fn).apply(null, args);
      };
    }
    var dir = consoleFunc("dir");
    function doDuring(fn, test, callback) {
      callback = onlyOnce(callback || noop);
      var _fn = wrapAsync(fn);
      var _test = wrapAsync(test);
      function next(err) {
        if (err)
          return callback(err);
        var args = slice(arguments, 1);
        args.push(check);
        _test.apply(this, args);
      }
      function check(err, truth) {
        if (err)
          return callback(err);
        if (!truth)
          return callback(null);
        _fn(next);
      }
      check(null, true);
    }
    function doWhilst(iteratee, test, callback) {
      callback = onlyOnce(callback || noop);
      var _iteratee = wrapAsync(iteratee);
      var next = function(err) {
        if (err)
          return callback(err);
        var args = slice(arguments, 1);
        if (test.apply(this, args))
          return _iteratee(next);
        callback.apply(null, [null].concat(args));
      };
      _iteratee(next);
    }
    function doUntil(iteratee, test, callback) {
      doWhilst(iteratee, function() {
        return !test.apply(this, arguments);
      }, callback);
    }
    function during(test, fn, callback) {
      callback = onlyOnce(callback || noop);
      var _fn = wrapAsync(fn);
      var _test = wrapAsync(test);
      function next(err) {
        if (err)
          return callback(err);
        _test(check);
      }
      function check(err, truth) {
        if (err)
          return callback(err);
        if (!truth)
          return callback(null);
        _fn(next);
      }
      _test(check);
    }
    function _withoutIndex(iteratee) {
      return function(value, index2, callback) {
        return iteratee(value, callback);
      };
    }
    function eachLimit(coll, iteratee, callback) {
      eachOf(coll, _withoutIndex(wrapAsync(iteratee)), callback);
    }
    function eachLimit$1(coll, limit, iteratee, callback) {
      _eachOfLimit(limit)(coll, _withoutIndex(wrapAsync(iteratee)), callback);
    }
    var eachSeries = doLimit(eachLimit$1, 1);
    function ensureAsync(fn) {
      if (isAsync(fn))
        return fn;
      return initialParams(function(args, callback) {
        var sync = true;
        args.push(function() {
          var innerArgs = arguments;
          if (sync) {
            setImmediate$1(function() {
              callback.apply(null, innerArgs);
            });
          } else {
            callback.apply(null, innerArgs);
          }
        });
        fn.apply(this, args);
        sync = false;
      });
    }
    function notId(v) {
      return !v;
    }
    var every = doParallel(_createTester(notId, notId));
    var everyLimit = doParallelLimit(_createTester(notId, notId));
    var everySeries = doLimit(everyLimit, 1);
    function baseProperty(key) {
      return function(object) {
        return object == null ? void 0 : object[key];
      };
    }
    function filterArray(eachfn, arr, iteratee, callback) {
      var truthValues = new Array(arr.length);
      eachfn(arr, function(x, index2, callback2) {
        iteratee(x, function(err, v) {
          truthValues[index2] = !!v;
          callback2(err);
        });
      }, function(err) {
        if (err)
          return callback(err);
        var results = [];
        for (var i = 0; i < arr.length; i++) {
          if (truthValues[i])
            results.push(arr[i]);
        }
        callback(null, results);
      });
    }
    function filterGeneric(eachfn, coll, iteratee, callback) {
      var results = [];
      eachfn(coll, function(x, index2, callback2) {
        iteratee(x, function(err, v) {
          if (err) {
            callback2(err);
          } else {
            if (v) {
              results.push({ index: index2, value: x });
            }
            callback2();
          }
        });
      }, function(err) {
        if (err) {
          callback(err);
        } else {
          callback(null, arrayMap(results.sort(function(a, b) {
            return a.index - b.index;
          }), baseProperty("value")));
        }
      });
    }
    function _filter(eachfn, coll, iteratee, callback) {
      var filter2 = isArrayLike(coll) ? filterArray : filterGeneric;
      filter2(eachfn, coll, wrapAsync(iteratee), callback || noop);
    }
    var filter = doParallel(_filter);
    var filterLimit = doParallelLimit(_filter);
    var filterSeries = doLimit(filterLimit, 1);
    function forever(fn, errback) {
      var done = onlyOnce(errback || noop);
      var task = wrapAsync(ensureAsync(fn));
      function next(err) {
        if (err)
          return done(err);
        task(next);
      }
      next();
    }
    var groupByLimit = function(coll, limit, iteratee, callback) {
      callback = callback || noop;
      var _iteratee = wrapAsync(iteratee);
      mapLimit(coll, limit, function(val, callback2) {
        _iteratee(val, function(err, key) {
          if (err)
            return callback2(err);
          return callback2(null, { key, val });
        });
      }, function(err, mapResults) {
        var result = {};
        var hasOwnProperty2 = Object.prototype.hasOwnProperty;
        for (var i = 0; i < mapResults.length; i++) {
          if (mapResults[i]) {
            var key = mapResults[i].key;
            var val = mapResults[i].val;
            if (hasOwnProperty2.call(result, key)) {
              result[key].push(val);
            } else {
              result[key] = [val];
            }
          }
        }
        return callback(err, result);
      });
    };
    var groupBy = doLimit(groupByLimit, Infinity);
    var groupBySeries = doLimit(groupByLimit, 1);
    var log = consoleFunc("log");
    function mapValuesLimit(obj, limit, iteratee, callback) {
      callback = once3(callback || noop);
      var newObj = {};
      var _iteratee = wrapAsync(iteratee);
      eachOfLimit(obj, limit, function(val, key, next) {
        _iteratee(val, key, function(err, result) {
          if (err)
            return next(err);
          newObj[key] = result;
          next();
        });
      }, function(err) {
        callback(err, newObj);
      });
    }
    var mapValues = doLimit(mapValuesLimit, Infinity);
    var mapValuesSeries = doLimit(mapValuesLimit, 1);
    function has(obj, key) {
      return key in obj;
    }
    function memoize(fn, hasher) {
      var memo = /* @__PURE__ */ Object.create(null);
      var queues = /* @__PURE__ */ Object.create(null);
      hasher = hasher || identity;
      var _fn = wrapAsync(fn);
      var memoized = initialParams(function memoized2(args, callback) {
        var key = hasher.apply(null, args);
        if (has(memo, key)) {
          setImmediate$1(function() {
            callback.apply(null, memo[key]);
          });
        } else if (has(queues, key)) {
          queues[key].push(callback);
        } else {
          queues[key] = [callback];
          _fn.apply(null, args.concat(function() {
            var args2 = slice(arguments);
            memo[key] = args2;
            var q = queues[key];
            delete queues[key];
            for (var i = 0, l = q.length; i < l; i++) {
              q[i].apply(null, args2);
            }
          }));
        }
      });
      memoized.memo = memo;
      memoized.unmemoized = fn;
      return memoized;
    }
    var _defer$1;
    if (hasNextTick) {
      _defer$1 = process.nextTick;
    } else if (hasSetImmediate) {
      _defer$1 = setImmediate;
    } else {
      _defer$1 = fallback;
    }
    var nextTick = wrap(_defer$1);
    function _parallel(eachfn, tasks, callback) {
      callback = callback || noop;
      var results = isArrayLike(tasks) ? [] : {};
      eachfn(tasks, function(task, key, callback2) {
        wrapAsync(task)(function(err, result) {
          if (arguments.length > 2) {
            result = slice(arguments, 1);
          }
          results[key] = result;
          callback2(err);
        });
      }, function(err) {
        callback(err, results);
      });
    }
    function parallelLimit(tasks, callback) {
      _parallel(eachOf, tasks, callback);
    }
    function parallelLimit$1(tasks, limit, callback) {
      _parallel(_eachOfLimit(limit), tasks, callback);
    }
    var queue$1 = function(worker, concurrency) {
      var _worker = wrapAsync(worker);
      return queue(function(items, cb) {
        _worker(items[0], cb);
      }, concurrency, 1);
    };
    var priorityQueue = function(worker, concurrency) {
      var q = queue$1(worker, concurrency);
      q.push = function(data, priority, callback) {
        if (callback == null)
          callback = noop;
        if (typeof callback !== "function") {
          throw new Error("task callback must be a function");
        }
        q.started = true;
        if (!isArray2(data)) {
          data = [data];
        }
        if (data.length === 0) {
          return setImmediate$1(function() {
            q.drain();
          });
        }
        priority = priority || 0;
        var nextNode = q._tasks.head;
        while (nextNode && priority >= nextNode.priority) {
          nextNode = nextNode.next;
        }
        for (var i = 0, l = data.length; i < l; i++) {
          var item = {
            data: data[i],
            priority,
            callback
          };
          if (nextNode) {
            q._tasks.insertBefore(nextNode, item);
          } else {
            q._tasks.push(item);
          }
        }
        setImmediate$1(q.process);
      };
      delete q.unshift;
      return q;
    };
    function race(tasks, callback) {
      callback = once3(callback || noop);
      if (!isArray2(tasks))
        return callback(new TypeError("First argument to race must be an array of functions"));
      if (!tasks.length)
        return callback();
      for (var i = 0, l = tasks.length; i < l; i++) {
        wrapAsync(tasks[i])(callback);
      }
    }
    function reduceRight(array, memo, iteratee, callback) {
      var reversed = slice(array).reverse();
      reduce(reversed, memo, iteratee, callback);
    }
    function reflect(fn) {
      var _fn = wrapAsync(fn);
      return initialParams(function reflectOn(args, reflectCallback) {
        args.push(function callback(error2, cbArg) {
          if (error2) {
            reflectCallback(null, { error: error2 });
          } else {
            var value;
            if (arguments.length <= 2) {
              value = cbArg;
            } else {
              value = slice(arguments, 1);
            }
            reflectCallback(null, { value });
          }
        });
        return _fn.apply(this, args);
      });
    }
    function reflectAll(tasks) {
      var results;
      if (isArray2(tasks)) {
        results = arrayMap(tasks, reflect);
      } else {
        results = {};
        baseForOwn(tasks, function(task, key) {
          results[key] = reflect.call(this, task);
        });
      }
      return results;
    }
    function reject$1(eachfn, arr, iteratee, callback) {
      _filter(eachfn, arr, function(value, cb) {
        iteratee(value, function(err, v) {
          cb(err, !v);
        });
      }, callback);
    }
    var reject = doParallel(reject$1);
    var rejectLimit = doParallelLimit(reject$1);
    var rejectSeries = doLimit(rejectLimit, 1);
    function constant$1(value) {
      return function() {
        return value;
      };
    }
    function retry(opts, task, callback) {
      var DEFAULT_TIMES = 5;
      var DEFAULT_INTERVAL = 0;
      var options = {
        times: DEFAULT_TIMES,
        intervalFunc: constant$1(DEFAULT_INTERVAL)
      };
      function parseTimes(acc, t) {
        if (typeof t === "object") {
          acc.times = +t.times || DEFAULT_TIMES;
          acc.intervalFunc = typeof t.interval === "function" ? t.interval : constant$1(+t.interval || DEFAULT_INTERVAL);
          acc.errorFilter = t.errorFilter;
        } else if (typeof t === "number" || typeof t === "string") {
          acc.times = +t || DEFAULT_TIMES;
        } else {
          throw new Error("Invalid arguments for async.retry");
        }
      }
      if (arguments.length < 3 && typeof opts === "function") {
        callback = task || noop;
        task = opts;
      } else {
        parseTimes(options, opts);
        callback = callback || noop;
      }
      if (typeof task !== "function") {
        throw new Error("Invalid arguments for async.retry");
      }
      var _task = wrapAsync(task);
      var attempt = 1;
      function retryAttempt() {
        _task(function(err) {
          if (err && attempt++ < options.times && (typeof options.errorFilter != "function" || options.errorFilter(err))) {
            setTimeout(retryAttempt, options.intervalFunc(attempt));
          } else {
            callback.apply(null, arguments);
          }
        });
      }
      retryAttempt();
    }
    var retryable = function(opts, task) {
      if (!task) {
        task = opts;
        opts = null;
      }
      var _task = wrapAsync(task);
      return initialParams(function(args, callback) {
        function taskFn(cb) {
          _task.apply(null, args.concat(cb));
        }
        if (opts)
          retry(opts, taskFn, callback);
        else
          retry(taskFn, callback);
      });
    };
    function series(tasks, callback) {
      _parallel(eachOfSeries, tasks, callback);
    }
    var some = doParallel(_createTester(Boolean, identity));
    var someLimit = doParallelLimit(_createTester(Boolean, identity));
    var someSeries = doLimit(someLimit, 1);
    function sortBy(coll, iteratee, callback) {
      var _iteratee = wrapAsync(iteratee);
      map(coll, function(x, callback2) {
        _iteratee(x, function(err, criteria) {
          if (err)
            return callback2(err);
          callback2(null, { value: x, criteria });
        });
      }, function(err, results) {
        if (err)
          return callback(err);
        callback(null, arrayMap(results.sort(comparator), baseProperty("value")));
      });
      function comparator(left, right) {
        var a = left.criteria, b = right.criteria;
        return a < b ? -1 : a > b ? 1 : 0;
      }
    }
    function timeout(asyncFn, milliseconds, info) {
      var fn = wrapAsync(asyncFn);
      return initialParams(function(args, callback) {
        var timedOut = false;
        var timer;
        function timeoutCallback() {
          var name = asyncFn.name || "anonymous";
          var error2 = new Error('Callback function "' + name + '" timed out.');
          error2.code = "ETIMEDOUT";
          if (info) {
            error2.info = info;
          }
          timedOut = true;
          callback(error2);
        }
        args.push(function() {
          if (!timedOut) {
            callback.apply(null, arguments);
            clearTimeout(timer);
          }
        });
        timer = setTimeout(timeoutCallback, milliseconds);
        fn.apply(null, args);
      });
    }
    var nativeCeil = Math.ceil;
    var nativeMax2 = Math.max;
    function baseRange(start, end, step, fromRight) {
      var index2 = -1, length = nativeMax2(nativeCeil((end - start) / (step || 1)), 0), result = Array(length);
      while (length--) {
        result[fromRight ? length : ++index2] = start;
        start += step;
      }
      return result;
    }
    function timeLimit(count, limit, iteratee, callback) {
      var _iteratee = wrapAsync(iteratee);
      mapLimit(baseRange(0, count, 1), limit, _iteratee, callback);
    }
    var times = doLimit(timeLimit, Infinity);
    var timesSeries = doLimit(timeLimit, 1);
    function transform(coll, accumulator, iteratee, callback) {
      if (arguments.length <= 3) {
        callback = iteratee;
        iteratee = accumulator;
        accumulator = isArray2(coll) ? [] : {};
      }
      callback = once3(callback || noop);
      var _iteratee = wrapAsync(iteratee);
      eachOf(coll, function(v, k, cb) {
        _iteratee(accumulator, v, k, cb);
      }, function(err) {
        callback(err, accumulator);
      });
    }
    function tryEach(tasks, callback) {
      var error2 = null;
      var result;
      callback = callback || noop;
      eachSeries(tasks, function(task, callback2) {
        wrapAsync(task)(function(err, res) {
          if (arguments.length > 2) {
            result = slice(arguments, 1);
          } else {
            result = res;
          }
          error2 = err;
          callback2(!err);
        });
      }, function() {
        callback(error2, result);
      });
    }
    function unmemoize(fn) {
      return function() {
        return (fn.unmemoized || fn).apply(null, arguments);
      };
    }
    function whilst(test, iteratee, callback) {
      callback = onlyOnce(callback || noop);
      var _iteratee = wrapAsync(iteratee);
      if (!test())
        return callback(null);
      var next = function(err) {
        if (err)
          return callback(err);
        if (test())
          return _iteratee(next);
        var args = slice(arguments, 1);
        callback.apply(null, [null].concat(args));
      };
      _iteratee(next);
    }
    function until(test, iteratee, callback) {
      whilst(function() {
        return !test.apply(this, arguments);
      }, iteratee, callback);
    }
    var waterfall = function(tasks, callback) {
      callback = once3(callback || noop);
      if (!isArray2(tasks))
        return callback(new Error("First argument to waterfall must be an array of functions"));
      if (!tasks.length)
        return callback();
      var taskIndex = 0;
      function nextTask(args) {
        var task = wrapAsync(tasks[taskIndex++]);
        args.push(onlyOnce(next));
        task.apply(null, args);
      }
      function next(err) {
        if (err || taskIndex === tasks.length) {
          return callback.apply(null, arguments);
        }
        nextTask(slice(arguments, 1));
      }
      nextTask([]);
    };
    var index = {
      apply,
      applyEach,
      applyEachSeries,
      asyncify,
      auto,
      autoInject,
      cargo,
      compose,
      concat,
      concatLimit,
      concatSeries,
      constant,
      detect,
      detectLimit,
      detectSeries,
      dir,
      doDuring,
      doUntil,
      doWhilst,
      during,
      each: eachLimit,
      eachLimit: eachLimit$1,
      eachOf,
      eachOfLimit,
      eachOfSeries,
      eachSeries,
      ensureAsync,
      every,
      everyLimit,
      everySeries,
      filter,
      filterLimit,
      filterSeries,
      forever,
      groupBy,
      groupByLimit,
      groupBySeries,
      log,
      map,
      mapLimit,
      mapSeries,
      mapValues,
      mapValuesLimit,
      mapValuesSeries,
      memoize,
      nextTick,
      parallel: parallelLimit,
      parallelLimit: parallelLimit$1,
      priorityQueue,
      queue: queue$1,
      race,
      reduce,
      reduceRight,
      reflect,
      reflectAll,
      reject,
      rejectLimit,
      rejectSeries,
      retry,
      retryable,
      seq,
      series,
      setImmediate: setImmediate$1,
      some,
      someLimit,
      someSeries,
      sortBy,
      timeout,
      times,
      timesLimit: timeLimit,
      timesSeries,
      transform,
      tryEach,
      unmemoize,
      until,
      waterfall,
      whilst,
      all: every,
      allLimit: everyLimit,
      allSeries: everySeries,
      any: some,
      anyLimit: someLimit,
      anySeries: someSeries,
      find: detect,
      findLimit: detectLimit,
      findSeries: detectSeries,
      forEach: eachLimit,
      forEachSeries: eachSeries,
      forEachLimit: eachLimit$1,
      forEachOf: eachOf,
      forEachOfSeries: eachOfSeries,
      forEachOfLimit: eachOfLimit,
      inject: reduce,
      foldl: reduce,
      foldr: reduceRight,
      select: filter,
      selectLimit: filterLimit,
      selectSeries: filterSeries,
      wrapSync: asyncify
    };
    exports2["default"] = index;
    exports2.apply = apply;
    exports2.applyEach = applyEach;
    exports2.applyEachSeries = applyEachSeries;
    exports2.asyncify = asyncify;
    exports2.auto = auto;
    exports2.autoInject = autoInject;
    exports2.cargo = cargo;
    exports2.compose = compose;
    exports2.concat = concat;
    exports2.concatLimit = concatLimit;
    exports2.concatSeries = concatSeries;
    exports2.constant = constant;
    exports2.detect = detect;
    exports2.detectLimit = detectLimit;
    exports2.detectSeries = detectSeries;
    exports2.dir = dir;
    exports2.doDuring = doDuring;
    exports2.doUntil = doUntil;
    exports2.doWhilst = doWhilst;
    exports2.during = during;
    exports2.each = eachLimit;
    exports2.eachLimit = eachLimit$1;
    exports2.eachOf = eachOf;
    exports2.eachOfLimit = eachOfLimit;
    exports2.eachOfSeries = eachOfSeries;
    exports2.eachSeries = eachSeries;
    exports2.ensureAsync = ensureAsync;
    exports2.every = every;
    exports2.everyLimit = everyLimit;
    exports2.everySeries = everySeries;
    exports2.filter = filter;
    exports2.filterLimit = filterLimit;
    exports2.filterSeries = filterSeries;
    exports2.forever = forever;
    exports2.groupBy = groupBy;
    exports2.groupByLimit = groupByLimit;
    exports2.groupBySeries = groupBySeries;
    exports2.log = log;
    exports2.map = map;
    exports2.mapLimit = mapLimit;
    exports2.mapSeries = mapSeries;
    exports2.mapValues = mapValues;
    exports2.mapValuesLimit = mapValuesLimit;
    exports2.mapValuesSeries = mapValuesSeries;
    exports2.memoize = memoize;
    exports2.nextTick = nextTick;
    exports2.parallel = parallelLimit;
    exports2.parallelLimit = parallelLimit$1;
    exports2.priorityQueue = priorityQueue;
    exports2.queue = queue$1;
    exports2.race = race;
    exports2.reduce = reduce;
    exports2.reduceRight = reduceRight;
    exports2.reflect = reflect;
    exports2.reflectAll = reflectAll;
    exports2.reject = reject;
    exports2.rejectLimit = rejectLimit;
    exports2.rejectSeries = rejectSeries;
    exports2.retry = retry;
    exports2.retryable = retryable;
    exports2.seq = seq;
    exports2.series = series;
    exports2.setImmediate = setImmediate$1;
    exports2.some = some;
    exports2.someLimit = someLimit;
    exports2.someSeries = someSeries;
    exports2.sortBy = sortBy;
    exports2.timeout = timeout;
    exports2.times = times;
    exports2.timesLimit = timeLimit;
    exports2.timesSeries = timesSeries;
    exports2.transform = transform;
    exports2.tryEach = tryEach;
    exports2.unmemoize = unmemoize;
    exports2.until = until;
    exports2.waterfall = waterfall;
    exports2.whilst = whilst;
    exports2.all = every;
    exports2.allLimit = everyLimit;
    exports2.allSeries = everySeries;
    exports2.any = some;
    exports2.anyLimit = someLimit;
    exports2.anySeries = someSeries;
    exports2.find = detect;
    exports2.findLimit = detectLimit;
    exports2.findSeries = detectSeries;
    exports2.forEach = eachLimit;
    exports2.forEachSeries = eachSeries;
    exports2.forEachLimit = eachLimit$1;
    exports2.forEachOf = eachOf;
    exports2.forEachOfSeries = eachOfSeries;
    exports2.forEachOfLimit = eachOfLimit;
    exports2.inject = reduce;
    exports2.foldl = reduce;
    exports2.foldr = reduceRight;
    exports2.select = filter;
    exports2.selectLimit = filterLimit;
    exports2.selectSeries = filterSeries;
    exports2.wrapSync = asyncify;
    Object.defineProperty(exports2, "__esModule", { value: true });
  });
})(async$1, async$1.exports);
var hat$2 = { exports: {} };
var hat$1 = hat$2.exports = function(bits, base) {
  if (!base)
    base = 16;
  if (bits === void 0)
    bits = 128;
  if (bits <= 0)
    return "0";
  var digits = Math.log(Math.pow(2, bits)) / Math.log(base);
  for (var i = 2; digits === Infinity; i *= 2) {
    digits = Math.log(Math.pow(2, bits / i)) / Math.log(base) * i;
  }
  var rem = digits - Math.floor(digits);
  var res = "";
  for (var i = 0; i < Math.floor(digits); i++) {
    var x = Math.floor(Math.random() * base).toString(base);
    res = x + res;
  }
  if (rem) {
    var b = Math.pow(base, rem);
    var x = Math.floor(Math.random() * b).toString(base);
    res = x + res;
  }
  var parsed = parseInt(res, base);
  if (parsed !== Infinity && parsed >= Math.pow(2, bits)) {
    return hat$1(bits, base);
  } else
    return res;
};
hat$1.rack = function(bits, base, expandBy) {
  var fn = function(data) {
    var iters = 0;
    do {
      if (iters++ > 10) {
        if (expandBy)
          bits += expandBy;
        else
          throw new Error("too many ID collisions, use more bits");
      }
      var id = hat$1(bits, base);
    } while (Object.hasOwnProperty.call(hats, id));
    hats[id] = data;
    return id;
  };
  var hats = fn.hats = {};
  fn.get = function(id) {
    return fn.hats[id];
  };
  fn.set = function(id, value) {
    fn.hats[id] = value;
    return fn;
  };
  fn.bits = bits || 128;
  fn.base = base || 16;
  return fn;
};
var emitter$2 = emitter$6;
var LocalPresence$1 = localPresence;
var RemotePresence$1 = remotePresence;
var util$4 = util$9;
var async = async$1.exports;
var hat = hat$2.exports;
var presence = Presence$2;
function Presence$2(connection2, channel) {
  emitter$2.EventEmitter.call(this);
  if (!channel || typeof channel !== "string") {
    throw new Error("Presence channel must be provided");
  }
  this.connection = connection2;
  this.channel = channel;
  this.wantSubscribe = false;
  this.subscribed = false;
  this.remotePresences = {};
  this.localPresences = {};
  this._remotePresenceInstances = {};
  this._subscriptionCallbacksBySeq = {};
}
emitter$2.mixin(Presence$2);
Presence$2.prototype.subscribe = function(callback) {
  this._sendSubscriptionAction(true, callback);
};
Presence$2.prototype.unsubscribe = function(callback) {
  this._sendSubscriptionAction(false, callback);
};
Presence$2.prototype.create = function(id) {
  id = id || hat();
  var localPresence2 = this._createLocalPresence(id);
  this.localPresences[id] = localPresence2;
  return localPresence2;
};
Presence$2.prototype.destroy = function(callback) {
  var presence2 = this;
  this.unsubscribe(function(error2) {
    if (error2)
      return presence2._callbackOrEmit(error2, callback);
    var localIds = Object.keys(presence2.localPresences);
    var remoteIds = Object.keys(presence2._remotePresenceInstances);
    async.parallel([
      function(next) {
        async.each(localIds, function(presenceId, next2) {
          presence2.localPresences[presenceId].destroy(next2);
        }, next);
      },
      function(next) {
        async.each(remoteIds, function(presenceId, next2) {
          presence2._remotePresenceInstances[presenceId].destroy(next2);
        }, next);
      }
    ], function(error3) {
      delete presence2.connection._presences[presence2.channel];
      presence2._callbackOrEmit(error3, callback);
    });
  });
};
Presence$2.prototype._sendSubscriptionAction = function(wantSubscribe, callback) {
  this.wantSubscribe = !!wantSubscribe;
  var action = this.wantSubscribe ? "ps" : "pu";
  var seq = this.connection._presenceSeq++;
  this._subscriptionCallbacksBySeq[seq] = callback;
  if (this.connection.canSend) {
    this.connection._sendPresenceAction(action, seq, this);
  }
};
Presence$2.prototype._handleSubscribe = function(error2, seq) {
  if (this.wantSubscribe)
    this.subscribed = true;
  var callback = this._subscriptionCallback(seq);
  this._callbackOrEmit(error2, callback);
};
Presence$2.prototype._handleUnsubscribe = function(error2, seq) {
  this.subscribed = false;
  var callback = this._subscriptionCallback(seq);
  this._callbackOrEmit(error2, callback);
};
Presence$2.prototype._receiveUpdate = function(error2, message) {
  var localPresence2 = util$4.dig(this.localPresences, message.id);
  if (localPresence2)
    return localPresence2._ack(error2, message.pv);
  if (error2)
    return this.emit("error", error2);
  var presence2 = this;
  var remotePresence2 = util$4.digOrCreate(this._remotePresenceInstances, message.id, function() {
    return presence2._createRemotePresence(message.id);
  });
  remotePresence2.receiveUpdate(message);
};
Presence$2.prototype._updateRemotePresence = function(remotePresence2) {
  this.remotePresences[remotePresence2.presenceId] = remotePresence2.value;
  if (remotePresence2.value === null)
    this._removeRemotePresence(remotePresence2.presenceId);
  this.emit("receive", remotePresence2.presenceId, remotePresence2.value);
};
Presence$2.prototype._broadcastAllLocalPresence = function(error2) {
  if (error2)
    return this.emit("error", error2);
  for (var id in this.localPresences) {
    var localPresence2 = this.localPresences[id];
    if (localPresence2.value !== null)
      localPresence2.send();
  }
};
Presence$2.prototype._removeRemotePresence = function(id) {
  this._remotePresenceInstances[id].destroy();
  delete this._remotePresenceInstances[id];
  delete this.remotePresences[id];
};
Presence$2.prototype._onConnectionStateChanged = function() {
  if (!this.connection.canSend)
    return;
  this._resubscribe();
  for (var id in this.localPresences) {
    this.localPresences[id]._sendPending();
  }
};
Presence$2.prototype._resubscribe = function() {
  var callbacks = [];
  for (var seq in this._subscriptionCallbacksBySeq) {
    var callback = this._subscriptionCallback(seq);
    callbacks.push(callback);
  }
  if (!this.wantSubscribe)
    return this._callEachOrEmit(callbacks);
  var presence2 = this;
  this.subscribe(function(error2) {
    presence2._callEachOrEmit(callbacks, error2);
  });
};
Presence$2.prototype._subscriptionCallback = function(seq) {
  var callback = this._subscriptionCallbacksBySeq[seq];
  delete this._subscriptionCallbacksBySeq[seq];
  return callback;
};
Presence$2.prototype._callbackOrEmit = function(error2, callback) {
  if (callback)
    return util$4.nextTick(callback, error2);
  if (error2)
    this.emit("error", error2);
};
Presence$2.prototype._createLocalPresence = function(id) {
  return new LocalPresence$1(this, id);
};
Presence$2.prototype._createRemotePresence = function(id) {
  return new RemotePresence$1(this, id);
};
Presence$2.prototype._callEachOrEmit = function(callbacks, error2) {
  var called = util$4.callEach(callbacks, error2);
  if (!called && error2)
    this.emit("error", error2);
};
var LocalPresence = localPresence;
var ShareDBError$1 = error;
var util$3 = util$9;
var ERROR_CODE$1 = ShareDBError$1.CODES;
var localDocPresence = LocalDocPresence$1;
function LocalDocPresence$1(presence2, presenceId) {
  LocalPresence.call(this, presence2, presenceId);
  this.collection = this.presence.collection;
  this.id = this.presence.id;
  this._doc = this.connection.get(this.collection, this.id);
  this._isSending = false;
  this._docDataVersionByPresenceVersion = {};
  this._opHandler = this._transformAgainstOp.bind(this);
  this._createOrDelHandler = this._handleCreateOrDel.bind(this);
  this._loadHandler = this._handleLoad.bind(this);
  this._destroyHandler = this.destroy.bind(this);
  this._registerWithDoc();
}
LocalDocPresence$1.prototype = Object.create(LocalPresence.prototype);
LocalDocPresence$1.prototype.submit = function(value, callback) {
  if (!this._doc.type) {
    if (value === null)
      return this._callbackOrEmit(null, callback);
    var error2 = {
      code: ERROR_CODE$1.ERR_DOC_DOES_NOT_EXIST,
      message: "Cannot submit presence. Document has not been created"
    };
    return this._callbackOrEmit(error2, callback);
  }
  this._docDataVersionByPresenceVersion[this.presenceVersion] = this._doc._dataStateVersion;
  LocalPresence.prototype.submit.call(this, value, callback);
};
LocalDocPresence$1.prototype.destroy = function(callback) {
  this._doc.removeListener("op", this._opHandler);
  this._doc.removeListener("create", this._createOrDelHandler);
  this._doc.removeListener("del", this._createOrDelHandler);
  this._doc.removeListener("load", this._loadHandler);
  this._doc.removeListener("destroy", this._destroyHandler);
  LocalPresence.prototype.destroy.call(this, callback);
};
LocalDocPresence$1.prototype._sendPending = function() {
  if (this._isSending)
    return;
  this._isSending = true;
  var presence2 = this;
  this._doc.whenNothingPending(function() {
    presence2._isSending = false;
    if (!presence2.connection.canSend)
      return;
    presence2._pendingMessages.forEach(function(message) {
      message.t = presence2._doc.type.uri;
      message.v = presence2._doc.version;
      presence2.connection.send(message);
    });
    presence2._pendingMessages = [];
    presence2._docDataVersionByPresenceVersion = {};
  });
};
LocalDocPresence$1.prototype._registerWithDoc = function() {
  this._doc.on("op", this._opHandler);
  this._doc.on("create", this._createOrDelHandler);
  this._doc.on("del", this._createOrDelHandler);
  this._doc.on("load", this._loadHandler);
  this._doc.on("destroy", this._destroyHandler);
};
LocalDocPresence$1.prototype._transformAgainstOp = function(op, source) {
  var presence2 = this;
  var docDataVersion = this._doc._dataStateVersion;
  this._pendingMessages.forEach(function(message) {
    var messageDocDataVersion = presence2._docDataVersionByPresenceVersion[message.pv];
    if (messageDocDataVersion >= docDataVersion)
      return;
    try {
      message.p = presence2._transformPresence(message.p, op, source);
      presence2._docDataVersionByPresenceVersion[message.pv] = docDataVersion;
    } catch (error2) {
      var callback = presence2._getCallback(message.pv);
      presence2._callbackOrEmit(error2, callback);
    }
  });
  try {
    this.value = this._transformPresence(this.value, op, source);
  } catch (error2) {
    this.emit("error", error2);
  }
};
LocalDocPresence$1.prototype._handleCreateOrDel = function() {
  this._pendingMessages.forEach(function(message) {
    message.p = null;
  });
  this.value = null;
};
LocalDocPresence$1.prototype._handleLoad = function() {
  this.value = null;
  this._pendingMessages = [];
  this._docDataVersionByPresenceVersion = {};
};
LocalDocPresence$1.prototype._message = function() {
  var message = LocalPresence.prototype._message.call(this);
  message.c = this.collection, message.d = this.id, message.v = null;
  message.t = null;
  return message;
};
LocalDocPresence$1.prototype._transformPresence = function(value, op, source) {
  var type = this._doc.type;
  if (!util$3.supportsPresence(type)) {
    throw new ShareDBError$1(ERROR_CODE$1.ERR_TYPE_DOES_NOT_SUPPORT_PRESENCE, "Type does not support presence: " + type.name);
  }
  return type.transformPresence(value, op, source);
};
var ot$1 = {};
(function(exports) {
  var types2 = types$3;
  var ShareDBError2 = error;
  var util2 = util$9;
  var ERROR_CODE2 = ShareDBError2.CODES;
  exports.checkOp = function(op) {
    if (op == null || typeof op !== "object") {
      return new ShareDBError2(ERROR_CODE2.ERR_OT_OP_BADLY_FORMED, "Op must be an object");
    }
    if (op.create != null) {
      if (typeof op.create !== "object") {
        return new ShareDBError2(ERROR_CODE2.ERR_OT_OP_BADLY_FORMED, "Create data must be an object");
      }
      var typeName = op.create.type;
      if (typeof typeName !== "string") {
        return new ShareDBError2(ERROR_CODE2.ERR_OT_OP_BADLY_FORMED, "Missing create type");
      }
      var type = types2.map[typeName];
      if (type == null || typeof type !== "object") {
        return new ShareDBError2(ERROR_CODE2.ERR_DOC_TYPE_NOT_RECOGNIZED, "Unknown type");
      }
    } else if (op.del != null) {
      if (op.del !== true)
        return new ShareDBError2(ERROR_CODE2.ERR_OT_OP_BADLY_FORMED, "del value must be true");
    } else if (!("op" in op)) {
      return new ShareDBError2(ERROR_CODE2.ERR_OT_OP_BADLY_FORMED, "Missing op, create, or del");
    }
    if (op.src != null && typeof op.src !== "string") {
      return new ShareDBError2(ERROR_CODE2.ERR_OT_OP_BADLY_FORMED, "src must be a string");
    }
    if (op.seq != null && typeof op.seq !== "number") {
      return new ShareDBError2(ERROR_CODE2.ERR_OT_OP_BADLY_FORMED, "seq must be a number");
    }
    if (op.src == null && op.seq != null || op.src != null && op.seq == null) {
      return new ShareDBError2(ERROR_CODE2.ERR_OT_OP_BADLY_FORMED, "Both src and seq must be set together");
    }
    if (op.m != null && typeof op.m !== "object") {
      return new ShareDBError2(ERROR_CODE2.ERR_OT_OP_BADLY_FORMED, "op.m must be an object or null");
    }
  };
  exports.normalizeType = function(typeName) {
    return types2.map[typeName] && types2.map[typeName].uri;
  };
  exports.apply = function(snapshot2, op) {
    if (typeof snapshot2 !== "object") {
      return new ShareDBError2(ERROR_CODE2.ERR_APPLY_SNAPSHOT_NOT_PROVIDED, "Missing snapshot");
    }
    if (snapshot2.v != null && op.v != null && snapshot2.v !== op.v) {
      return new ShareDBError2(ERROR_CODE2.ERR_APPLY_OP_VERSION_DOES_NOT_MATCH_SNAPSHOT, "Version mismatch");
    }
    if (op.create) {
      if (snapshot2.type)
        return new ShareDBError2(ERROR_CODE2.ERR_DOC_ALREADY_CREATED, "Document already exists");
      var create = op.create;
      var type = types2.map[create.type];
      if (!type)
        return new ShareDBError2(ERROR_CODE2.ERR_DOC_TYPE_NOT_RECOGNIZED, "Unknown type");
      try {
        snapshot2.data = type.create(create.data);
        snapshot2.type = type.uri;
        snapshot2.v++;
      } catch (err2) {
        return err2;
      }
    } else if (op.del) {
      snapshot2.data = void 0;
      snapshot2.type = null;
      snapshot2.v++;
    } else if ("op" in op) {
      var err = applyOpEdit(snapshot2, op.op);
      if (err)
        return err;
      snapshot2.v++;
    } else {
      snapshot2.v++;
    }
  };
  function applyOpEdit(snapshot2, edit) {
    if (!snapshot2.type)
      return new ShareDBError2(ERROR_CODE2.ERR_DOC_DOES_NOT_EXIST, "Document does not exist");
    if (edit === void 0)
      return new ShareDBError2(ERROR_CODE2.ERR_OT_OP_NOT_PROVIDED, "Missing op");
    var type = types2.map[snapshot2.type];
    if (!type)
      return new ShareDBError2(ERROR_CODE2.ERR_DOC_TYPE_NOT_RECOGNIZED, "Unknown type");
    try {
      snapshot2.data = type.apply(snapshot2.data, edit);
    } catch (err) {
      return new ShareDBError2(ERROR_CODE2.ERR_OT_OP_NOT_APPLIED, err.message);
    }
  }
  exports.transform = function(type, op, appliedOp) {
    if (op.v != null && op.v !== appliedOp.v) {
      return new ShareDBError2(ERROR_CODE2.ERR_OP_VERSION_MISMATCH_DURING_TRANSFORM, "Version mismatch");
    }
    if (appliedOp.del) {
      if (op.create || "op" in op) {
        return new ShareDBError2(ERROR_CODE2.ERR_DOC_WAS_DELETED, "Document was deleted");
      }
    } else if (appliedOp.create && ("op" in op || op.create || op.del) || "op" in appliedOp && op.create) {
      return new ShareDBError2(ERROR_CODE2.ERR_DOC_ALREADY_CREATED, "Document was created remotely");
    } else if ("op" in appliedOp && "op" in op) {
      if (!type)
        return new ShareDBError2(ERROR_CODE2.ERR_DOC_DOES_NOT_EXIST, "Document does not exist");
      if (typeof type === "string") {
        type = types2.map[type];
        if (!type)
          return new ShareDBError2(ERROR_CODE2.ERR_DOC_TYPE_NOT_RECOGNIZED, "Unknown type");
      }
      try {
        op.op = type.transform(op.op, appliedOp.op, "left");
      } catch (err) {
        return err;
      }
    }
    if (op.v != null)
      op.v++;
  };
  exports.applyOps = function(snapshot2, ops, options) {
    options = options || {};
    for (var index = 0; index < ops.length; index++) {
      var op = ops[index];
      if (options._normalizeLegacyJson0Ops) {
        try {
          normalizeLegacyJson0Ops(snapshot2, op);
        } catch (error3) {
          return new ShareDBError2(ERROR_CODE2.ERR_OT_LEGACY_JSON0_OP_CANNOT_BE_NORMALIZED, "Cannot normalize legacy json0 op");
        }
      }
      snapshot2.v = op.v;
      var error2 = exports.apply(snapshot2, op);
      if (error2)
        return error2;
    }
  };
  exports.transformPresence = function(presence2, op, isOwnOp) {
    var opError = this.checkOp(op);
    if (opError)
      return opError;
    var type = presence2.t;
    if (typeof type === "string") {
      type = types2.map[type];
    }
    if (!type)
      return { code: ERROR_CODE2.ERR_DOC_TYPE_NOT_RECOGNIZED, message: "Unknown type" };
    if (!util2.supportsPresence(type)) {
      return { code: ERROR_CODE2.ERR_TYPE_DOES_NOT_SUPPORT_PRESENCE, message: "Type does not support presence" };
    }
    if (op.create || op.del) {
      presence2.p = null;
      presence2.v++;
      return;
    }
    try {
      presence2.p = presence2.p === null ? null : type.transformPresence(presence2.p, op.op, isOwnOp);
    } catch (error2) {
      return { code: ERROR_CODE2.ERR_PRESENCE_TRANSFORM_FAILED, message: error2.message || error2 };
    }
    presence2.v++;
  };
  function normalizeLegacyJson0Ops(snapshot2, json0Op) {
    if (snapshot2.type !== types2.defaultType.uri)
      return;
    var components = json0Op.op;
    if (!components)
      return;
    var data = snapshot2.data;
    if (components.length > 1)
      data = util2.clone(data);
    for (var i = 0; i < components.length; i++) {
      var component = components[i];
      if (typeof component.lm === "string")
        component.lm = +component.lm;
      var path = component.p;
      var element = data;
      for (var j = 0; j < path.length; j++) {
        var key = path[j];
        if (Object.prototype.toString.call(element) == "[object Array]")
          path[j] = +key;
        else if (element.constructor === Object)
          path[j] = key.toString();
        element = element[key];
      }
      if (i < components.length - 1)
        data = types2.defaultType.apply(data, [component]);
    }
  }
})(ot$1);
var RemotePresence = remotePresence;
var ot = ot$1;
var remoteDocPresence = RemoteDocPresence$1;
function RemoteDocPresence$1(presence2, presenceId) {
  RemotePresence.call(this, presence2, presenceId);
  this.collection = this.presence.collection;
  this.id = this.presence.id;
  this.src = null;
  this.presenceVersion = null;
  this._doc = this.connection.get(this.collection, this.id);
  this._pending = null;
  this._opCache = null;
  this._pendingSetPending = false;
  this._opHandler = this._handleOp.bind(this);
  this._createDelHandler = this._handleCreateDel.bind(this);
  this._loadHandler = this._handleLoad.bind(this);
  this._registerWithDoc();
}
RemoteDocPresence$1.prototype = Object.create(RemotePresence.prototype);
RemoteDocPresence$1.prototype.receiveUpdate = function(message) {
  if (this._pending && message.pv < this._pending.pv)
    return;
  this.src = message.src;
  this._pending = message;
  this._setPendingPresence();
};
RemoteDocPresence$1.prototype.destroy = function(callback) {
  this._doc.removeListener("op", this._opHandler);
  this._doc.removeListener("create", this._createDelHandler);
  this._doc.removeListener("del", this._createDelHandler);
  this._doc.removeListener("load", this._loadHandler);
  RemotePresence.prototype.destroy.call(this, callback);
};
RemoteDocPresence$1.prototype._registerWithDoc = function() {
  this._doc.on("op", this._opHandler);
  this._doc.on("create", this._createDelHandler);
  this._doc.on("del", this._createDelHandler);
  this._doc.on("load", this._loadHandler);
};
RemoteDocPresence$1.prototype._setPendingPresence = function() {
  if (this._pendingSetPending)
    return;
  this._pendingSetPending = true;
  var presence2 = this;
  this._doc.whenNothingPending(function() {
    presence2._pendingSetPending = false;
    if (!presence2._pending)
      return;
    if (presence2._pending.pv < presence2.presenceVersion)
      return presence2._pending = null;
    if (presence2._pending.v > presence2._doc.version) {
      return presence2._doc.fetch();
    }
    if (!presence2._catchUpStalePresence())
      return;
    presence2.value = presence2._pending.p;
    presence2.presenceVersion = presence2._pending.pv;
    presence2._pending = null;
    presence2.presence._updateRemotePresence(presence2);
  });
};
RemoteDocPresence$1.prototype._handleOp = function(op, source, connectionId) {
  var isOwnOp = connectionId === this.src;
  this._transformAgainstOp(op, isOwnOp);
  this._cacheOp(op, isOwnOp);
  this._setPendingPresence();
};
RemotePresence.prototype._handleCreateDel = function() {
  this._cacheOp(null);
  this._setPendingPresence();
};
RemotePresence.prototype._handleLoad = function() {
  this.value = null;
  this._pending = null;
  this._opCache = null;
  this.presence._updateRemotePresence(this);
};
RemoteDocPresence$1.prototype._transformAgainstOp = function(op, isOwnOp) {
  if (!this.value)
    return;
  try {
    this.value = this._doc.type.transformPresence(this.value, op, isOwnOp);
  } catch (error2) {
    return this.presence.emit("error", error2);
  }
  this.presence._updateRemotePresence(this);
};
RemoteDocPresence$1.prototype._catchUpStalePresence = function() {
  if (this._pending.v >= this._doc.version)
    return true;
  if (!this._opCache) {
    this._startCachingOps();
    this._doc.fetch();
    this.presence.subscribe();
    return false;
  }
  while (this._opCache[this._pending.v]) {
    var item = this._opCache[this._pending.v];
    var op = item.op;
    var isOwnOp = item.isOwnOp;
    if (op === null) {
      this._pending.p = null;
      this._pending.v++;
    } else {
      ot.transformPresence(this._pending, op, isOwnOp);
    }
  }
  var hasCaughtUp = this._pending.v >= this._doc.version;
  if (hasCaughtUp) {
    this._stopCachingOps();
  }
  return hasCaughtUp;
};
RemoteDocPresence$1.prototype._startCachingOps = function() {
  this._opCache = [];
};
RemoteDocPresence$1.prototype._stopCachingOps = function() {
  this._opCache = null;
};
RemoteDocPresence$1.prototype._cacheOp = function(op, isOwnOp) {
  if (this._opCache) {
    op = op ? { op } : null;
    this._opCache[this._doc.version - 1] = { op, isOwnOp };
  }
};
var Presence$1 = presence;
var LocalDocPresence = localDocPresence;
var RemoteDocPresence = remoteDocPresence;
function DocPresence$1(connection2, collection, id) {
  var channel = DocPresence$1.channel(collection, id);
  Presence$1.call(this, connection2, channel);
  this.collection = collection;
  this.id = id;
}
var docPresence = DocPresence$1;
DocPresence$1.prototype = Object.create(Presence$1.prototype);
DocPresence$1.channel = function(collection, id) {
  return collection + "." + id;
};
DocPresence$1.prototype._createLocalPresence = function(id) {
  return new LocalDocPresence(this, id);
};
DocPresence$1.prototype._createRemotePresence = function(id) {
  return new RemoteDocPresence(this, id);
};
var snapshot = Snapshot$1;
function Snapshot$1(id, version, type, data, meta) {
  this.id = id;
  this.v = version;
  this.type = type;
  this.data = data;
  this.m = meta;
}
var Snapshot = snapshot;
var emitter$1 = emitter$6;
var snapshotRequest = SnapshotRequest$2;
function SnapshotRequest$2(connection2, requestId, collection, id, callback) {
  emitter$1.EventEmitter.call(this);
  if (typeof callback !== "function") {
    throw new Error("Callback is required for SnapshotRequest");
  }
  this.requestId = requestId;
  this.connection = connection2;
  this.id = id;
  this.collection = collection;
  this.callback = callback;
  this.sent = false;
}
emitter$1.mixin(SnapshotRequest$2);
SnapshotRequest$2.prototype.send = function() {
  if (!this.connection.canSend) {
    return;
  }
  this.connection.send(this._message());
  this.sent = true;
};
SnapshotRequest$2.prototype._onConnectionStateChanged = function() {
  if (this.connection.canSend) {
    if (!this.sent)
      this.send();
  } else {
    this.sent = false;
  }
};
SnapshotRequest$2.prototype._handleResponse = function(error2, message) {
  this.emit("ready");
  if (error2) {
    return this.callback(error2);
  }
  var metadata = message.meta ? message.meta : null;
  var snapshot2 = new Snapshot(this.id, message.v, message.type, message.data, metadata);
  this.callback(null, snapshot2);
};
var SnapshotRequest$1 = snapshotRequest;
var util$2 = util$9;
var snapshotVersionRequest = SnapshotVersionRequest$1;
function SnapshotVersionRequest$1(connection2, requestId, collection, id, version, callback) {
  SnapshotRequest$1.call(this, connection2, requestId, collection, id, callback);
  if (!util$2.isValidVersion(version)) {
    throw new Error("Snapshot version must be a positive integer or null");
  }
  this.version = version;
}
SnapshotVersionRequest$1.prototype = Object.create(SnapshotRequest$1.prototype);
SnapshotVersionRequest$1.prototype._message = function() {
  return {
    a: "nf",
    id: this.requestId,
    c: this.collection,
    d: this.id,
    v: this.version
  };
};
var SnapshotRequest = snapshotRequest;
var util$1 = util$9;
var snapshotTimestampRequest = SnapshotTimestampRequest$1;
function SnapshotTimestampRequest$1(connection2, requestId, collection, id, timestamp, callback) {
  SnapshotRequest.call(this, connection2, requestId, collection, id, callback);
  if (!util$1.isValidTimestamp(timestamp)) {
    throw new Error("Snapshot timestamp must be a positive integer or null");
  }
  this.timestamp = timestamp;
}
SnapshotTimestampRequest$1.prototype = Object.create(SnapshotRequest.prototype);
SnapshotTimestampRequest$1.prototype._message = function() {
  return {
    a: "nt",
    id: this.requestId,
    c: this.collection,
    d: this.id,
    ts: this.timestamp
  };
};
var Doc = doc;
var Query = query;
var Presence = presence;
var DocPresence = docPresence;
var SnapshotVersionRequest = snapshotVersionRequest;
var SnapshotTimestampRequest = snapshotTimestampRequest;
var emitter = emitter$6;
var ShareDBError = error;
var types$1 = types$3;
var util = util$9;
var logger = logger_1;
var ERROR_CODE = ShareDBError.CODES;
function connectionState(socket) {
  if (socket.readyState === 0 || socket.readyState === 1)
    return "connecting";
  return "disconnected";
}
var connection = Connection$1;
function Connection$1(socket) {
  emitter.EventEmitter.call(this);
  this.collections = {};
  this.nextQueryId = 1;
  this.nextSnapshotRequestId = 1;
  this.queries = {};
  this._presences = {};
  this._snapshotRequests = {};
  this.seq = 1;
  this._presenceSeq = 1;
  this.id = null;
  this.agent = null;
  this.debug = false;
  this.state = connectionState(socket);
  this.bindToSocket(socket);
}
emitter.mixin(Connection$1);
Connection$1.prototype.bindToSocket = function(socket) {
  if (this.socket) {
    this.socket.close();
    this.socket.onmessage = null;
    this.socket.onopen = null;
    this.socket.onerror = null;
    this.socket.onclose = null;
  }
  this.socket = socket;
  var newState = connectionState(socket);
  this._setState(newState);
  this.canSend = false;
  var connection2 = this;
  socket.onmessage = function(event) {
    try {
      var data = typeof event.data === "string" ? JSON.parse(event.data) : event.data;
    } catch (err) {
      logger.warn("Failed to parse message", event);
      return;
    }
    if (connection2.debug)
      logger.info("RECV", JSON.stringify(data));
    var request = { data };
    connection2.emit("receive", request);
    if (!request.data)
      return;
    try {
      connection2.handleMessage(request.data);
    } catch (err) {
      util.nextTick(function() {
        connection2.emit("error", err);
      });
    }
  };
  if (socket.readyState === 1) {
    connection2._initializeHandshake();
  }
  socket.onopen = function() {
    connection2._setState("connecting");
    connection2._initializeHandshake();
  };
  socket.onerror = function(err) {
    connection2.emit("connection error", err);
  };
  socket.onclose = function(reason) {
    if (reason === "closed" || reason === "Closed") {
      connection2._setState("closed", reason);
    } else if (reason === "stopped" || reason === "Stopped by server") {
      connection2._setState("stopped", reason);
    } else {
      connection2._setState("disconnected", reason);
    }
  };
};
Connection$1.prototype.handleMessage = function(message) {
  var err = null;
  if (message.error) {
    err = wrapErrorData(message.error, message);
    delete message.error;
  }
  switch (message.a) {
    case "init":
      return this._handleLegacyInit(message);
    case "hs":
      return this._handleHandshake(err, message);
    case "qf":
      var query2 = this.queries[message.id];
      if (query2)
        query2._handleFetch(err, message.data, message.extra);
      return;
    case "qs":
      var query2 = this.queries[message.id];
      if (query2)
        query2._handleSubscribe(err, message.data, message.extra);
      return;
    case "qu":
      return;
    case "q":
      var query2 = this.queries[message.id];
      if (!query2)
        return;
      if (err)
        return query2._handleError(err);
      if (message.diff)
        query2._handleDiff(message.diff);
      if (message.hasOwnProperty("extra"))
        query2._handleExtra(message.extra);
      return;
    case "bf":
      return this._handleBulkMessage(err, message, "_handleFetch");
    case "bs":
    case "bu":
      return this._handleBulkMessage(err, message, "_handleSubscribe");
    case "nf":
    case "nt":
      return this._handleSnapshotFetch(err, message);
    case "f":
      var doc2 = this.getExisting(message.c, message.d);
      if (doc2)
        doc2._handleFetch(err, message.data);
      return;
    case "s":
    case "u":
      var doc2 = this.getExisting(message.c, message.d);
      if (doc2)
        doc2._handleSubscribe(err, message.data);
      return;
    case "op":
      var doc2 = this.getExisting(message.c, message.d);
      if (doc2)
        doc2._handleOp(err, message);
      return;
    case "p":
      return this._handlePresence(err, message);
    case "ps":
      return this._handlePresenceSubscribe(err, message);
    case "pu":
      return this._handlePresenceUnsubscribe(err, message);
    case "pr":
      return this._handlePresenceRequest(err, message);
    default:
      logger.warn("Ignoring unrecognized message", message);
  }
};
function wrapErrorData(errorData, fullMessage) {
  var err = new Error(errorData.message);
  err.code = errorData.code;
  if (fullMessage) {
    err.data = fullMessage;
  }
  return err;
}
Connection$1.prototype._handleBulkMessage = function(err, message, method) {
  if (message.data) {
    for (var id in message.data) {
      var dataForId = message.data[id];
      var doc2 = this.getExisting(message.c, id);
      if (doc2) {
        if (err) {
          doc2[method](err);
        } else if (dataForId.error) {
          doc2[method](wrapErrorData(dataForId.error));
        } else {
          doc2[method](null, dataForId);
        }
      }
    }
  } else if (Array.isArray(message.b)) {
    for (var i = 0; i < message.b.length; i++) {
      var id = message.b[i];
      var doc2 = this.getExisting(message.c, id);
      if (doc2)
        doc2[method](err);
    }
  } else if (message.b) {
    for (var id in message.b) {
      var doc2 = this.getExisting(message.c, id);
      if (doc2)
        doc2[method](err);
    }
  } else {
    logger.error("Invalid bulk message", message);
  }
};
Connection$1.prototype._reset = function() {
  this.agent = null;
};
Connection$1.prototype._setState = function(newState, reason) {
  if (this.state === newState)
    return;
  if (newState === "connecting" && this.state !== "disconnected" && this.state !== "stopped" && this.state !== "closed" || newState === "connected" && this.state !== "connecting") {
    var err = new ShareDBError(ERROR_CODE.ERR_CONNECTION_STATE_TRANSITION_INVALID, "Cannot transition directly from " + this.state + " to " + newState);
    return this.emit("error", err);
  }
  this.state = newState;
  this.canSend = newState === "connected";
  if (newState === "disconnected" || newState === "stopped" || newState === "closed") {
    this._reset();
  }
  this.startBulk();
  for (var id in this.queries) {
    var query2 = this.queries[id];
    query2._onConnectionStateChanged();
  }
  for (var collection in this.collections) {
    var docs = this.collections[collection];
    for (var id in docs) {
      docs[id]._onConnectionStateChanged();
    }
  }
  for (var channel in this._presences) {
    this._presences[channel]._onConnectionStateChanged();
  }
  for (var id in this._snapshotRequests) {
    var snapshotRequest2 = this._snapshotRequests[id];
    snapshotRequest2._onConnectionStateChanged();
  }
  this.endBulk();
  this.emit(newState, reason);
  this.emit("state", newState, reason);
};
Connection$1.prototype.startBulk = function() {
  if (!this.bulk)
    this.bulk = {};
};
Connection$1.prototype.endBulk = function() {
  if (this.bulk) {
    for (var collection in this.bulk) {
      var actions = this.bulk[collection];
      this._sendBulk("f", collection, actions.f);
      this._sendBulk("s", collection, actions.s);
      this._sendBulk("u", collection, actions.u);
    }
  }
  this.bulk = null;
};
Connection$1.prototype._sendBulk = function(action, collection, values) {
  if (!values)
    return;
  var ids = [];
  var versions = {};
  var versionsCount = 0;
  var versionId;
  for (var id in values) {
    var value = values[id];
    if (value == null) {
      ids.push(id);
    } else {
      versions[id] = value;
      versionId = id;
      versionsCount++;
    }
  }
  if (ids.length === 1) {
    var id = ids[0];
    this.send({ a: action, c: collection, d: id });
  } else if (ids.length) {
    this.send({ a: "b" + action, c: collection, b: ids });
  }
  if (versionsCount === 1) {
    var version = versions[versionId];
    this.send({ a: action, c: collection, d: versionId, v: version });
  } else if (versionsCount) {
    this.send({ a: "b" + action, c: collection, b: versions });
  }
};
Connection$1.prototype._sendAction = function(action, doc2, version) {
  this._addDoc(doc2);
  if (this.bulk) {
    var actions = this.bulk[doc2.collection] || (this.bulk[doc2.collection] = {});
    var versions = actions[action] || (actions[action] = {});
    var isDuplicate = versions.hasOwnProperty(doc2.id);
    versions[doc2.id] = version;
    return isDuplicate;
  } else {
    var message = { a: action, c: doc2.collection, d: doc2.id, v: version };
    this.send(message);
  }
};
Connection$1.prototype.sendFetch = function(doc2) {
  return this._sendAction("f", doc2, doc2.version);
};
Connection$1.prototype.sendSubscribe = function(doc2) {
  return this._sendAction("s", doc2, doc2.version);
};
Connection$1.prototype.sendUnsubscribe = function(doc2) {
  return this._sendAction("u", doc2);
};
Connection$1.prototype.sendOp = function(doc2, op) {
  this._addDoc(doc2);
  var message = {
    a: "op",
    c: doc2.collection,
    d: doc2.id,
    v: doc2.version,
    src: op.src,
    seq: op.seq,
    x: {}
  };
  if ("op" in op)
    message.op = op.op;
  if (op.create)
    message.create = op.create;
  if (op.del)
    message.del = op.del;
  if (doc2.submitSource)
    message.x.source = op.source;
  this.send(message);
};
Connection$1.prototype.send = function(message) {
  if (this.debug)
    logger.info("SEND", JSON.stringify(message));
  this.emit("send", message);
  this.socket.send(JSON.stringify(message));
};
Connection$1.prototype.close = function() {
  this.socket.close();
};
Connection$1.prototype.getExisting = function(collection, id) {
  if (this.collections[collection])
    return this.collections[collection][id];
};
Connection$1.prototype.get = function(collection, id) {
  var docs = this.collections[collection] || (this.collections[collection] = {});
  var doc2 = docs[id];
  if (!doc2) {
    doc2 = docs[id] = new Doc(this, collection, id);
    this.emit("doc", doc2);
  }
  return doc2;
};
Connection$1.prototype._destroyDoc = function(doc2) {
  util.digAndRemove(this.collections, doc2.collection, doc2.id);
};
Connection$1.prototype._addDoc = function(doc2) {
  var docs = this.collections[doc2.collection];
  if (!docs) {
    docs = this.collections[doc2.collection] = {};
  }
  if (docs[doc2.id] !== doc2) {
    docs[doc2.id] = doc2;
  }
};
Connection$1.prototype._createQuery = function(action, collection, q, options, callback) {
  var id = this.nextQueryId++;
  var query2 = new Query(action, this, id, collection, q, options, callback);
  this.queries[id] = query2;
  query2.send();
  return query2;
};
Connection$1.prototype._destroyQuery = function(query2) {
  delete this.queries[query2.id];
};
Connection$1.prototype.createFetchQuery = function(collection, q, options, callback) {
  return this._createQuery("qf", collection, q, options, callback);
};
Connection$1.prototype.createSubscribeQuery = function(collection, q, options, callback) {
  return this._createQuery("qs", collection, q, options, callback);
};
Connection$1.prototype.hasPending = function() {
  return !!(this._firstDoc(hasPending) || this._firstQuery(hasPending) || this._firstSnapshotRequest());
};
function hasPending(object) {
  return object.hasPending();
}
Connection$1.prototype.hasWritePending = function() {
  return !!this._firstDoc(hasWritePending);
};
function hasWritePending(object) {
  return object.hasWritePending();
}
Connection$1.prototype.whenNothingPending = function(callback) {
  var doc2 = this._firstDoc(hasPending);
  if (doc2) {
    doc2.once("nothing pending", this._nothingPendingRetry(callback));
    return;
  }
  var query2 = this._firstQuery(hasPending);
  if (query2) {
    query2.once("ready", this._nothingPendingRetry(callback));
    return;
  }
  var snapshotRequest2 = this._firstSnapshotRequest();
  if (snapshotRequest2) {
    snapshotRequest2.once("ready", this._nothingPendingRetry(callback));
    return;
  }
  util.nextTick(callback);
};
Connection$1.prototype._nothingPendingRetry = function(callback) {
  var connection2 = this;
  return function() {
    util.nextTick(function() {
      connection2.whenNothingPending(callback);
    });
  };
};
Connection$1.prototype._firstDoc = function(fn) {
  for (var collection in this.collections) {
    var docs = this.collections[collection];
    for (var id in docs) {
      var doc2 = docs[id];
      if (fn(doc2)) {
        return doc2;
      }
    }
  }
};
Connection$1.prototype._firstQuery = function(fn) {
  for (var id in this.queries) {
    var query2 = this.queries[id];
    if (fn(query2)) {
      return query2;
    }
  }
};
Connection$1.prototype._firstSnapshotRequest = function() {
  for (var id in this._snapshotRequests) {
    return this._snapshotRequests[id];
  }
};
Connection$1.prototype.fetchSnapshot = function(collection, id, version, callback) {
  if (typeof version === "function") {
    callback = version;
    version = null;
  }
  var requestId = this.nextSnapshotRequestId++;
  var snapshotRequest2 = new SnapshotVersionRequest(this, requestId, collection, id, version, callback);
  this._snapshotRequests[snapshotRequest2.requestId] = snapshotRequest2;
  snapshotRequest2.send();
};
Connection$1.prototype.fetchSnapshotByTimestamp = function(collection, id, timestamp, callback) {
  if (typeof timestamp === "function") {
    callback = timestamp;
    timestamp = null;
  }
  var requestId = this.nextSnapshotRequestId++;
  var snapshotRequest2 = new SnapshotTimestampRequest(this, requestId, collection, id, timestamp, callback);
  this._snapshotRequests[snapshotRequest2.requestId] = snapshotRequest2;
  snapshotRequest2.send();
};
Connection$1.prototype._handleSnapshotFetch = function(error2, message) {
  var snapshotRequest2 = this._snapshotRequests[message.id];
  if (!snapshotRequest2)
    return;
  delete this._snapshotRequests[message.id];
  snapshotRequest2._handleResponse(error2, message);
};
Connection$1.prototype._handleLegacyInit = function(message) {
  if (message.protocolMinor)
    return this._initializeHandshake();
  this._initialize(message);
};
Connection$1.prototype._initializeHandshake = function() {
  this.send({ a: "hs", id: this.id });
};
Connection$1.prototype._handleHandshake = function(error2, message) {
  if (error2)
    return this.emit("error", error2);
  this._initialize(message);
};
Connection$1.prototype._initialize = function(message) {
  if (this.state !== "connecting")
    return;
  if (message.protocol !== 1) {
    return this.emit("error", new ShareDBError(ERROR_CODE.ERR_PROTOCOL_VERSION_NOT_SUPPORTED, "Unsupported protocol version: " + message.protocol));
  }
  if (types$1.map[message.type] !== types$1.defaultType) {
    return this.emit("error", new ShareDBError(ERROR_CODE.ERR_DEFAULT_TYPE_MISMATCH, message.type + " does not match the server default type"));
  }
  if (typeof message.id !== "string") {
    return this.emit("error", new ShareDBError(ERROR_CODE.ERR_CLIENT_ID_BADLY_FORMED, "Client id must be a string"));
  }
  this.id = message.id;
  this._setState("connected");
};
Connection$1.prototype.getPresence = function(channel) {
  var connection2 = this;
  return util.digOrCreate(this._presences, channel, function() {
    return new Presence(connection2, channel);
  });
};
Connection$1.prototype.getDocPresence = function(collection, id) {
  var channel = DocPresence.channel(collection, id);
  var connection2 = this;
  return util.digOrCreate(this._presences, channel, function() {
    return new DocPresence(connection2, collection, id);
  });
};
Connection$1.prototype._sendPresenceAction = function(action, seq, presence2) {
  this._addPresence(presence2);
  var message = { a: action, ch: presence2.channel, seq };
  this.send(message);
  return message.seq;
};
Connection$1.prototype._addPresence = function(presence2) {
  util.digOrCreate(this._presences, presence2.channel, function() {
    return presence2;
  });
};
Connection$1.prototype._handlePresenceSubscribe = function(error2, message) {
  var presence2 = util.dig(this._presences, message.ch);
  if (presence2)
    presence2._handleSubscribe(error2, message.seq);
};
Connection$1.prototype._handlePresenceUnsubscribe = function(error2, message) {
  var presence2 = util.dig(this._presences, message.ch);
  if (presence2)
    presence2._handleUnsubscribe(error2, message.seq);
};
Connection$1.prototype._handlePresence = function(error2, message) {
  var presence2 = util.dig(this._presences, message.ch);
  if (presence2)
    presence2._receiveUpdate(error2, message);
};
Connection$1.prototype._handlePresenceRequest = function(error2, message) {
  var presence2 = util.dig(this._presences, message.ch);
  if (presence2)
    presence2._broadcastAllLocalPresence(error2, message);
};
var Connection = connection;
var types = types$3;
var richText_umd = { exports: {} };
var commonjsGlobal = typeof globalThis !== "undefined" ? globalThis : typeof window !== "undefined" ? window : typeof global !== "undefined" ? global : typeof self !== "undefined" ? self : {};
var DIFF_DELETE = -1;
var DIFF_INSERT = 1;
var DIFF_EQUAL = 0;
function diff_main(text1, text2, cursor_pos, _fix_unicode) {
  if (text1 === text2) {
    if (text1) {
      return [[DIFF_EQUAL, text1]];
    }
    return [];
  }
  if (cursor_pos != null) {
    var editdiff = find_cursor_edit_diff(text1, text2, cursor_pos);
    if (editdiff) {
      return editdiff;
    }
  }
  var commonlength = diff_commonPrefix(text1, text2);
  var commonprefix = text1.substring(0, commonlength);
  text1 = text1.substring(commonlength);
  text2 = text2.substring(commonlength);
  commonlength = diff_commonSuffix(text1, text2);
  var commonsuffix = text1.substring(text1.length - commonlength);
  text1 = text1.substring(0, text1.length - commonlength);
  text2 = text2.substring(0, text2.length - commonlength);
  var diffs = diff_compute_(text1, text2);
  if (commonprefix) {
    diffs.unshift([DIFF_EQUAL, commonprefix]);
  }
  if (commonsuffix) {
    diffs.push([DIFF_EQUAL, commonsuffix]);
  }
  diff_cleanupMerge(diffs, _fix_unicode);
  return diffs;
}
function diff_compute_(text1, text2) {
  var diffs;
  if (!text1) {
    return [[DIFF_INSERT, text2]];
  }
  if (!text2) {
    return [[DIFF_DELETE, text1]];
  }
  var longtext = text1.length > text2.length ? text1 : text2;
  var shorttext = text1.length > text2.length ? text2 : text1;
  var i = longtext.indexOf(shorttext);
  if (i !== -1) {
    diffs = [
      [DIFF_INSERT, longtext.substring(0, i)],
      [DIFF_EQUAL, shorttext],
      [DIFF_INSERT, longtext.substring(i + shorttext.length)]
    ];
    if (text1.length > text2.length) {
      diffs[0][0] = diffs[2][0] = DIFF_DELETE;
    }
    return diffs;
  }
  if (shorttext.length === 1) {
    return [[DIFF_DELETE, text1], [DIFF_INSERT, text2]];
  }
  var hm = diff_halfMatch_(text1, text2);
  if (hm) {
    var text1_a = hm[0];
    var text1_b = hm[1];
    var text2_a = hm[2];
    var text2_b = hm[3];
    var mid_common = hm[4];
    var diffs_a = diff_main(text1_a, text2_a);
    var diffs_b = diff_main(text1_b, text2_b);
    return diffs_a.concat([[DIFF_EQUAL, mid_common]], diffs_b);
  }
  return diff_bisect_(text1, text2);
}
function diff_bisect_(text1, text2) {
  var text1_length = text1.length;
  var text2_length = text2.length;
  var max_d = Math.ceil((text1_length + text2_length) / 2);
  var v_offset = max_d;
  var v_length = 2 * max_d;
  var v1 = new Array(v_length);
  var v2 = new Array(v_length);
  for (var x = 0; x < v_length; x++) {
    v1[x] = -1;
    v2[x] = -1;
  }
  v1[v_offset + 1] = 0;
  v2[v_offset + 1] = 0;
  var delta = text1_length - text2_length;
  var front = delta % 2 !== 0;
  var k1start = 0;
  var k1end = 0;
  var k2start = 0;
  var k2end = 0;
  for (var d = 0; d < max_d; d++) {
    for (var k1 = -d + k1start; k1 <= d - k1end; k1 += 2) {
      var k1_offset = v_offset + k1;
      var x1;
      if (k1 === -d || k1 !== d && v1[k1_offset - 1] < v1[k1_offset + 1]) {
        x1 = v1[k1_offset + 1];
      } else {
        x1 = v1[k1_offset - 1] + 1;
      }
      var y1 = x1 - k1;
      while (x1 < text1_length && y1 < text2_length && text1.charAt(x1) === text2.charAt(y1)) {
        x1++;
        y1++;
      }
      v1[k1_offset] = x1;
      if (x1 > text1_length) {
        k1end += 2;
      } else if (y1 > text2_length) {
        k1start += 2;
      } else if (front) {
        var k2_offset = v_offset + delta - k1;
        if (k2_offset >= 0 && k2_offset < v_length && v2[k2_offset] !== -1) {
          var x2 = text1_length - v2[k2_offset];
          if (x1 >= x2) {
            return diff_bisectSplit_(text1, text2, x1, y1);
          }
        }
      }
    }
    for (var k2 = -d + k2start; k2 <= d - k2end; k2 += 2) {
      var k2_offset = v_offset + k2;
      var x2;
      if (k2 === -d || k2 !== d && v2[k2_offset - 1] < v2[k2_offset + 1]) {
        x2 = v2[k2_offset + 1];
      } else {
        x2 = v2[k2_offset - 1] + 1;
      }
      var y2 = x2 - k2;
      while (x2 < text1_length && y2 < text2_length && text1.charAt(text1_length - x2 - 1) === text2.charAt(text2_length - y2 - 1)) {
        x2++;
        y2++;
      }
      v2[k2_offset] = x2;
      if (x2 > text1_length) {
        k2end += 2;
      } else if (y2 > text2_length) {
        k2start += 2;
      } else if (!front) {
        var k1_offset = v_offset + delta - k2;
        if (k1_offset >= 0 && k1_offset < v_length && v1[k1_offset] !== -1) {
          var x1 = v1[k1_offset];
          var y1 = v_offset + x1 - k1_offset;
          x2 = text1_length - x2;
          if (x1 >= x2) {
            return diff_bisectSplit_(text1, text2, x1, y1);
          }
        }
      }
    }
  }
  return [[DIFF_DELETE, text1], [DIFF_INSERT, text2]];
}
function diff_bisectSplit_(text1, text2, x, y) {
  var text1a = text1.substring(0, x);
  var text2a = text2.substring(0, y);
  var text1b = text1.substring(x);
  var text2b = text2.substring(y);
  var diffs = diff_main(text1a, text2a);
  var diffsb = diff_main(text1b, text2b);
  return diffs.concat(diffsb);
}
function diff_commonPrefix(text1, text2) {
  if (!text1 || !text2 || text1.charAt(0) !== text2.charAt(0)) {
    return 0;
  }
  var pointermin = 0;
  var pointermax = Math.min(text1.length, text2.length);
  var pointermid = pointermax;
  var pointerstart = 0;
  while (pointermin < pointermid) {
    if (text1.substring(pointerstart, pointermid) == text2.substring(pointerstart, pointermid)) {
      pointermin = pointermid;
      pointerstart = pointermin;
    } else {
      pointermax = pointermid;
    }
    pointermid = Math.floor((pointermax - pointermin) / 2 + pointermin);
  }
  if (is_surrogate_pair_start(text1.charCodeAt(pointermid - 1))) {
    pointermid--;
  }
  return pointermid;
}
function diff_commonSuffix(text1, text2) {
  if (!text1 || !text2 || text1.slice(-1) !== text2.slice(-1)) {
    return 0;
  }
  var pointermin = 0;
  var pointermax = Math.min(text1.length, text2.length);
  var pointermid = pointermax;
  var pointerend = 0;
  while (pointermin < pointermid) {
    if (text1.substring(text1.length - pointermid, text1.length - pointerend) == text2.substring(text2.length - pointermid, text2.length - pointerend)) {
      pointermin = pointermid;
      pointerend = pointermin;
    } else {
      pointermax = pointermid;
    }
    pointermid = Math.floor((pointermax - pointermin) / 2 + pointermin);
  }
  if (is_surrogate_pair_end(text1.charCodeAt(text1.length - pointermid))) {
    pointermid--;
  }
  return pointermid;
}
function diff_halfMatch_(text1, text2) {
  var longtext = text1.length > text2.length ? text1 : text2;
  var shorttext = text1.length > text2.length ? text2 : text1;
  if (longtext.length < 4 || shorttext.length * 2 < longtext.length) {
    return null;
  }
  function diff_halfMatchI_(longtext2, shorttext2, i) {
    var seed = longtext2.substring(i, i + Math.floor(longtext2.length / 4));
    var j = -1;
    var best_common = "";
    var best_longtext_a, best_longtext_b, best_shorttext_a, best_shorttext_b;
    while ((j = shorttext2.indexOf(seed, j + 1)) !== -1) {
      var prefixLength = diff_commonPrefix(longtext2.substring(i), shorttext2.substring(j));
      var suffixLength = diff_commonSuffix(longtext2.substring(0, i), shorttext2.substring(0, j));
      if (best_common.length < suffixLength + prefixLength) {
        best_common = shorttext2.substring(j - suffixLength, j) + shorttext2.substring(j, j + prefixLength);
        best_longtext_a = longtext2.substring(0, i - suffixLength);
        best_longtext_b = longtext2.substring(i + prefixLength);
        best_shorttext_a = shorttext2.substring(0, j - suffixLength);
        best_shorttext_b = shorttext2.substring(j + prefixLength);
      }
    }
    if (best_common.length * 2 >= longtext2.length) {
      return [
        best_longtext_a,
        best_longtext_b,
        best_shorttext_a,
        best_shorttext_b,
        best_common
      ];
    } else {
      return null;
    }
  }
  var hm1 = diff_halfMatchI_(longtext, shorttext, Math.ceil(longtext.length / 4));
  var hm2 = diff_halfMatchI_(longtext, shorttext, Math.ceil(longtext.length / 2));
  var hm;
  if (!hm1 && !hm2) {
    return null;
  } else if (!hm2) {
    hm = hm1;
  } else if (!hm1) {
    hm = hm2;
  } else {
    hm = hm1[4].length > hm2[4].length ? hm1 : hm2;
  }
  var text1_a, text1_b, text2_a, text2_b;
  if (text1.length > text2.length) {
    text1_a = hm[0];
    text1_b = hm[1];
    text2_a = hm[2];
    text2_b = hm[3];
  } else {
    text2_a = hm[0];
    text2_b = hm[1];
    text1_a = hm[2];
    text1_b = hm[3];
  }
  var mid_common = hm[4];
  return [text1_a, text1_b, text2_a, text2_b, mid_common];
}
function diff_cleanupMerge(diffs, fix_unicode) {
  diffs.push([DIFF_EQUAL, ""]);
  var pointer = 0;
  var count_delete = 0;
  var count_insert = 0;
  var text_delete = "";
  var text_insert = "";
  var commonlength;
  while (pointer < diffs.length) {
    if (pointer < diffs.length - 1 && !diffs[pointer][1]) {
      diffs.splice(pointer, 1);
      continue;
    }
    switch (diffs[pointer][0]) {
      case DIFF_INSERT:
        count_insert++;
        text_insert += diffs[pointer][1];
        pointer++;
        break;
      case DIFF_DELETE:
        count_delete++;
        text_delete += diffs[pointer][1];
        pointer++;
        break;
      case DIFF_EQUAL:
        var previous_equality = pointer - count_insert - count_delete - 1;
        if (fix_unicode) {
          if (previous_equality >= 0 && ends_with_pair_start(diffs[previous_equality][1])) {
            var stray = diffs[previous_equality][1].slice(-1);
            diffs[previous_equality][1] = diffs[previous_equality][1].slice(0, -1);
            text_delete = stray + text_delete;
            text_insert = stray + text_insert;
            if (!diffs[previous_equality][1]) {
              diffs.splice(previous_equality, 1);
              pointer--;
              var k = previous_equality - 1;
              if (diffs[k] && diffs[k][0] === DIFF_INSERT) {
                count_insert++;
                text_insert = diffs[k][1] + text_insert;
                k--;
              }
              if (diffs[k] && diffs[k][0] === DIFF_DELETE) {
                count_delete++;
                text_delete = diffs[k][1] + text_delete;
                k--;
              }
              previous_equality = k;
            }
          }
          if (starts_with_pair_end(diffs[pointer][1])) {
            var stray = diffs[pointer][1].charAt(0);
            diffs[pointer][1] = diffs[pointer][1].slice(1);
            text_delete += stray;
            text_insert += stray;
          }
        }
        if (pointer < diffs.length - 1 && !diffs[pointer][1]) {
          diffs.splice(pointer, 1);
          break;
        }
        if (text_delete.length > 0 || text_insert.length > 0) {
          if (text_delete.length > 0 && text_insert.length > 0) {
            commonlength = diff_commonPrefix(text_insert, text_delete);
            if (commonlength !== 0) {
              if (previous_equality >= 0) {
                diffs[previous_equality][1] += text_insert.substring(0, commonlength);
              } else {
                diffs.splice(0, 0, [DIFF_EQUAL, text_insert.substring(0, commonlength)]);
                pointer++;
              }
              text_insert = text_insert.substring(commonlength);
              text_delete = text_delete.substring(commonlength);
            }
            commonlength = diff_commonSuffix(text_insert, text_delete);
            if (commonlength !== 0) {
              diffs[pointer][1] = text_insert.substring(text_insert.length - commonlength) + diffs[pointer][1];
              text_insert = text_insert.substring(0, text_insert.length - commonlength);
              text_delete = text_delete.substring(0, text_delete.length - commonlength);
            }
          }
          var n = count_insert + count_delete;
          if (text_delete.length === 0 && text_insert.length === 0) {
            diffs.splice(pointer - n, n);
            pointer = pointer - n;
          } else if (text_delete.length === 0) {
            diffs.splice(pointer - n, n, [DIFF_INSERT, text_insert]);
            pointer = pointer - n + 1;
          } else if (text_insert.length === 0) {
            diffs.splice(pointer - n, n, [DIFF_DELETE, text_delete]);
            pointer = pointer - n + 1;
          } else {
            diffs.splice(pointer - n, n, [DIFF_DELETE, text_delete], [DIFF_INSERT, text_insert]);
            pointer = pointer - n + 2;
          }
        }
        if (pointer !== 0 && diffs[pointer - 1][0] === DIFF_EQUAL) {
          diffs[pointer - 1][1] += diffs[pointer][1];
          diffs.splice(pointer, 1);
        } else {
          pointer++;
        }
        count_insert = 0;
        count_delete = 0;
        text_delete = "";
        text_insert = "";
        break;
    }
  }
  if (diffs[diffs.length - 1][1] === "") {
    diffs.pop();
  }
  var changes = false;
  pointer = 1;
  while (pointer < diffs.length - 1) {
    if (diffs[pointer - 1][0] === DIFF_EQUAL && diffs[pointer + 1][0] === DIFF_EQUAL) {
      if (diffs[pointer][1].substring(diffs[pointer][1].length - diffs[pointer - 1][1].length) === diffs[pointer - 1][1]) {
        diffs[pointer][1] = diffs[pointer - 1][1] + diffs[pointer][1].substring(0, diffs[pointer][1].length - diffs[pointer - 1][1].length);
        diffs[pointer + 1][1] = diffs[pointer - 1][1] + diffs[pointer + 1][1];
        diffs.splice(pointer - 1, 1);
        changes = true;
      } else if (diffs[pointer][1].substring(0, diffs[pointer + 1][1].length) == diffs[pointer + 1][1]) {
        diffs[pointer - 1][1] += diffs[pointer + 1][1];
        diffs[pointer][1] = diffs[pointer][1].substring(diffs[pointer + 1][1].length) + diffs[pointer + 1][1];
        diffs.splice(pointer + 1, 1);
        changes = true;
      }
    }
    pointer++;
  }
  if (changes) {
    diff_cleanupMerge(diffs, fix_unicode);
  }
}
function is_surrogate_pair_start(charCode) {
  return charCode >= 55296 && charCode <= 56319;
}
function is_surrogate_pair_end(charCode) {
  return charCode >= 56320 && charCode <= 57343;
}
function starts_with_pair_end(str) {
  return is_surrogate_pair_end(str.charCodeAt(0));
}
function ends_with_pair_start(str) {
  return is_surrogate_pair_start(str.charCodeAt(str.length - 1));
}
function remove_empty_tuples(tuples) {
  var ret = [];
  for (var i = 0; i < tuples.length; i++) {
    if (tuples[i][1].length > 0) {
      ret.push(tuples[i]);
    }
  }
  return ret;
}
function make_edit_splice(before, oldMiddle, newMiddle, after) {
  if (ends_with_pair_start(before) || starts_with_pair_end(after)) {
    return null;
  }
  return remove_empty_tuples([
    [DIFF_EQUAL, before],
    [DIFF_DELETE, oldMiddle],
    [DIFF_INSERT, newMiddle],
    [DIFF_EQUAL, after]
  ]);
}
function find_cursor_edit_diff(oldText, newText, cursor_pos) {
  var oldRange = typeof cursor_pos === "number" ? { index: cursor_pos, length: 0 } : cursor_pos.oldRange;
  var newRange = typeof cursor_pos === "number" ? null : cursor_pos.newRange;
  var oldLength = oldText.length;
  var newLength = newText.length;
  if (oldRange.length === 0 && (newRange === null || newRange.length === 0)) {
    var oldCursor = oldRange.index;
    var oldBefore = oldText.slice(0, oldCursor);
    var oldAfter = oldText.slice(oldCursor);
    var maybeNewCursor = newRange ? newRange.index : null;
    editBefore: {
      var newCursor = oldCursor + newLength - oldLength;
      if (maybeNewCursor !== null && maybeNewCursor !== newCursor) {
        break editBefore;
      }
      if (newCursor < 0 || newCursor > newLength) {
        break editBefore;
      }
      var newBefore = newText.slice(0, newCursor);
      var newAfter = newText.slice(newCursor);
      if (newAfter !== oldAfter) {
        break editBefore;
      }
      var prefixLength = Math.min(oldCursor, newCursor);
      var oldPrefix = oldBefore.slice(0, prefixLength);
      var newPrefix = newBefore.slice(0, prefixLength);
      if (oldPrefix !== newPrefix) {
        break editBefore;
      }
      var oldMiddle = oldBefore.slice(prefixLength);
      var newMiddle = newBefore.slice(prefixLength);
      return make_edit_splice(oldPrefix, oldMiddle, newMiddle, oldAfter);
    }
    editAfter: {
      if (maybeNewCursor !== null && maybeNewCursor !== oldCursor) {
        break editAfter;
      }
      var cursor = oldCursor;
      var newBefore = newText.slice(0, cursor);
      var newAfter = newText.slice(cursor);
      if (newBefore !== oldBefore) {
        break editAfter;
      }
      var suffixLength = Math.min(oldLength - cursor, newLength - cursor);
      var oldSuffix = oldAfter.slice(oldAfter.length - suffixLength);
      var newSuffix = newAfter.slice(newAfter.length - suffixLength);
      if (oldSuffix !== newSuffix) {
        break editAfter;
      }
      var oldMiddle = oldAfter.slice(0, oldAfter.length - suffixLength);
      var newMiddle = newAfter.slice(0, newAfter.length - suffixLength);
      return make_edit_splice(oldBefore, oldMiddle, newMiddle, oldSuffix);
    }
  }
  if (oldRange.length > 0 && newRange && newRange.length === 0) {
    replaceRange: {
      var oldPrefix = oldText.slice(0, oldRange.index);
      var oldSuffix = oldText.slice(oldRange.index + oldRange.length);
      var prefixLength = oldPrefix.length;
      var suffixLength = oldSuffix.length;
      if (newLength < prefixLength + suffixLength) {
        break replaceRange;
      }
      var newPrefix = newText.slice(0, prefixLength);
      var newSuffix = newText.slice(newLength - suffixLength);
      if (oldPrefix !== newPrefix || oldSuffix !== newSuffix) {
        break replaceRange;
      }
      var oldMiddle = oldText.slice(prefixLength, oldLength - suffixLength);
      var newMiddle = newText.slice(prefixLength, newLength - suffixLength);
      return make_edit_splice(oldPrefix, oldMiddle, newMiddle, oldSuffix);
    }
  }
  return null;
}
function diff(text1, text2, cursor_pos) {
  return diff_main(text1, text2, cursor_pos, true);
}
diff.INSERT = DIFF_INSERT;
diff.DELETE = DIFF_DELETE;
diff.EQUAL = DIFF_EQUAL;
var diff_1 = diff;
var lodash_clonedeep = { exports: {} };
(function(module, exports) {
  var LARGE_ARRAY_SIZE = 200;
  var HASH_UNDEFINED = "__lodash_hash_undefined__";
  var MAX_SAFE_INTEGER = 9007199254740991;
  var argsTag = "[object Arguments]", arrayTag = "[object Array]", boolTag = "[object Boolean]", dateTag = "[object Date]", errorTag = "[object Error]", funcTag = "[object Function]", genTag = "[object GeneratorFunction]", mapTag = "[object Map]", numberTag = "[object Number]", objectTag = "[object Object]", promiseTag = "[object Promise]", regexpTag = "[object RegExp]", setTag = "[object Set]", stringTag = "[object String]", symbolTag2 = "[object Symbol]", weakMapTag = "[object WeakMap]";
  var arrayBufferTag = "[object ArrayBuffer]", dataViewTag = "[object DataView]", float32Tag = "[object Float32Array]", float64Tag = "[object Float64Array]", int8Tag = "[object Int8Array]", int16Tag = "[object Int16Array]", int32Tag = "[object Int32Array]", uint8Tag = "[object Uint8Array]", uint8ClampedTag = "[object Uint8ClampedArray]", uint16Tag = "[object Uint16Array]", uint32Tag = "[object Uint32Array]";
  var reRegExpChar = /[\\^$.*+?()[\]{}|]/g;
  var reFlags = /\w*$/;
  var reIsHostCtor = /^\[object .+?Constructor\]$/;
  var reIsUint = /^(?:0|[1-9]\d*)$/;
  var cloneableTags = {};
  cloneableTags[argsTag] = cloneableTags[arrayTag] = cloneableTags[arrayBufferTag] = cloneableTags[dataViewTag] = cloneableTags[boolTag] = cloneableTags[dateTag] = cloneableTags[float32Tag] = cloneableTags[float64Tag] = cloneableTags[int8Tag] = cloneableTags[int16Tag] = cloneableTags[int32Tag] = cloneableTags[mapTag] = cloneableTags[numberTag] = cloneableTags[objectTag] = cloneableTags[regexpTag] = cloneableTags[setTag] = cloneableTags[stringTag] = cloneableTags[symbolTag2] = cloneableTags[uint8Tag] = cloneableTags[uint8ClampedTag] = cloneableTags[uint16Tag] = cloneableTags[uint32Tag] = true;
  cloneableTags[errorTag] = cloneableTags[funcTag] = cloneableTags[weakMapTag] = false;
  var freeGlobal2 = typeof commonjsGlobal == "object" && commonjsGlobal && commonjsGlobal.Object === Object && commonjsGlobal;
  var freeSelf2 = typeof self == "object" && self && self.Object === Object && self;
  var root2 = freeGlobal2 || freeSelf2 || Function("return this")();
  var freeExports = exports && !exports.nodeType && exports;
  var freeModule = freeExports && true && module && !module.nodeType && module;
  var moduleExports = freeModule && freeModule.exports === freeExports;
  function addMapEntry(map, pair) {
    map.set(pair[0], pair[1]);
    return map;
  }
  function addSetEntry(set, value) {
    set.add(value);
    return set;
  }
  function arrayEach(array, iteratee) {
    var index = -1, length = array ? array.length : 0;
    while (++index < length) {
      if (iteratee(array[index], index, array) === false) {
        break;
      }
    }
    return array;
  }
  function arrayPush(array, values) {
    var index = -1, length = values.length, offset = array.length;
    while (++index < length) {
      array[offset + index] = values[index];
    }
    return array;
  }
  function arrayReduce(array, iteratee, accumulator, initAccum) {
    var index = -1, length = array ? array.length : 0;
    if (initAccum && length) {
      accumulator = array[++index];
    }
    while (++index < length) {
      accumulator = iteratee(accumulator, array[index], index, array);
    }
    return accumulator;
  }
  function baseTimes(n, iteratee) {
    var index = -1, result = Array(n);
    while (++index < n) {
      result[index] = iteratee(index);
    }
    return result;
  }
  function getValue(object, key) {
    return object == null ? void 0 : object[key];
  }
  function isHostObject(value) {
    var result = false;
    if (value != null && typeof value.toString != "function") {
      try {
        result = !!(value + "");
      } catch (e) {
      }
    }
    return result;
  }
  function mapToArray(map) {
    var index = -1, result = Array(map.size);
    map.forEach(function(value, key) {
      result[++index] = [key, value];
    });
    return result;
  }
  function overArg(func, transform) {
    return function(arg) {
      return func(transform(arg));
    };
  }
  function setToArray(set) {
    var index = -1, result = Array(set.size);
    set.forEach(function(value) {
      result[++index] = value;
    });
    return result;
  }
  var arrayProto = Array.prototype, funcProto = Function.prototype, objectProto2 = Object.prototype;
  var coreJsData = root2["__core-js_shared__"];
  var maskSrcKey = function() {
    var uid = /[^.]+$/.exec(coreJsData && coreJsData.keys && coreJsData.keys.IE_PROTO || "");
    return uid ? "Symbol(src)_1." + uid : "";
  }();
  var funcToString = funcProto.toString;
  var hasOwnProperty = objectProto2.hasOwnProperty;
  var objectToString2 = objectProto2.toString;
  var reIsNative = RegExp("^" + funcToString.call(hasOwnProperty).replace(reRegExpChar, "\\$&").replace(/hasOwnProperty|(function).*?(?=\\\()| for .+?(?=\\\])/g, "$1.*?") + "$");
  var Buffer2 = moduleExports ? root2.Buffer : void 0, Symbol2 = root2.Symbol, Uint8Array2 = root2.Uint8Array, getPrototype = overArg(Object.getPrototypeOf, Object), objectCreate = Object.create, propertyIsEnumerable = objectProto2.propertyIsEnumerable, splice = arrayProto.splice;
  var nativeGetSymbols = Object.getOwnPropertySymbols, nativeIsBuffer = Buffer2 ? Buffer2.isBuffer : void 0, nativeKeys = overArg(Object.keys, Object);
  var DataView = getNative(root2, "DataView"), Map2 = getNative(root2, "Map"), Promise2 = getNative(root2, "Promise"), Set2 = getNative(root2, "Set"), WeakMap2 = getNative(root2, "WeakMap"), nativeCreate = getNative(Object, "create");
  var dataViewCtorString = toSource(DataView), mapCtorString = toSource(Map2), promiseCtorString = toSource(Promise2), setCtorString = toSource(Set2), weakMapCtorString = toSource(WeakMap2);
  var symbolProto = Symbol2 ? Symbol2.prototype : void 0, symbolValueOf = symbolProto ? symbolProto.valueOf : void 0;
  function Hash(entries) {
    var index = -1, length = entries ? entries.length : 0;
    this.clear();
    while (++index < length) {
      var entry = entries[index];
      this.set(entry[0], entry[1]);
    }
  }
  function hashClear() {
    this.__data__ = nativeCreate ? nativeCreate(null) : {};
  }
  function hashDelete(key) {
    return this.has(key) && delete this.__data__[key];
  }
  function hashGet(key) {
    var data = this.__data__;
    if (nativeCreate) {
      var result = data[key];
      return result === HASH_UNDEFINED ? void 0 : result;
    }
    return hasOwnProperty.call(data, key) ? data[key] : void 0;
  }
  function hashHas(key) {
    var data = this.__data__;
    return nativeCreate ? data[key] !== void 0 : hasOwnProperty.call(data, key);
  }
  function hashSet(key, value) {
    var data = this.__data__;
    data[key] = nativeCreate && value === void 0 ? HASH_UNDEFINED : value;
    return this;
  }
  Hash.prototype.clear = hashClear;
  Hash.prototype["delete"] = hashDelete;
  Hash.prototype.get = hashGet;
  Hash.prototype.has = hashHas;
  Hash.prototype.set = hashSet;
  function ListCache(entries) {
    var index = -1, length = entries ? entries.length : 0;
    this.clear();
    while (++index < length) {
      var entry = entries[index];
      this.set(entry[0], entry[1]);
    }
  }
  function listCacheClear() {
    this.__data__ = [];
  }
  function listCacheDelete(key) {
    var data = this.__data__, index = assocIndexOf(data, key);
    if (index < 0) {
      return false;
    }
    var lastIndex = data.length - 1;
    if (index == lastIndex) {
      data.pop();
    } else {
      splice.call(data, index, 1);
    }
    return true;
  }
  function listCacheGet(key) {
    var data = this.__data__, index = assocIndexOf(data, key);
    return index < 0 ? void 0 : data[index][1];
  }
  function listCacheHas(key) {
    return assocIndexOf(this.__data__, key) > -1;
  }
  function listCacheSet(key, value) {
    var data = this.__data__, index = assocIndexOf(data, key);
    if (index < 0) {
      data.push([key, value]);
    } else {
      data[index][1] = value;
    }
    return this;
  }
  ListCache.prototype.clear = listCacheClear;
  ListCache.prototype["delete"] = listCacheDelete;
  ListCache.prototype.get = listCacheGet;
  ListCache.prototype.has = listCacheHas;
  ListCache.prototype.set = listCacheSet;
  function MapCache(entries) {
    var index = -1, length = entries ? entries.length : 0;
    this.clear();
    while (++index < length) {
      var entry = entries[index];
      this.set(entry[0], entry[1]);
    }
  }
  function mapCacheClear() {
    this.__data__ = {
      "hash": new Hash(),
      "map": new (Map2 || ListCache)(),
      "string": new Hash()
    };
  }
  function mapCacheDelete(key) {
    return getMapData(this, key)["delete"](key);
  }
  function mapCacheGet(key) {
    return getMapData(this, key).get(key);
  }
  function mapCacheHas(key) {
    return getMapData(this, key).has(key);
  }
  function mapCacheSet(key, value) {
    getMapData(this, key).set(key, value);
    return this;
  }
  MapCache.prototype.clear = mapCacheClear;
  MapCache.prototype["delete"] = mapCacheDelete;
  MapCache.prototype.get = mapCacheGet;
  MapCache.prototype.has = mapCacheHas;
  MapCache.prototype.set = mapCacheSet;
  function Stack(entries) {
    this.__data__ = new ListCache(entries);
  }
  function stackClear() {
    this.__data__ = new ListCache();
  }
  function stackDelete(key) {
    return this.__data__["delete"](key);
  }
  function stackGet(key) {
    return this.__data__.get(key);
  }
  function stackHas(key) {
    return this.__data__.has(key);
  }
  function stackSet(key, value) {
    var cache = this.__data__;
    if (cache instanceof ListCache) {
      var pairs = cache.__data__;
      if (!Map2 || pairs.length < LARGE_ARRAY_SIZE - 1) {
        pairs.push([key, value]);
        return this;
      }
      cache = this.__data__ = new MapCache(pairs);
    }
    cache.set(key, value);
    return this;
  }
  Stack.prototype.clear = stackClear;
  Stack.prototype["delete"] = stackDelete;
  Stack.prototype.get = stackGet;
  Stack.prototype.has = stackHas;
  Stack.prototype.set = stackSet;
  function arrayLikeKeys(value, inherited) {
    var result = isArray2(value) || isArguments(value) ? baseTimes(value.length, String) : [];
    var length = result.length, skipIndexes = !!length;
    for (var key in value) {
      if ((inherited || hasOwnProperty.call(value, key)) && !(skipIndexes && (key == "length" || isIndex(key, length)))) {
        result.push(key);
      }
    }
    return result;
  }
  function assignValue(object, key, value) {
    var objValue = object[key];
    if (!(hasOwnProperty.call(object, key) && eq(objValue, value)) || value === void 0 && !(key in object)) {
      object[key] = value;
    }
  }
  function assocIndexOf(array, key) {
    var length = array.length;
    while (length--) {
      if (eq(array[length][0], key)) {
        return length;
      }
    }
    return -1;
  }
  function baseAssign(object, source) {
    return object && copyObject(source, keys(source), object);
  }
  function baseClone(value, isDeep, isFull, customizer, key, object, stack) {
    var result;
    if (customizer) {
      result = object ? customizer(value, key, object, stack) : customizer(value);
    }
    if (result !== void 0) {
      return result;
    }
    if (!isObject2(value)) {
      return value;
    }
    var isArr = isArray2(value);
    if (isArr) {
      result = initCloneArray(value);
      if (!isDeep) {
        return copyArray(value, result);
      }
    } else {
      var tag = getTag(value), isFunc = tag == funcTag || tag == genTag;
      if (isBuffer(value)) {
        return cloneBuffer(value, isDeep);
      }
      if (tag == objectTag || tag == argsTag || isFunc && !object) {
        if (isHostObject(value)) {
          return object ? value : {};
        }
        result = initCloneObject(isFunc ? {} : value);
        if (!isDeep) {
          return copySymbols(value, baseAssign(result, value));
        }
      } else {
        if (!cloneableTags[tag]) {
          return object ? value : {};
        }
        result = initCloneByTag(value, tag, baseClone, isDeep);
      }
    }
    stack || (stack = new Stack());
    var stacked = stack.get(value);
    if (stacked) {
      return stacked;
    }
    stack.set(value, result);
    if (!isArr) {
      var props = isFull ? getAllKeys(value) : keys(value);
    }
    arrayEach(props || value, function(subValue, key2) {
      if (props) {
        key2 = subValue;
        subValue = value[key2];
      }
      assignValue(result, key2, baseClone(subValue, isDeep, isFull, customizer, key2, value, stack));
    });
    return result;
  }
  function baseCreate(proto) {
    return isObject2(proto) ? objectCreate(proto) : {};
  }
  function baseGetAllKeys(object, keysFunc, symbolsFunc) {
    var result = keysFunc(object);
    return isArray2(object) ? result : arrayPush(result, symbolsFunc(object));
  }
  function baseGetTag(value) {
    return objectToString2.call(value);
  }
  function baseIsNative(value) {
    if (!isObject2(value) || isMasked(value)) {
      return false;
    }
    var pattern = isFunction(value) || isHostObject(value) ? reIsNative : reIsHostCtor;
    return pattern.test(toSource(value));
  }
  function baseKeys(object) {
    if (!isPrototype(object)) {
      return nativeKeys(object);
    }
    var result = [];
    for (var key in Object(object)) {
      if (hasOwnProperty.call(object, key) && key != "constructor") {
        result.push(key);
      }
    }
    return result;
  }
  function cloneBuffer(buffer, isDeep) {
    if (isDeep) {
      return buffer.slice();
    }
    var result = new buffer.constructor(buffer.length);
    buffer.copy(result);
    return result;
  }
  function cloneArrayBuffer(arrayBuffer) {
    var result = new arrayBuffer.constructor(arrayBuffer.byteLength);
    new Uint8Array2(result).set(new Uint8Array2(arrayBuffer));
    return result;
  }
  function cloneDataView(dataView, isDeep) {
    var buffer = isDeep ? cloneArrayBuffer(dataView.buffer) : dataView.buffer;
    return new dataView.constructor(buffer, dataView.byteOffset, dataView.byteLength);
  }
  function cloneMap(map, isDeep, cloneFunc) {
    var array = isDeep ? cloneFunc(mapToArray(map), true) : mapToArray(map);
    return arrayReduce(array, addMapEntry, new map.constructor());
  }
  function cloneRegExp(regexp) {
    var result = new regexp.constructor(regexp.source, reFlags.exec(regexp));
    result.lastIndex = regexp.lastIndex;
    return result;
  }
  function cloneSet(set, isDeep, cloneFunc) {
    var array = isDeep ? cloneFunc(setToArray(set), true) : setToArray(set);
    return arrayReduce(array, addSetEntry, new set.constructor());
  }
  function cloneSymbol(symbol) {
    return symbolValueOf ? Object(symbolValueOf.call(symbol)) : {};
  }
  function cloneTypedArray(typedArray, isDeep) {
    var buffer = isDeep ? cloneArrayBuffer(typedArray.buffer) : typedArray.buffer;
    return new typedArray.constructor(buffer, typedArray.byteOffset, typedArray.length);
  }
  function copyArray(source, array) {
    var index = -1, length = source.length;
    array || (array = Array(length));
    while (++index < length) {
      array[index] = source[index];
    }
    return array;
  }
  function copyObject(source, props, object, customizer) {
    object || (object = {});
    var index = -1, length = props.length;
    while (++index < length) {
      var key = props[index];
      var newValue = customizer ? customizer(object[key], source[key], key, object, source) : void 0;
      assignValue(object, key, newValue === void 0 ? source[key] : newValue);
    }
    return object;
  }
  function copySymbols(source, object) {
    return copyObject(source, getSymbols(source), object);
  }
  function getAllKeys(object) {
    return baseGetAllKeys(object, keys, getSymbols);
  }
  function getMapData(map, key) {
    var data = map.__data__;
    return isKeyable(key) ? data[typeof key == "string" ? "string" : "hash"] : data.map;
  }
  function getNative(object, key) {
    var value = getValue(object, key);
    return baseIsNative(value) ? value : void 0;
  }
  var getSymbols = nativeGetSymbols ? overArg(nativeGetSymbols, Object) : stubArray;
  var getTag = baseGetTag;
  if (DataView && getTag(new DataView(new ArrayBuffer(1))) != dataViewTag || Map2 && getTag(new Map2()) != mapTag || Promise2 && getTag(Promise2.resolve()) != promiseTag || Set2 && getTag(new Set2()) != setTag || WeakMap2 && getTag(new WeakMap2()) != weakMapTag) {
    getTag = function(value) {
      var result = objectToString2.call(value), Ctor = result == objectTag ? value.constructor : void 0, ctorString = Ctor ? toSource(Ctor) : void 0;
      if (ctorString) {
        switch (ctorString) {
          case dataViewCtorString:
            return dataViewTag;
          case mapCtorString:
            return mapTag;
          case promiseCtorString:
            return promiseTag;
          case setCtorString:
            return setTag;
          case weakMapCtorString:
            return weakMapTag;
        }
      }
      return result;
    };
  }
  function initCloneArray(array) {
    var length = array.length, result = array.constructor(length);
    if (length && typeof array[0] == "string" && hasOwnProperty.call(array, "index")) {
      result.index = array.index;
      result.input = array.input;
    }
    return result;
  }
  function initCloneObject(object) {
    return typeof object.constructor == "function" && !isPrototype(object) ? baseCreate(getPrototype(object)) : {};
  }
  function initCloneByTag(object, tag, cloneFunc, isDeep) {
    var Ctor = object.constructor;
    switch (tag) {
      case arrayBufferTag:
        return cloneArrayBuffer(object);
      case boolTag:
      case dateTag:
        return new Ctor(+object);
      case dataViewTag:
        return cloneDataView(object, isDeep);
      case float32Tag:
      case float64Tag:
      case int8Tag:
      case int16Tag:
      case int32Tag:
      case uint8Tag:
      case uint8ClampedTag:
      case uint16Tag:
      case uint32Tag:
        return cloneTypedArray(object, isDeep);
      case mapTag:
        return cloneMap(object, isDeep, cloneFunc);
      case numberTag:
      case stringTag:
        return new Ctor(object);
      case regexpTag:
        return cloneRegExp(object);
      case setTag:
        return cloneSet(object, isDeep, cloneFunc);
      case symbolTag2:
        return cloneSymbol(object);
    }
  }
  function isIndex(value, length) {
    length = length == null ? MAX_SAFE_INTEGER : length;
    return !!length && (typeof value == "number" || reIsUint.test(value)) && (value > -1 && value % 1 == 0 && value < length);
  }
  function isKeyable(value) {
    var type = typeof value;
    return type == "string" || type == "number" || type == "symbol" || type == "boolean" ? value !== "__proto__" : value === null;
  }
  function isMasked(func) {
    return !!maskSrcKey && maskSrcKey in func;
  }
  function isPrototype(value) {
    var Ctor = value && value.constructor, proto = typeof Ctor == "function" && Ctor.prototype || objectProto2;
    return value === proto;
  }
  function toSource(func) {
    if (func != null) {
      try {
        return funcToString.call(func);
      } catch (e) {
      }
      try {
        return func + "";
      } catch (e) {
      }
    }
    return "";
  }
  function cloneDeep2(value) {
    return baseClone(value, true, true);
  }
  function eq(value, other) {
    return value === other || value !== value && other !== other;
  }
  function isArguments(value) {
    return isArrayLikeObject(value) && hasOwnProperty.call(value, "callee") && (!propertyIsEnumerable.call(value, "callee") || objectToString2.call(value) == argsTag);
  }
  var isArray2 = Array.isArray;
  function isArrayLike(value) {
    return value != null && isLength(value.length) && !isFunction(value);
  }
  function isArrayLikeObject(value) {
    return isObjectLike2(value) && isArrayLike(value);
  }
  var isBuffer = nativeIsBuffer || stubFalse;
  function isFunction(value) {
    var tag = isObject2(value) ? objectToString2.call(value) : "";
    return tag == funcTag || tag == genTag;
  }
  function isLength(value) {
    return typeof value == "number" && value > -1 && value % 1 == 0 && value <= MAX_SAFE_INTEGER;
  }
  function isObject2(value) {
    var type = typeof value;
    return !!value && (type == "object" || type == "function");
  }
  function isObjectLike2(value) {
    return !!value && typeof value == "object";
  }
  function keys(object) {
    return isArrayLike(object) ? arrayLikeKeys(object) : baseKeys(object);
  }
  function stubArray() {
    return [];
  }
  function stubFalse() {
    return false;
  }
  module.exports = cloneDeep2;
})(lodash_clonedeep, lodash_clonedeep.exports);
var cloneDeep = lodash_clonedeep.exports;
var lodash_isequal = { exports: {} };
(function(module, exports) {
  var LARGE_ARRAY_SIZE = 200;
  var HASH_UNDEFINED = "__lodash_hash_undefined__";
  var COMPARE_PARTIAL_FLAG = 1, COMPARE_UNORDERED_FLAG = 2;
  var MAX_SAFE_INTEGER = 9007199254740991;
  var argsTag = "[object Arguments]", arrayTag = "[object Array]", asyncTag = "[object AsyncFunction]", boolTag = "[object Boolean]", dateTag = "[object Date]", errorTag = "[object Error]", funcTag = "[object Function]", genTag = "[object GeneratorFunction]", mapTag = "[object Map]", numberTag = "[object Number]", nullTag = "[object Null]", objectTag = "[object Object]", promiseTag = "[object Promise]", proxyTag = "[object Proxy]", regexpTag = "[object RegExp]", setTag = "[object Set]", stringTag = "[object String]", symbolTag2 = "[object Symbol]", undefinedTag = "[object Undefined]", weakMapTag = "[object WeakMap]";
  var arrayBufferTag = "[object ArrayBuffer]", dataViewTag = "[object DataView]", float32Tag = "[object Float32Array]", float64Tag = "[object Float64Array]", int8Tag = "[object Int8Array]", int16Tag = "[object Int16Array]", int32Tag = "[object Int32Array]", uint8Tag = "[object Uint8Array]", uint8ClampedTag = "[object Uint8ClampedArray]", uint16Tag = "[object Uint16Array]", uint32Tag = "[object Uint32Array]";
  var reRegExpChar = /[\\^$.*+?()[\]{}|]/g;
  var reIsHostCtor = /^\[object .+?Constructor\]$/;
  var reIsUint = /^(?:0|[1-9]\d*)$/;
  var typedArrayTags = {};
  typedArrayTags[float32Tag] = typedArrayTags[float64Tag] = typedArrayTags[int8Tag] = typedArrayTags[int16Tag] = typedArrayTags[int32Tag] = typedArrayTags[uint8Tag] = typedArrayTags[uint8ClampedTag] = typedArrayTags[uint16Tag] = typedArrayTags[uint32Tag] = true;
  typedArrayTags[argsTag] = typedArrayTags[arrayTag] = typedArrayTags[arrayBufferTag] = typedArrayTags[boolTag] = typedArrayTags[dataViewTag] = typedArrayTags[dateTag] = typedArrayTags[errorTag] = typedArrayTags[funcTag] = typedArrayTags[mapTag] = typedArrayTags[numberTag] = typedArrayTags[objectTag] = typedArrayTags[regexpTag] = typedArrayTags[setTag] = typedArrayTags[stringTag] = typedArrayTags[weakMapTag] = false;
  var freeGlobal2 = typeof commonjsGlobal == "object" && commonjsGlobal && commonjsGlobal.Object === Object && commonjsGlobal;
  var freeSelf2 = typeof self == "object" && self && self.Object === Object && self;
  var root2 = freeGlobal2 || freeSelf2 || Function("return this")();
  var freeExports = exports && !exports.nodeType && exports;
  var freeModule = freeExports && true && module && !module.nodeType && module;
  var moduleExports = freeModule && freeModule.exports === freeExports;
  var freeProcess = moduleExports && freeGlobal2.process;
  var nodeUtil = function() {
    try {
      return freeProcess && freeProcess.binding && freeProcess.binding("util");
    } catch (e) {
    }
  }();
  var nodeIsTypedArray = nodeUtil && nodeUtil.isTypedArray;
  function arrayFilter(array, predicate) {
    var index = -1, length = array == null ? 0 : array.length, resIndex = 0, result = [];
    while (++index < length) {
      var value = array[index];
      if (predicate(value, index, array)) {
        result[resIndex++] = value;
      }
    }
    return result;
  }
  function arrayPush(array, values) {
    var index = -1, length = values.length, offset = array.length;
    while (++index < length) {
      array[offset + index] = values[index];
    }
    return array;
  }
  function arraySome(array, predicate) {
    var index = -1, length = array == null ? 0 : array.length;
    while (++index < length) {
      if (predicate(array[index], index, array)) {
        return true;
      }
    }
    return false;
  }
  function baseTimes(n, iteratee) {
    var index = -1, result = Array(n);
    while (++index < n) {
      result[index] = iteratee(index);
    }
    return result;
  }
  function baseUnary(func) {
    return function(value) {
      return func(value);
    };
  }
  function cacheHas(cache, key) {
    return cache.has(key);
  }
  function getValue(object, key) {
    return object == null ? void 0 : object[key];
  }
  function mapToArray(map) {
    var index = -1, result = Array(map.size);
    map.forEach(function(value, key) {
      result[++index] = [key, value];
    });
    return result;
  }
  function overArg(func, transform) {
    return function(arg) {
      return func(transform(arg));
    };
  }
  function setToArray(set) {
    var index = -1, result = Array(set.size);
    set.forEach(function(value) {
      result[++index] = value;
    });
    return result;
  }
  var arrayProto = Array.prototype, funcProto = Function.prototype, objectProto2 = Object.prototype;
  var coreJsData = root2["__core-js_shared__"];
  var funcToString = funcProto.toString;
  var hasOwnProperty = objectProto2.hasOwnProperty;
  var maskSrcKey = function() {
    var uid = /[^.]+$/.exec(coreJsData && coreJsData.keys && coreJsData.keys.IE_PROTO || "");
    return uid ? "Symbol(src)_1." + uid : "";
  }();
  var nativeObjectToString = objectProto2.toString;
  var reIsNative = RegExp("^" + funcToString.call(hasOwnProperty).replace(reRegExpChar, "\\$&").replace(/hasOwnProperty|(function).*?(?=\\\()| for .+?(?=\\\])/g, "$1.*?") + "$");
  var Buffer2 = moduleExports ? root2.Buffer : void 0, Symbol2 = root2.Symbol, Uint8Array2 = root2.Uint8Array, propertyIsEnumerable = objectProto2.propertyIsEnumerable, splice = arrayProto.splice, symToStringTag = Symbol2 ? Symbol2.toStringTag : void 0;
  var nativeGetSymbols = Object.getOwnPropertySymbols, nativeIsBuffer = Buffer2 ? Buffer2.isBuffer : void 0, nativeKeys = overArg(Object.keys, Object);
  var DataView = getNative(root2, "DataView"), Map2 = getNative(root2, "Map"), Promise2 = getNative(root2, "Promise"), Set2 = getNative(root2, "Set"), WeakMap2 = getNative(root2, "WeakMap"), nativeCreate = getNative(Object, "create");
  var dataViewCtorString = toSource(DataView), mapCtorString = toSource(Map2), promiseCtorString = toSource(Promise2), setCtorString = toSource(Set2), weakMapCtorString = toSource(WeakMap2);
  var symbolProto = Symbol2 ? Symbol2.prototype : void 0, symbolValueOf = symbolProto ? symbolProto.valueOf : void 0;
  function Hash(entries) {
    var index = -1, length = entries == null ? 0 : entries.length;
    this.clear();
    while (++index < length) {
      var entry = entries[index];
      this.set(entry[0], entry[1]);
    }
  }
  function hashClear() {
    this.__data__ = nativeCreate ? nativeCreate(null) : {};
    this.size = 0;
  }
  function hashDelete(key) {
    var result = this.has(key) && delete this.__data__[key];
    this.size -= result ? 1 : 0;
    return result;
  }
  function hashGet(key) {
    var data = this.__data__;
    if (nativeCreate) {
      var result = data[key];
      return result === HASH_UNDEFINED ? void 0 : result;
    }
    return hasOwnProperty.call(data, key) ? data[key] : void 0;
  }
  function hashHas(key) {
    var data = this.__data__;
    return nativeCreate ? data[key] !== void 0 : hasOwnProperty.call(data, key);
  }
  function hashSet(key, value) {
    var data = this.__data__;
    this.size += this.has(key) ? 0 : 1;
    data[key] = nativeCreate && value === void 0 ? HASH_UNDEFINED : value;
    return this;
  }
  Hash.prototype.clear = hashClear;
  Hash.prototype["delete"] = hashDelete;
  Hash.prototype.get = hashGet;
  Hash.prototype.has = hashHas;
  Hash.prototype.set = hashSet;
  function ListCache(entries) {
    var index = -1, length = entries == null ? 0 : entries.length;
    this.clear();
    while (++index < length) {
      var entry = entries[index];
      this.set(entry[0], entry[1]);
    }
  }
  function listCacheClear() {
    this.__data__ = [];
    this.size = 0;
  }
  function listCacheDelete(key) {
    var data = this.__data__, index = assocIndexOf(data, key);
    if (index < 0) {
      return false;
    }
    var lastIndex = data.length - 1;
    if (index == lastIndex) {
      data.pop();
    } else {
      splice.call(data, index, 1);
    }
    --this.size;
    return true;
  }
  function listCacheGet(key) {
    var data = this.__data__, index = assocIndexOf(data, key);
    return index < 0 ? void 0 : data[index][1];
  }
  function listCacheHas(key) {
    return assocIndexOf(this.__data__, key) > -1;
  }
  function listCacheSet(key, value) {
    var data = this.__data__, index = assocIndexOf(data, key);
    if (index < 0) {
      ++this.size;
      data.push([key, value]);
    } else {
      data[index][1] = value;
    }
    return this;
  }
  ListCache.prototype.clear = listCacheClear;
  ListCache.prototype["delete"] = listCacheDelete;
  ListCache.prototype.get = listCacheGet;
  ListCache.prototype.has = listCacheHas;
  ListCache.prototype.set = listCacheSet;
  function MapCache(entries) {
    var index = -1, length = entries == null ? 0 : entries.length;
    this.clear();
    while (++index < length) {
      var entry = entries[index];
      this.set(entry[0], entry[1]);
    }
  }
  function mapCacheClear() {
    this.size = 0;
    this.__data__ = {
      "hash": new Hash(),
      "map": new (Map2 || ListCache)(),
      "string": new Hash()
    };
  }
  function mapCacheDelete(key) {
    var result = getMapData(this, key)["delete"](key);
    this.size -= result ? 1 : 0;
    return result;
  }
  function mapCacheGet(key) {
    return getMapData(this, key).get(key);
  }
  function mapCacheHas(key) {
    return getMapData(this, key).has(key);
  }
  function mapCacheSet(key, value) {
    var data = getMapData(this, key), size = data.size;
    data.set(key, value);
    this.size += data.size == size ? 0 : 1;
    return this;
  }
  MapCache.prototype.clear = mapCacheClear;
  MapCache.prototype["delete"] = mapCacheDelete;
  MapCache.prototype.get = mapCacheGet;
  MapCache.prototype.has = mapCacheHas;
  MapCache.prototype.set = mapCacheSet;
  function SetCache(values) {
    var index = -1, length = values == null ? 0 : values.length;
    this.__data__ = new MapCache();
    while (++index < length) {
      this.add(values[index]);
    }
  }
  function setCacheAdd(value) {
    this.__data__.set(value, HASH_UNDEFINED);
    return this;
  }
  function setCacheHas(value) {
    return this.__data__.has(value);
  }
  SetCache.prototype.add = SetCache.prototype.push = setCacheAdd;
  SetCache.prototype.has = setCacheHas;
  function Stack(entries) {
    var data = this.__data__ = new ListCache(entries);
    this.size = data.size;
  }
  function stackClear() {
    this.__data__ = new ListCache();
    this.size = 0;
  }
  function stackDelete(key) {
    var data = this.__data__, result = data["delete"](key);
    this.size = data.size;
    return result;
  }
  function stackGet(key) {
    return this.__data__.get(key);
  }
  function stackHas(key) {
    return this.__data__.has(key);
  }
  function stackSet(key, value) {
    var data = this.__data__;
    if (data instanceof ListCache) {
      var pairs = data.__data__;
      if (!Map2 || pairs.length < LARGE_ARRAY_SIZE - 1) {
        pairs.push([key, value]);
        this.size = ++data.size;
        return this;
      }
      data = this.__data__ = new MapCache(pairs);
    }
    data.set(key, value);
    this.size = data.size;
    return this;
  }
  Stack.prototype.clear = stackClear;
  Stack.prototype["delete"] = stackDelete;
  Stack.prototype.get = stackGet;
  Stack.prototype.has = stackHas;
  Stack.prototype.set = stackSet;
  function arrayLikeKeys(value, inherited) {
    var isArr = isArray2(value), isArg = !isArr && isArguments(value), isBuff = !isArr && !isArg && isBuffer(value), isType = !isArr && !isArg && !isBuff && isTypedArray(value), skipIndexes = isArr || isArg || isBuff || isType, result = skipIndexes ? baseTimes(value.length, String) : [], length = result.length;
    for (var key in value) {
      if ((inherited || hasOwnProperty.call(value, key)) && !(skipIndexes && (key == "length" || isBuff && (key == "offset" || key == "parent") || isType && (key == "buffer" || key == "byteLength" || key == "byteOffset") || isIndex(key, length)))) {
        result.push(key);
      }
    }
    return result;
  }
  function assocIndexOf(array, key) {
    var length = array.length;
    while (length--) {
      if (eq(array[length][0], key)) {
        return length;
      }
    }
    return -1;
  }
  function baseGetAllKeys(object, keysFunc, symbolsFunc) {
    var result = keysFunc(object);
    return isArray2(object) ? result : arrayPush(result, symbolsFunc(object));
  }
  function baseGetTag(value) {
    if (value == null) {
      return value === void 0 ? undefinedTag : nullTag;
    }
    return symToStringTag && symToStringTag in Object(value) ? getRawTag(value) : objectToString2(value);
  }
  function baseIsArguments(value) {
    return isObjectLike2(value) && baseGetTag(value) == argsTag;
  }
  function baseIsEqual(value, other, bitmask, customizer, stack) {
    if (value === other) {
      return true;
    }
    if (value == null || other == null || !isObjectLike2(value) && !isObjectLike2(other)) {
      return value !== value && other !== other;
    }
    return baseIsEqualDeep(value, other, bitmask, customizer, baseIsEqual, stack);
  }
  function baseIsEqualDeep(object, other, bitmask, customizer, equalFunc, stack) {
    var objIsArr = isArray2(object), othIsArr = isArray2(other), objTag = objIsArr ? arrayTag : getTag(object), othTag = othIsArr ? arrayTag : getTag(other);
    objTag = objTag == argsTag ? objectTag : objTag;
    othTag = othTag == argsTag ? objectTag : othTag;
    var objIsObj = objTag == objectTag, othIsObj = othTag == objectTag, isSameTag = objTag == othTag;
    if (isSameTag && isBuffer(object)) {
      if (!isBuffer(other)) {
        return false;
      }
      objIsArr = true;
      objIsObj = false;
    }
    if (isSameTag && !objIsObj) {
      stack || (stack = new Stack());
      return objIsArr || isTypedArray(object) ? equalArrays(object, other, bitmask, customizer, equalFunc, stack) : equalByTag(object, other, objTag, bitmask, customizer, equalFunc, stack);
    }
    if (!(bitmask & COMPARE_PARTIAL_FLAG)) {
      var objIsWrapped = objIsObj && hasOwnProperty.call(object, "__wrapped__"), othIsWrapped = othIsObj && hasOwnProperty.call(other, "__wrapped__");
      if (objIsWrapped || othIsWrapped) {
        var objUnwrapped = objIsWrapped ? object.value() : object, othUnwrapped = othIsWrapped ? other.value() : other;
        stack || (stack = new Stack());
        return equalFunc(objUnwrapped, othUnwrapped, bitmask, customizer, stack);
      }
    }
    if (!isSameTag) {
      return false;
    }
    stack || (stack = new Stack());
    return equalObjects(object, other, bitmask, customizer, equalFunc, stack);
  }
  function baseIsNative(value) {
    if (!isObject2(value) || isMasked(value)) {
      return false;
    }
    var pattern = isFunction(value) ? reIsNative : reIsHostCtor;
    return pattern.test(toSource(value));
  }
  function baseIsTypedArray(value) {
    return isObjectLike2(value) && isLength(value.length) && !!typedArrayTags[baseGetTag(value)];
  }
  function baseKeys(object) {
    if (!isPrototype(object)) {
      return nativeKeys(object);
    }
    var result = [];
    for (var key in Object(object)) {
      if (hasOwnProperty.call(object, key) && key != "constructor") {
        result.push(key);
      }
    }
    return result;
  }
  function equalArrays(array, other, bitmask, customizer, equalFunc, stack) {
    var isPartial = bitmask & COMPARE_PARTIAL_FLAG, arrLength = array.length, othLength = other.length;
    if (arrLength != othLength && !(isPartial && othLength > arrLength)) {
      return false;
    }
    var stacked = stack.get(array);
    if (stacked && stack.get(other)) {
      return stacked == other;
    }
    var index = -1, result = true, seen = bitmask & COMPARE_UNORDERED_FLAG ? new SetCache() : void 0;
    stack.set(array, other);
    stack.set(other, array);
    while (++index < arrLength) {
      var arrValue = array[index], othValue = other[index];
      if (customizer) {
        var compared = isPartial ? customizer(othValue, arrValue, index, other, array, stack) : customizer(arrValue, othValue, index, array, other, stack);
      }
      if (compared !== void 0) {
        if (compared) {
          continue;
        }
        result = false;
        break;
      }
      if (seen) {
        if (!arraySome(other, function(othValue2, othIndex) {
          if (!cacheHas(seen, othIndex) && (arrValue === othValue2 || equalFunc(arrValue, othValue2, bitmask, customizer, stack))) {
            return seen.push(othIndex);
          }
        })) {
          result = false;
          break;
        }
      } else if (!(arrValue === othValue || equalFunc(arrValue, othValue, bitmask, customizer, stack))) {
        result = false;
        break;
      }
    }
    stack["delete"](array);
    stack["delete"](other);
    return result;
  }
  function equalByTag(object, other, tag, bitmask, customizer, equalFunc, stack) {
    switch (tag) {
      case dataViewTag:
        if (object.byteLength != other.byteLength || object.byteOffset != other.byteOffset) {
          return false;
        }
        object = object.buffer;
        other = other.buffer;
      case arrayBufferTag:
        if (object.byteLength != other.byteLength || !equalFunc(new Uint8Array2(object), new Uint8Array2(other))) {
          return false;
        }
        return true;
      case boolTag:
      case dateTag:
      case numberTag:
        return eq(+object, +other);
      case errorTag:
        return object.name == other.name && object.message == other.message;
      case regexpTag:
      case stringTag:
        return object == other + "";
      case mapTag:
        var convert = mapToArray;
      case setTag:
        var isPartial = bitmask & COMPARE_PARTIAL_FLAG;
        convert || (convert = setToArray);
        if (object.size != other.size && !isPartial) {
          return false;
        }
        var stacked = stack.get(object);
        if (stacked) {
          return stacked == other;
        }
        bitmask |= COMPARE_UNORDERED_FLAG;
        stack.set(object, other);
        var result = equalArrays(convert(object), convert(other), bitmask, customizer, equalFunc, stack);
        stack["delete"](object);
        return result;
      case symbolTag2:
        if (symbolValueOf) {
          return symbolValueOf.call(object) == symbolValueOf.call(other);
        }
    }
    return false;
  }
  function equalObjects(object, other, bitmask, customizer, equalFunc, stack) {
    var isPartial = bitmask & COMPARE_PARTIAL_FLAG, objProps = getAllKeys(object), objLength = objProps.length, othProps = getAllKeys(other), othLength = othProps.length;
    if (objLength != othLength && !isPartial) {
      return false;
    }
    var index = objLength;
    while (index--) {
      var key = objProps[index];
      if (!(isPartial ? key in other : hasOwnProperty.call(other, key))) {
        return false;
      }
    }
    var stacked = stack.get(object);
    if (stacked && stack.get(other)) {
      return stacked == other;
    }
    var result = true;
    stack.set(object, other);
    stack.set(other, object);
    var skipCtor = isPartial;
    while (++index < objLength) {
      key = objProps[index];
      var objValue = object[key], othValue = other[key];
      if (customizer) {
        var compared = isPartial ? customizer(othValue, objValue, key, other, object, stack) : customizer(objValue, othValue, key, object, other, stack);
      }
      if (!(compared === void 0 ? objValue === othValue || equalFunc(objValue, othValue, bitmask, customizer, stack) : compared)) {
        result = false;
        break;
      }
      skipCtor || (skipCtor = key == "constructor");
    }
    if (result && !skipCtor) {
      var objCtor = object.constructor, othCtor = other.constructor;
      if (objCtor != othCtor && ("constructor" in object && "constructor" in other) && !(typeof objCtor == "function" && objCtor instanceof objCtor && typeof othCtor == "function" && othCtor instanceof othCtor)) {
        result = false;
      }
    }
    stack["delete"](object);
    stack["delete"](other);
    return result;
  }
  function getAllKeys(object) {
    return baseGetAllKeys(object, keys, getSymbols);
  }
  function getMapData(map, key) {
    var data = map.__data__;
    return isKeyable(key) ? data[typeof key == "string" ? "string" : "hash"] : data.map;
  }
  function getNative(object, key) {
    var value = getValue(object, key);
    return baseIsNative(value) ? value : void 0;
  }
  function getRawTag(value) {
    var isOwn = hasOwnProperty.call(value, symToStringTag), tag = value[symToStringTag];
    try {
      value[symToStringTag] = void 0;
      var unmasked = true;
    } catch (e) {
    }
    var result = nativeObjectToString.call(value);
    if (unmasked) {
      if (isOwn) {
        value[symToStringTag] = tag;
      } else {
        delete value[symToStringTag];
      }
    }
    return result;
  }
  var getSymbols = !nativeGetSymbols ? stubArray : function(object) {
    if (object == null) {
      return [];
    }
    object = Object(object);
    return arrayFilter(nativeGetSymbols(object), function(symbol) {
      return propertyIsEnumerable.call(object, symbol);
    });
  };
  var getTag = baseGetTag;
  if (DataView && getTag(new DataView(new ArrayBuffer(1))) != dataViewTag || Map2 && getTag(new Map2()) != mapTag || Promise2 && getTag(Promise2.resolve()) != promiseTag || Set2 && getTag(new Set2()) != setTag || WeakMap2 && getTag(new WeakMap2()) != weakMapTag) {
    getTag = function(value) {
      var result = baseGetTag(value), Ctor = result == objectTag ? value.constructor : void 0, ctorString = Ctor ? toSource(Ctor) : "";
      if (ctorString) {
        switch (ctorString) {
          case dataViewCtorString:
            return dataViewTag;
          case mapCtorString:
            return mapTag;
          case promiseCtorString:
            return promiseTag;
          case setCtorString:
            return setTag;
          case weakMapCtorString:
            return weakMapTag;
        }
      }
      return result;
    };
  }
  function isIndex(value, length) {
    length = length == null ? MAX_SAFE_INTEGER : length;
    return !!length && (typeof value == "number" || reIsUint.test(value)) && (value > -1 && value % 1 == 0 && value < length);
  }
  function isKeyable(value) {
    var type = typeof value;
    return type == "string" || type == "number" || type == "symbol" || type == "boolean" ? value !== "__proto__" : value === null;
  }
  function isMasked(func) {
    return !!maskSrcKey && maskSrcKey in func;
  }
  function isPrototype(value) {
    var Ctor = value && value.constructor, proto = typeof Ctor == "function" && Ctor.prototype || objectProto2;
    return value === proto;
  }
  function objectToString2(value) {
    return nativeObjectToString.call(value);
  }
  function toSource(func) {
    if (func != null) {
      try {
        return funcToString.call(func);
      } catch (e) {
      }
      try {
        return func + "";
      } catch (e) {
      }
    }
    return "";
  }
  function eq(value, other) {
    return value === other || value !== value && other !== other;
  }
  var isArguments = baseIsArguments(function() {
    return arguments;
  }()) ? baseIsArguments : function(value) {
    return isObjectLike2(value) && hasOwnProperty.call(value, "callee") && !propertyIsEnumerable.call(value, "callee");
  };
  var isArray2 = Array.isArray;
  function isArrayLike(value) {
    return value != null && isLength(value.length) && !isFunction(value);
  }
  var isBuffer = nativeIsBuffer || stubFalse;
  function isEqual2(value, other) {
    return baseIsEqual(value, other);
  }
  function isFunction(value) {
    if (!isObject2(value)) {
      return false;
    }
    var tag = baseGetTag(value);
    return tag == funcTag || tag == genTag || tag == asyncTag || tag == proxyTag;
  }
  function isLength(value) {
    return typeof value == "number" && value > -1 && value % 1 == 0 && value <= MAX_SAFE_INTEGER;
  }
  function isObject2(value) {
    var type = typeof value;
    return value != null && (type == "object" || type == "function");
  }
  function isObjectLike2(value) {
    return value != null && typeof value == "object";
  }
  var isTypedArray = nodeIsTypedArray ? baseUnary(nodeIsTypedArray) : baseIsTypedArray;
  function keys(object) {
    return isArrayLike(object) ? arrayLikeKeys(object) : baseKeys(object);
  }
  function stubArray() {
    return [];
  }
  function stubFalse() {
    return false;
  }
  module.exports = isEqual2;
})(lodash_isequal, lodash_isequal.exports);
var isEqual = lodash_isequal.exports;
var AttributeMap;
((AttributeMap2) => {
  function compose(a = {}, b = {}, keepNull) {
    if (typeof a !== "object") {
      a = {};
    }
    if (typeof b !== "object") {
      b = {};
    }
    let attributes = cloneDeep(b);
    if (!keepNull) {
      attributes = Object.keys(attributes).reduce((copy, key) => {
        if (attributes[key] != null) {
          copy[key] = attributes[key];
        }
        return copy;
      }, {});
    }
    for (const key in a) {
      if (a[key] !== void 0 && b[key] === void 0) {
        attributes[key] = a[key];
      }
    }
    return Object.keys(attributes).length > 0 ? attributes : void 0;
  }
  AttributeMap2.compose = compose;
  function diff2(a = {}, b = {}) {
    if (typeof a !== "object") {
      a = {};
    }
    if (typeof b !== "object") {
      b = {};
    }
    const attributes = Object.keys(a).concat(Object.keys(b)).reduce((attrs, key) => {
      if (!isEqual(a[key], b[key])) {
        attrs[key] = b[key] === void 0 ? null : b[key];
      }
      return attrs;
    }, {});
    return Object.keys(attributes).length > 0 ? attributes : void 0;
  }
  AttributeMap2.diff = diff2;
  function invert(attr = {}, base = {}) {
    attr = attr || {};
    const baseInverted = Object.keys(base).reduce((memo, key) => {
      if (base[key] !== attr[key] && attr[key] !== void 0) {
        memo[key] = base[key];
      }
      return memo;
    }, {});
    return Object.keys(attr).reduce((memo, key) => {
      if (attr[key] !== base[key] && base[key] === void 0) {
        memo[key] = null;
      }
      return memo;
    }, baseInverted);
  }
  AttributeMap2.invert = invert;
  function transform(a, b, priority = false) {
    if (typeof a !== "object") {
      return b;
    }
    if (typeof b !== "object") {
      return void 0;
    }
    if (!priority) {
      return b;
    }
    const attributes = Object.keys(b).reduce((attrs, key) => {
      if (a[key] === void 0) {
        attrs[key] = b[key];
      }
      return attrs;
    }, {});
    return Object.keys(attributes).length > 0 ? attributes : void 0;
  }
  AttributeMap2.transform = transform;
})(AttributeMap || (AttributeMap = {}));
var AttributeMap$1 = AttributeMap;
var Op;
((Op2) => {
  function length(op) {
    if (typeof op.delete === "number") {
      return op.delete;
    } else if (typeof op.retain === "number") {
      return op.retain;
    } else if (typeof op.retain === "object" && op.retain !== null) {
      return 1;
    } else {
      return typeof op.insert === "string" ? op.insert.length : 1;
    }
  }
  Op2.length = length;
})(Op || (Op = {}));
var Op$1 = Op;
class Iterator {
  constructor(ops) {
    this.ops = ops;
    this.index = 0;
    this.offset = 0;
  }
  hasNext() {
    return this.peekLength() < Infinity;
  }
  next(length) {
    if (!length) {
      length = Infinity;
    }
    const nextOp = this.ops[this.index];
    if (nextOp) {
      const offset = this.offset;
      const opLength = Op$1.length(nextOp);
      if (length >= opLength - offset) {
        length = opLength - offset;
        this.index += 1;
        this.offset = 0;
      } else {
        this.offset += length;
      }
      if (typeof nextOp.delete === "number") {
        return { delete: length };
      } else {
        const retOp = {};
        if (nextOp.attributes) {
          retOp.attributes = nextOp.attributes;
        }
        if (typeof nextOp.retain === "number") {
          retOp.retain = length;
        } else if (typeof nextOp.retain === "object" && nextOp.retain !== null) {
          retOp.retain = nextOp.retain;
        } else if (typeof nextOp.insert === "string") {
          retOp.insert = nextOp.insert.substr(offset, length);
        } else {
          retOp.insert = nextOp.insert;
        }
        return retOp;
      }
    } else {
      return { retain: Infinity };
    }
  }
  peek() {
    return this.ops[this.index];
  }
  peekLength() {
    if (this.ops[this.index]) {
      return Op$1.length(this.ops[this.index]) - this.offset;
    } else {
      return Infinity;
    }
  }
  peekType() {
    const op = this.ops[this.index];
    if (op) {
      if (typeof op.delete === "number") {
        return "delete";
      } else if (typeof op.retain === "number" || typeof op.retain === "object" && op.retain !== null) {
        return "retain";
      } else {
        return "insert";
      }
    }
    return "retain";
  }
  rest() {
    if (!this.hasNext()) {
      return [];
    } else if (this.offset === 0) {
      return this.ops.slice(this.index);
    } else {
      const offset = this.offset;
      const index = this.index;
      const next = this.next();
      const rest = this.ops.slice(this.index);
      this.offset = offset;
      this.index = index;
      return [next].concat(rest);
    }
  }
}
const NULL_CHARACTER = String.fromCharCode(0);
const getEmbedTypeAndData = (a, b) => {
  if (typeof a !== "object" || a === null) {
    throw new Error(`cannot retain a ${typeof a}`);
  }
  if (typeof b !== "object" || b === null) {
    throw new Error(`cannot retain a ${typeof b}`);
  }
  const embedType = Object.keys(a)[0];
  if (!embedType || embedType !== Object.keys(b)[0]) {
    throw new Error(`embed types not matched: ${embedType} != ${Object.keys(b)[0]}`);
  }
  return [embedType, a[embedType], b[embedType]];
};
const _Delta = class {
  static registerEmbed(embedType, handler) {
    this.handlers[embedType] = handler;
  }
  static unregisterEmbed(embedType) {
    delete this.handlers[embedType];
  }
  static getHandler(embedType) {
    const handler = this.handlers[embedType];
    if (!handler) {
      throw new Error(`no handlers for embed type "${embedType}"`);
    }
    return handler;
  }
  constructor(ops) {
    if (Array.isArray(ops)) {
      this.ops = ops;
    } else if (ops != null && Array.isArray(ops.ops)) {
      this.ops = ops.ops;
    } else {
      this.ops = [];
    }
  }
  insert(arg, attributes) {
    const newOp = {};
    if (typeof arg === "string" && arg.length === 0) {
      return this;
    }
    newOp.insert = arg;
    if (attributes != null && typeof attributes === "object" && Object.keys(attributes).length > 0) {
      newOp.attributes = attributes;
    }
    return this.push(newOp);
  }
  delete(length) {
    if (length <= 0) {
      return this;
    }
    return this.push({ delete: length });
  }
  retain(length, attributes) {
    if (typeof length === "number" && length <= 0) {
      return this;
    }
    const newOp = { retain: length };
    if (attributes != null && typeof attributes === "object" && Object.keys(attributes).length > 0) {
      newOp.attributes = attributes;
    }
    return this.push(newOp);
  }
  push(newOp) {
    let index = this.ops.length;
    let lastOp = this.ops[index - 1];
    newOp = cloneDeep(newOp);
    if (typeof lastOp === "object") {
      if (typeof newOp.delete === "number" && typeof lastOp.delete === "number") {
        this.ops[index - 1] = { delete: lastOp.delete + newOp.delete };
        return this;
      }
      if (typeof lastOp.delete === "number" && newOp.insert != null) {
        index -= 1;
        lastOp = this.ops[index - 1];
        if (typeof lastOp !== "object") {
          this.ops.unshift(newOp);
          return this;
        }
      }
      if (isEqual(newOp.attributes, lastOp.attributes)) {
        if (typeof newOp.insert === "string" && typeof lastOp.insert === "string") {
          this.ops[index - 1] = { insert: lastOp.insert + newOp.insert };
          if (typeof newOp.attributes === "object") {
            this.ops[index - 1].attributes = newOp.attributes;
          }
          return this;
        } else if (typeof newOp.retain === "number" && typeof lastOp.retain === "number") {
          this.ops[index - 1] = { retain: lastOp.retain + newOp.retain };
          if (typeof newOp.attributes === "object") {
            this.ops[index - 1].attributes = newOp.attributes;
          }
          return this;
        }
      }
    }
    if (index === this.ops.length) {
      this.ops.push(newOp);
    } else {
      this.ops.splice(index, 0, newOp);
    }
    return this;
  }
  chop() {
    const lastOp = this.ops[this.ops.length - 1];
    if (lastOp && typeof lastOp.retain === "number" && !lastOp.attributes) {
      this.ops.pop();
    }
    return this;
  }
  filter(predicate) {
    return this.ops.filter(predicate);
  }
  forEach(predicate) {
    this.ops.forEach(predicate);
  }
  map(predicate) {
    return this.ops.map(predicate);
  }
  partition(predicate) {
    const passed = [];
    const failed = [];
    this.forEach((op) => {
      const target = predicate(op) ? passed : failed;
      target.push(op);
    });
    return [passed, failed];
  }
  reduce(predicate, initialValue) {
    return this.ops.reduce(predicate, initialValue);
  }
  changeLength() {
    return this.reduce((length, elem) => {
      if (elem.insert) {
        return length + Op$1.length(elem);
      } else if (elem.delete) {
        return length - elem.delete;
      }
      return length;
    }, 0);
  }
  length() {
    return this.reduce((length, elem) => {
      return length + Op$1.length(elem);
    }, 0);
  }
  slice(start = 0, end = Infinity) {
    const ops = [];
    const iter = new Iterator(this.ops);
    let index = 0;
    while (index < end && iter.hasNext()) {
      let nextOp;
      if (index < start) {
        nextOp = iter.next(start - index);
      } else {
        nextOp = iter.next(end - index);
        ops.push(nextOp);
      }
      index += Op$1.length(nextOp);
    }
    return new _Delta(ops);
  }
  compose(other) {
    const thisIter = new Iterator(this.ops);
    const otherIter = new Iterator(other.ops);
    const ops = [];
    const firstOther = otherIter.peek();
    if (firstOther != null && typeof firstOther.retain === "number" && firstOther.attributes == null) {
      let firstLeft = firstOther.retain;
      while (thisIter.peekType() === "insert" && thisIter.peekLength() <= firstLeft) {
        firstLeft -= thisIter.peekLength();
        ops.push(thisIter.next());
      }
      if (firstOther.retain - firstLeft > 0) {
        otherIter.next(firstOther.retain - firstLeft);
      }
    }
    const delta = new _Delta(ops);
    while (thisIter.hasNext() || otherIter.hasNext()) {
      if (otherIter.peekType() === "insert") {
        delta.push(otherIter.next());
      } else if (thisIter.peekType() === "delete") {
        delta.push(thisIter.next());
      } else {
        const length = Math.min(thisIter.peekLength(), otherIter.peekLength());
        const thisOp = thisIter.next(length);
        const otherOp = otherIter.next(length);
        if (otherOp.retain) {
          const newOp = {};
          if (typeof thisOp.retain === "number") {
            newOp.retain = typeof otherOp.retain === "number" ? length : otherOp.retain;
          } else {
            if (typeof otherOp.retain === "number") {
              if (thisOp.retain == null) {
                newOp.insert = thisOp.insert;
              } else {
                newOp.retain = thisOp.retain;
              }
            } else {
              const action = thisOp.retain == null ? "insert" : "retain";
              const [embedType, thisData, otherData] = getEmbedTypeAndData(thisOp[action], otherOp.retain);
              const handler = _Delta.getHandler(embedType);
              newOp[action] = {
                [embedType]: handler.compose(thisData, otherData, action === "retain")
              };
            }
          }
          const attributes = AttributeMap$1.compose(thisOp.attributes, otherOp.attributes, typeof thisOp.retain === "number");
          if (attributes) {
            newOp.attributes = attributes;
          }
          delta.push(newOp);
          if (!otherIter.hasNext() && isEqual(delta.ops[delta.ops.length - 1], newOp)) {
            const rest = new _Delta(thisIter.rest());
            return delta.concat(rest).chop();
          }
        } else if (typeof otherOp.delete === "number" && (typeof thisOp.retain === "number" || typeof thisOp.retain === "object" && thisOp.retain !== null)) {
          delta.push(otherOp);
        }
      }
    }
    return delta.chop();
  }
  concat(other) {
    const delta = new _Delta(this.ops.slice());
    if (other.ops.length > 0) {
      delta.push(other.ops[0]);
      delta.ops = delta.ops.concat(other.ops.slice(1));
    }
    return delta;
  }
  diff(other, cursor) {
    if (this.ops === other.ops) {
      return new _Delta();
    }
    const strings = [this, other].map((delta) => {
      return delta.map((op) => {
        if (op.insert != null) {
          return typeof op.insert === "string" ? op.insert : NULL_CHARACTER;
        }
        const prep = delta === other ? "on" : "with";
        throw new Error("diff() called " + prep + " non-document");
      }).join("");
    });
    const retDelta = new _Delta();
    const diffResult = diff_1(strings[0], strings[1], cursor);
    const thisIter = new Iterator(this.ops);
    const otherIter = new Iterator(other.ops);
    diffResult.forEach((component) => {
      let length = component[1].length;
      while (length > 0) {
        let opLength = 0;
        switch (component[0]) {
          case diff_1.INSERT:
            opLength = Math.min(otherIter.peekLength(), length);
            retDelta.push(otherIter.next(opLength));
            break;
          case diff_1.DELETE:
            opLength = Math.min(length, thisIter.peekLength());
            thisIter.next(opLength);
            retDelta.delete(opLength);
            break;
          case diff_1.EQUAL:
            opLength = Math.min(thisIter.peekLength(), otherIter.peekLength(), length);
            const thisOp = thisIter.next(opLength);
            const otherOp = otherIter.next(opLength);
            if (isEqual(thisOp.insert, otherOp.insert)) {
              retDelta.retain(opLength, AttributeMap$1.diff(thisOp.attributes, otherOp.attributes));
            } else {
              retDelta.push(otherOp).delete(opLength);
            }
            break;
        }
        length -= opLength;
      }
    });
    return retDelta.chop();
  }
  eachLine(predicate, newline = "\n") {
    const iter = new Iterator(this.ops);
    let line = new _Delta();
    let i = 0;
    while (iter.hasNext()) {
      if (iter.peekType() !== "insert") {
        return;
      }
      const thisOp = iter.peek();
      const start = Op$1.length(thisOp) - iter.peekLength();
      const index = typeof thisOp.insert === "string" ? thisOp.insert.indexOf(newline, start) - start : -1;
      if (index < 0) {
        line.push(iter.next());
      } else if (index > 0) {
        line.push(iter.next(index));
      } else {
        if (predicate(line, iter.next(1).attributes || {}, i) === false) {
          return;
        }
        i += 1;
        line = new _Delta();
      }
    }
    if (line.length() > 0) {
      predicate(line, {}, i);
    }
  }
  invert(base) {
    const inverted = new _Delta();
    this.reduce((baseIndex, op) => {
      if (op.insert) {
        inverted.delete(Op$1.length(op));
      } else if (typeof op.retain === "number" && op.attributes == null) {
        inverted.retain(op.retain);
        return baseIndex + op.retain;
      } else if (op.delete || typeof op.retain === "number") {
        const length = op.delete || op.retain;
        const slice = base.slice(baseIndex, baseIndex + length);
        slice.forEach((baseOp) => {
          if (op.delete) {
            inverted.push(baseOp);
          } else if (op.retain && op.attributes) {
            inverted.retain(Op$1.length(baseOp), AttributeMap$1.invert(op.attributes, baseOp.attributes));
          }
        });
        return baseIndex + length;
      } else if (typeof op.retain === "object" && op.retain !== null) {
        const slice = base.slice(baseIndex, baseIndex + 1);
        const baseOp = new Iterator(slice.ops).next();
        const [embedType, opData, baseOpData] = getEmbedTypeAndData(op.retain, baseOp.insert);
        const handler = _Delta.getHandler(embedType);
        inverted.retain({ [embedType]: handler.invert(opData, baseOpData) }, AttributeMap$1.invert(op.attributes, baseOp.attributes));
        return baseIndex + 1;
      }
      return baseIndex;
    }, 0);
    return inverted.chop();
  }
  transform(arg, priority = false) {
    priority = !!priority;
    if (typeof arg === "number") {
      return this.transformPosition(arg, priority);
    }
    const other = arg;
    const thisIter = new Iterator(this.ops);
    const otherIter = new Iterator(other.ops);
    const delta = new _Delta();
    while (thisIter.hasNext() || otherIter.hasNext()) {
      if (thisIter.peekType() === "insert" && (priority || otherIter.peekType() !== "insert")) {
        delta.retain(Op$1.length(thisIter.next()));
      } else if (otherIter.peekType() === "insert") {
        delta.push(otherIter.next());
      } else {
        const length = Math.min(thisIter.peekLength(), otherIter.peekLength());
        const thisOp = thisIter.next(length);
        const otherOp = otherIter.next(length);
        if (thisOp.delete) {
          continue;
        } else if (otherOp.delete) {
          delta.push(otherOp);
        } else {
          const thisData = thisOp.retain;
          const otherData = otherOp.retain;
          let transformedData = typeof otherData === "object" && otherData !== null ? otherData : length;
          if (typeof thisData === "object" && thisData !== null && typeof otherData === "object" && otherData !== null) {
            const embedType = Object.keys(thisData)[0];
            if (embedType === Object.keys(otherData)[0]) {
              const handler = _Delta.getHandler(embedType);
              if (handler) {
                transformedData = {
                  [embedType]: handler.transform(thisData[embedType], otherData[embedType], priority)
                };
              }
            }
          }
          delta.retain(transformedData, AttributeMap$1.transform(thisOp.attributes, otherOp.attributes, priority));
        }
      }
    }
    return delta.chop();
  }
  transformPosition(index, priority = false) {
    priority = !!priority;
    const thisIter = new Iterator(this.ops);
    let offset = 0;
    while (thisIter.hasNext() && offset <= index) {
      const length = thisIter.peekLength();
      const nextType = thisIter.peekType();
      thisIter.next();
      if (nextType === "delete") {
        index -= Math.min(length, index - offset);
        continue;
      } else if (nextType === "insert" && (offset < index || !priority)) {
        index += length;
      }
      offset += length;
    }
    return index;
  }
};
let Delta = _Delta;
Delta.Op = Op$1;
Delta.OpIterator = Iterator;
Delta.AttributeMap = AttributeMap$1;
Delta.handlers = {};
var index_es = /* @__PURE__ */ Object.freeze({
  __proto__: null,
  [Symbol.toStringTag]: "Module",
  AttributeMap: AttributeMap$1,
  Op: Op$1,
  "default": Delta
});
var require$$0 = /* @__PURE__ */ getAugmentedNamespace(index_es);
(function(module, exports) {
  var __defProp2 = Object.defineProperty, __defProps = Object.defineProperties, __getOwnPropDescs = Object.getOwnPropertyDescriptors, __getOwnPropSymbols = Object.getOwnPropertySymbols, __hasOwnProp = Object.prototype.hasOwnProperty, __propIsEnum = Object.prototype.propertyIsEnumerable, __defNormalProp2 = (e, r, t) => r in e ? __defProp2(e, r, { enumerable: true, configurable: true, writable: true, value: t }) : e[r] = t, __spreadValues = (e, r) => {
    for (var t in r || (r = {}))
      __hasOwnProp.call(r, t) && __defNormalProp2(e, t, r[t]);
    if (__getOwnPropSymbols)
      for (var t of __getOwnPropSymbols(r))
        __propIsEnum.call(r, t) && __defNormalProp2(e, t, r[t]);
    return e;
  }, __spreadProps = (e, r) => __defProps(e, __getOwnPropDescs(r));
  !function(e, r) {
    module.exports = r(require$$0);
  }(commonjsGlobal$1, function(e) {
    function r(e2) {
      return e2 && typeof e2 == "object" && "default" in e2 ? e2 : { default: e2 };
    }
    var t = r(e);
    return { type: { name: "rich-text", uri: "http://sharejs.org/types/rich-text/v1", create: (e2) => new t.default(e2), apply(e2, r2) {
      const o = new t.default(e2), n = new t.default(r2);
      return o.compose(n).ops;
    }, compose(e2, r2) {
      const o = new t.default(e2), n = new t.default(r2);
      return o.compose(n).ops;
    }, diff(e2, r2) {
      const o = new t.default(e2), n = new t.default(r2);
      return o.diff(n).ops;
    }, transform(e2, r2, o) {
      const n = new t.default(e2);
      return new t.default(r2).transform(n, o === "left").ops;
    }, transformCursor: (e2, r2, t2) => r2.transformPosition(e2, !t2), normalize: (e2) => e2, serialize: (e2) => e2.ops, deserialize: (e2) => e2, transformPresence(e2, r2, o) {
      if (!e2)
        return null;
      const n = new t.default(r2), s = this.transformCursor(e2.index, n, o), p = this.transformCursor(e2.index + e2.length, n, o);
      return __spreadProps(__spreadValues({}, e2), { index: s, length: p - s });
    } } };
  });
})(richText_umd);
var richText = richText_umd.exports;
const console$1 = getLogger("client");
const JSON1_TYPE_NAME = "ot-json1";
json1.type.registerSubtype(richText.type);
json1.type.name = JSON1_TYPE_NAME;
types.register(json1.type);
class ShareDBDocClient {
  constructor(options, events2) {
    __publicField(this, "socket");
    __publicField(this, "connection");
    __publicField(this, "presence");
    __publicField(this, "localPresence", null);
    __publicField(this, "orgMessageHandler");
    __publicField(this, "docUser", null);
    __publicField(this, "remoteUsers", new RemoteUsers());
    __publicField(this, "clientId", genId());
    __publicField(this, "doc");
    __publicField(this, "handleSubscribe", (error2) => {
      if (error2) {
        this.events.onError("Subscribe", error2);
      } else {
        this.events.onSubscribe();
        this.sendJoinMessage();
      }
    });
    __publicField(this, "handleSubscribePresence", (error2) => {
      if (error2) {
        this.events.onError("Presence", new Error("failed to subscribe presence"));
      }
      this.presence.on("receive", this.handlePresenceMessage);
    });
    __publicField(this, "handleSocketError", (error2) => {
      this.events.onError("WebSocket", error2);
    });
    __publicField(this, "handleSocketClose", (event) => {
      this.events.onClose(event);
    });
    __publicField(this, "handleWebsocketMessage", (event) => {
      if (this.handleCustomMessage(event)) {
        return;
      }
      if (this.orgMessageHandler) {
        this.orgMessageHandler(event);
      }
    });
    __publicField(this, "handleCustomMessage", (event) => {
      const data = event.data;
      if (typeof data !== "string") {
        return false;
      }
      try {
        const message = JSON.parse(data);
        if (typeof message === "object" && typeof message.nexteditor === "string") {
          this.handleKnownCustomMessage(message);
          return true;
        }
      } catch (err) {
        console$1.error(JSON.stringify(err));
      }
      return false;
    });
    __publicField(this, "handleKnownCustomMessage", (message) => {
      if (message.nexteditor === "init") {
        this.handleInitMessage(message);
      } else if (message.nexteditor === "welcome") {
        this.handleWelcomeMessage(message);
      }
    });
    __publicField(this, "handleInitMessage", (message) => {
      if (this.localPresence) {
        console$1.debug("reconnected");
        assert(this.docUser, "user not exists");
        assert(this.docUser.userId === message.user.userId, "reconnect, user does not match");
        this.docUser = message.user;
        return;
      }
      this.docUser = message.user;
      assert(!this.localPresence, "local presence has already exists");
      this.localPresence = this.presence.create(this.docUser.clientId);
      this.doc.subscribe(this.handleSubscribe);
      this.doc.on("op", this.events.onOp);
    });
    __publicField(this, "handleWelcomeMessage", (message) => {
      this.remoteUsers.addUsers(message.onlineUsers);
    });
    __publicField(this, "handlePresenceMessage", (id, value) => {
      const message = value;
      if ((message == null ? void 0 : message.nexteditor) === "join") {
        console$1.debug(`${message.user.name} [${message.user.clientId}]join`);
        this.remoteUsers.addUser(message.user);
      } else if ((message == null ? void 0 : message.nexteditor) === "cursor") {
        this.remoteUsers.setCursor(message);
      } else if (value === null) {
        this.remoteUsers.removeUser(id);
      }
    });
    __publicField(this, "sendJoinMessage", () => {
      assert(this.localPresence, "no local presence");
      assert(this.user, "fault error, not joined");
      console$1.debug(`send join message, ${this.user.name} [${this.user.clientId}]`);
      const joinMessage = {
        nexteditor: "join",
        user: this.user
      };
      this.localPresence.submit(joinMessage);
    });
    __publicField(this, "submitOp", async (ops) => new Promise((resolve, reject) => {
      this.doc.submitOp(ops, {}, (err) => {
        if (err) {
          console$1.error(`invalid op, ${err.message}, ${JSON.stringify(ops)}`);
          reject(err);
        } else {
          resolve();
        }
      });
    }));
    __publicField(this, "createDoc", async (data) => new Promise((resolve, reject) => {
      this.doc.create(data, JSON1_TYPE_NAME, (error2) => {
        if (error2)
          reject(error2);
        else
          resolve();
      });
    }));
    __publicField(this, "insertChildContainer", async (containerId, blocks) => {
      const ops = ["blocks", containerId, { i: blocks }];
      return this.submitOp(ops);
    });
    __publicField(this, "deleteChildContainer", async (containerId) => {
      const ops = ["blocks", containerId, { r: true }];
      return this.submitOp(ops);
    });
    __publicField(this, "insertBlock", async (containerId, index, obj) => {
      const ops = ["blocks", containerId, index, { i: obj }];
      return this.submitOp(ops);
    });
    __publicField(this, "deleteBlock", async (containerId, index) => {
      const ops = ["blocks", containerId, index, { r: true }];
      return this.submitOp(ops);
    });
    __publicField(this, "updateBlockData", async (containerId, index, delta) => {
      if (delta.delete.length === 0 && Object.keys(delta.insert).length === 0) {
        return Promise.resolve();
      }
      const ops = ["blocks", containerId, index];
      const deletedKeysSet = new Set(delta.delete);
      Object.entries(delta.insert).forEach(([key, value]) => {
        if (deletedKeysSet.has(key)) {
          const op = { r: true, i: value };
          ops.push([key, op]);
        }
      });
      delta.delete.forEach((key) => {
        if (deletedKeysSet.has(key))
          return;
        const op = { r: true };
        ops.push([key, op]);
      });
      Object.entries(delta.insert).forEach(([key, value]) => {
        if (deletedKeysSet.has(key))
          return;
        const op = { i: value };
        ops.push([key, op]);
      });
      return this.submitOp(ops);
    });
    __publicField(this, "updateRichText", async (containerId, index, ops) => {
      const op = ["blocks", containerId, index, "text", { e: ops, et: "rich-text" }];
      return this.submitOp(op);
    });
    __publicField(this, "broadcastClientMessages", (data) => {
      if (!this.localPresence) {
        return Promise.reject(new Error("not connected"));
      }
      return new Promise((resolve, reject) => {
        assert(this.localPresence);
        this.localPresence.submit(data, (err) => {
          if (err)
            reject(err);
          else
            resolve();
        });
      });
    });
    this.options = options;
    this.events = events2;
    const protocols = JSON.stringify({ token: options.token, clientId: this.clientId });
    this.socket = new ReconnectingWebSocket(`${options.server}/${options.collectionName}/${options.documentId}`, toBase64URL(protocols));
    this.socket.onerror = this.handleSocketError;
    this.socket.onclose = this.handleSocketClose;
    this.connection = new Connection(this.socket);
    this.orgMessageHandler = this.socket.onmessage;
    this.socket.onmessage = this.handleWebsocketMessage;
    this.doc = this.connection.get(options.collectionName, options.documentId);
    this.doc.preventCompose = true;
    this.presence = this.connection.getPresence(`${options.collectionName}/${options.documentId}`);
    this.presence.subscribe(this.handleSubscribePresence);
  }
  get data() {
    return this.doc.data;
  }
  get user() {
    assert(this.docUser, "user have not initialized");
    return this.docUser;
  }
  destroy() {
    this.presence.unsubscribe();
    this.doc.removeAllListeners();
    this.connection.close();
  }
}
class ShareDBDoc extends EventCallbacks {
  constructor(options, onSubscribe, onLoadError) {
    super();
    __publicField(this, "client");
    __publicField(this, "handleClientError", () => {
    });
    __publicField(this, "handleSocketClose", () => {
    });
    __publicField(this, "handleOp", (ops, source, clientId) => {
      const local = !!source;
      parseOps(ops, this, local);
    });
    let loaded = false;
    const errorHandler = (type, error2) => {
      if (loaded) {
        options.onDocError(type, error2);
      } else {
        onLoadError(type, error2);
      }
    };
    const subscribeHandler = () => {
      loaded = true;
      onSubscribe();
    };
    this.client = new ShareDBDocClient(options, {
      onSubscribe: subscribeHandler,
      onError: errorHandler,
      onOp: this.handleOp,
      onClose: this.handleSocketClose
    });
  }
  static load(options) {
    return new Promise((resolve, reject) => {
      const doc2 = new ShareDBDoc(options, async () => {
        var _a;
        if (!doc2.client.doc.type) {
          try {
            const emptyDoc = (_a = options.docTemplate) != null ? _a : createEmptyDoc();
            await doc2.client.createDoc(emptyDoc);
          } catch (err) {
            reject(err);
            return;
          }
        }
        resolve(doc2);
      }, (err) => {
        reject(err);
      });
    });
  }
  get data() {
    return this.client.data;
  }
  toJSON() {
    return this.data;
  }
  getContainerBlocks(containerId) {
    const blocks = this.data.blocks[containerId];
    return blocks;
  }
  getBlockData(containerId, blockIndex) {
    const blocks = this.getContainerBlocks(containerId);
    assert(blocks, `no container data: ${containerId}`);
    const blockData = blocks[blockIndex];
    assert(blockData, `no block data: ${blockIndex}`);
    return blockData;
  }
  localInsertBlock(containerId, blockIndex, data) {
    this.client.insertBlock(containerId, blockIndex, data);
    return this.getBlockData(containerId, blockIndex);
  }
  localDeleteBlock(containerId, blockIndex) {
    const oldData = this.getBlockData(containerId, blockIndex);
    this.client.deleteBlock(containerId, blockIndex);
    return oldData;
  }
  localUpdateBlockText(containerId, blockIndex, actions) {
    const oldBlockData = this.getBlockData(containerId, blockIndex);
    assert(oldBlockData.text, "no block text");
    this.client.updateRichText(containerId, blockIndex, actions);
    const newText = this.getBlockData(containerId, blockIndex).text;
    assert(newText, "no block text");
    return newText;
  }
  localUpdateBlockData(containerId, blockIndex, delta) {
    const oldBlockData = cloneDeep$1(this.getBlockData(containerId, blockIndex));
    this.client.updateBlockData(containerId, blockIndex, delta);
    return oldBlockData;
  }
  localInsertChildContainer(containerId, blocks) {
    this.client.insertChildContainer(containerId, blocks);
  }
  localDeleteChildContainers(containerIds) {
    containerIds.forEach((id) => {
      this.client.deleteChildContainer(id);
    });
  }
  onDeleteBlock(containerId, blockIndex, local) {
    assert(this.callbacks.length > 0, "no callbacks");
    this.callbacks.forEach((cb) => {
      var _a;
      return (_a = cb.onDeleteBlock) == null ? void 0 : _a.call(cb, containerId, blockIndex, local);
    });
  }
  onInsertBlock(containerId, blockIndex, data, local) {
    assert(this.callbacks.length > 0, "no callbacks");
    this.callbacks.forEach((cb) => {
      var _a;
      return (_a = cb.onInsertBlock) == null ? void 0 : _a.call(cb, containerId, blockIndex, data, local);
    });
  }
  onUpdateBlockData(containerId, blockIndex, delta, local) {
    assert(this.callbacks.length > 0, "no callbacks");
    this.callbacks.forEach((cb) => {
      var _a;
      return (_a = cb.onUpdateBlockData) == null ? void 0 : _a.call(cb, containerId, blockIndex, delta.toDocBlockDelta(), local);
    });
  }
  onUpdateBlockText(containerId, blockIndex, actions, local) {
    assert(this.callbacks.length > 0, "no callbacks");
    this.client.remoteUsers.onUpdateBlockText(this.getBlockData(containerId, blockIndex), actions, local);
    this.callbacks.forEach((cb) => {
      var _a;
      return (_a = cb.onUpdateBlockText) == null ? void 0 : _a.call(cb, containerId, blockIndex, actions, local);
    });
  }
  onDeleteContainer(containerId, local) {
    assert(this.callbacks.length > 0, "no callbacks");
    assert(containerId !== "root", "should not delete root container in doc");
    this.callbacks.forEach((cb) => {
      var _a;
      return (_a = cb.onDeleteChildContainer) == null ? void 0 : _a.call(cb, containerId, local);
    });
  }
  onCreateContainer(containerId, blocks, local) {
    assert(this.callbacks.length > 0, "no callbacks");
    assert(containerId !== "root", "should not create root container in doc");
    this.callbacks.forEach((cb) => {
      var _a;
      return (_a = cb.onInsertChildContainer) == null ? void 0 : _a.call(cb, containerId, blocks, local);
    });
  }
  destroy() {
    this.client.destroy();
    this.clearCallbacks();
  }
}
class RemoteCursorDecorator {
  decorateText(editor, containerId, blockIndex, blockText) {
    const externDoc = editor.doc.externalDoc;
    assert(externDoc instanceof ShareDBDoc, "invalid doc type");
    const insertions = /* @__PURE__ */ new Map();
    const client = externDoc.client;
    const blockData = editor.doc.getBlockData(containerId, blockIndex);
    const length = getTextLength(blockText);
    const cursorMessages = client.remoteUsers.getSimpleCursors(blockData.id);
    const activeCursors = /* @__PURE__ */ new Set();
    const now2 = Date.now();
    cursorMessages.forEach((messages, offset) => {
      if (offset > length) {
        offset = length;
      }
      const insertionsData = messages.map((message) => {
        const data = {
          id: genId(),
          type: "remote-cursor",
          name: message.user.name,
          time: message.time,
          rainbowIndex: message.user.rainbowIndex
        };
        if (now2 - message.time < 5 * 1e3) {
          activeCursors.add(data.id);
        }
        return data;
      });
      const exists = insertions.get(offset);
      if (exists) {
        exists.push(...insertionsData);
      } else {
        insertions.set(offset, insertionsData);
      }
    });
    return {
      insertions
    };
  }
}
var FUNC_ERROR_TEXT = "Expected a function";
var NAN = 0 / 0;
var symbolTag = "[object Symbol]";
var reTrim = /^\s+|\s+$/g;
var reIsBadHex = /^[-+]0x[0-9a-f]+$/i;
var reIsBinary = /^0b[01]+$/i;
var reIsOctal = /^0o[0-7]+$/i;
var freeParseInt = parseInt;
var freeGlobal = typeof commonjsGlobal$1 == "object" && commonjsGlobal$1 && commonjsGlobal$1.Object === Object && commonjsGlobal$1;
var freeSelf = typeof self == "object" && self && self.Object === Object && self;
var root = freeGlobal || freeSelf || Function("return this")();
var objectProto = Object.prototype;
var objectToString = objectProto.toString;
var nativeMax = Math.max, nativeMin = Math.min;
var now = function() {
  return root.Date.now();
};
function debounce(func, wait, options) {
  var lastArgs, lastThis, maxWait, result, timerId, lastCallTime, lastInvokeTime = 0, leading = false, maxing = false, trailing = true;
  if (typeof func != "function") {
    throw new TypeError(FUNC_ERROR_TEXT);
  }
  wait = toNumber(wait) || 0;
  if (isObject(options)) {
    leading = !!options.leading;
    maxing = "maxWait" in options;
    maxWait = maxing ? nativeMax(toNumber(options.maxWait) || 0, wait) : maxWait;
    trailing = "trailing" in options ? !!options.trailing : trailing;
  }
  function invokeFunc(time) {
    var args = lastArgs, thisArg = lastThis;
    lastArgs = lastThis = void 0;
    lastInvokeTime = time;
    result = func.apply(thisArg, args);
    return result;
  }
  function leadingEdge(time) {
    lastInvokeTime = time;
    timerId = setTimeout(timerExpired, wait);
    return leading ? invokeFunc(time) : result;
  }
  function remainingWait(time) {
    var timeSinceLastCall = time - lastCallTime, timeSinceLastInvoke = time - lastInvokeTime, result2 = wait - timeSinceLastCall;
    return maxing ? nativeMin(result2, maxWait - timeSinceLastInvoke) : result2;
  }
  function shouldInvoke(time) {
    var timeSinceLastCall = time - lastCallTime, timeSinceLastInvoke = time - lastInvokeTime;
    return lastCallTime === void 0 || timeSinceLastCall >= wait || timeSinceLastCall < 0 || maxing && timeSinceLastInvoke >= maxWait;
  }
  function timerExpired() {
    var time = now();
    if (shouldInvoke(time)) {
      return trailingEdge(time);
    }
    timerId = setTimeout(timerExpired, remainingWait(time));
  }
  function trailingEdge(time) {
    timerId = void 0;
    if (trailing && lastArgs) {
      return invokeFunc(time);
    }
    lastArgs = lastThis = void 0;
    return result;
  }
  function cancel() {
    if (timerId !== void 0) {
      clearTimeout(timerId);
    }
    lastInvokeTime = 0;
    lastArgs = lastCallTime = lastThis = timerId = void 0;
  }
  function flush() {
    return timerId === void 0 ? result : trailingEdge(now());
  }
  function debounced() {
    var time = now(), isInvoking = shouldInvoke(time);
    lastArgs = arguments;
    lastThis = this;
    lastCallTime = time;
    if (isInvoking) {
      if (timerId === void 0) {
        return leadingEdge(lastCallTime);
      }
      if (maxing) {
        timerId = setTimeout(timerExpired, wait);
        return invokeFunc(lastCallTime);
      }
    }
    if (timerId === void 0) {
      timerId = setTimeout(timerExpired, wait);
    }
    return result;
  }
  debounced.cancel = cancel;
  debounced.flush = flush;
  return debounced;
}
function isObject(value) {
  var type = typeof value;
  return !!value && (type == "object" || type == "function");
}
function isObjectLike(value) {
  return !!value && typeof value == "object";
}
function isSymbol(value) {
  return typeof value == "symbol" || isObjectLike(value) && objectToString.call(value) == symbolTag;
}
function toNumber(value) {
  if (typeof value == "number") {
    return value;
  }
  if (isSymbol(value)) {
    return NAN;
  }
  if (isObject(value)) {
    var other = typeof value.valueOf == "function" ? value.valueOf() : value;
    value = isObject(other) ? other + "" : other;
  }
  if (typeof value != "string") {
    return value === 0 ? value : +value;
  }
  value = value.replace(reTrim, "");
  var isBinary = reIsBinary.test(value);
  return isBinary || reIsOctal.test(value) ? freeParseInt(value.slice(2), isBinary ? 2 : 8) : reIsBadHex.test(value) ? NAN : +value;
}
var lodash_debounce = debounce;
class BroadcastCursor {
  constructor(editor) {
    __publicField(this, "lastUpdateTextTime", 0);
    __publicField(this, "broadcastCursor", lodash_debounce(() => {
      const client = this.editor.doc.externalDoc.client;
      const range = this.editor.selection.range.toDocRange();
      const message = {
        nexteditor: "cursor",
        user: client.user,
        range,
        time: this.lastUpdateTextTime
      };
      this.editor.doc.externalDoc.client.broadcastClientMessages(message);
    }, 100));
    this.editor = editor;
    editor.doc.registerCallback(this);
  }
  destroy() {
    this.editor.doc.unregisterCallback(this);
  }
  handleSelectionChange() {
    this.broadcastCursor();
  }
  onUpdateBlockText(containerId, blockIndex, actions, local) {
    if (local) {
      this.lastUpdateTextTime = Date.now();
    }
  }
}
export { BroadcastCursor, RemoteCursorDecorator, ShareDBDoc as default };
//# sourceMappingURL=index.es.js.map
